# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.open_ai_think_provider_model import OpenAiThinkProviderModel


class OpenAiThinkProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["open_ai"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the OpenAI chat completions API
    """

    model: OpenAiThinkProviderModel
    """
    OpenAI model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    OpenAI temperature (0-2)
    """
