# This file was auto-generated by Fern from our API Definition.

import typing

from .read_v1request_text import ReadV1RequestTextParams
from .read_v1request_url import ReadV1RequestUrlParams

ReadV1RequestParams = typing.Union[ReadV1RequestUrlParams, ReadV1RequestTextParams]
