# This file was auto-generated by Fern from our API Definition.

import typing

from .get_model_v1response_batch import GetModelV1ResponseBatch
from .get_model_v1response_metadata import GetModelV1ResponseMetadata

GetModelV1Response = typing.Union[GetModelV1ResponseBatch, GetModelV1ResponseMetadata]
