# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GetModelV1ResponseBatch(UniversalBaseModel):
    name: typing.Optional[str] = None
    canonical_name: typing.Optional[str] = None
    architecture: typing.Optional[str] = None
    languages: typing.Optional[typing.List[str]] = None
    version: typing.Optional[str] = None
    uuid_: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="uuid"), pydantic.Field(alias="uuid")
    ] = None
    batch: typing.Optional[bool] = None
    streaming: typing.Optional[bool] = None
    formatted_output: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
