# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1conversation_text_role import AgentV1ConversationTextRole


class AgentV1ConversationText(UniversalBaseModel):
    type: typing.Literal["ConversationText"] = pydantic.Field(default="ConversationText")
    """
    Message type identifier for conversation text
    """

    role: AgentV1ConversationTextRole = pydantic.Field()
    """
    Identifies who spoke the statement
    """

    content: str = pydantic.Field()
    """
    The actual statement that was spoken
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
