# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListenV2FatalErrorParams(typing_extensions.TypedDict):
    type: typing.Literal["Error"]
    """
    Message type identifier
    """

    sequence_id: float
    """
    Starts at `0` and increments for each message the server sends
    to the client.  This includes messages of other types, like
    `Connected` messages.
    """

    code: str
    """
    A string code describing the error, e.g. `INTERNAL_SERVER_ERROR`
    """

    description: str
    """
    Prose description of the error
    """
