# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_utterances_item_words_item import ListenV1ResponseResultsUtterancesItemWordsItemParams


class ListenV1ResponseResultsUtterancesItemParams(typing_extensions.TypedDict):
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
    confidence: typing_extensions.NotRequired[float]
    channel: typing_extensions.NotRequired[float]
    transcript: typing_extensions.NotRequired[str]
    words: typing_extensions.NotRequired[typing.Sequence[ListenV1ResponseResultsUtterancesItemWordsItemParams]]
    speaker: typing_extensions.NotRequired[float]
    id: typing_extensions.NotRequired[str]
