# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_models_v1response_stt_models import ListModelsV1ResponseSttModelsParams
from .list_models_v1response_tts_models import ListModelsV1ResponseTtsModelsParams


class ListModelsV1ResponseParams(typing_extensions.TypedDict):
    stt: typing_extensions.NotRequired[typing.Sequence[ListModelsV1ResponseSttModelsParams]]
    tts: typing_extensions.NotRequired[typing.Sequence[ListModelsV1ResponseTtsModelsParams]]
