# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class UsageFieldsV1ResponseModelsItemParams(typing_extensions.TypedDict):
    name: typing_extensions.NotRequired[str]
    """
    Name of the model.
    """

    language: typing_extensions.NotRequired[str]
    """
    The language supported by the model (IETF language tag).
    """

    version: typing_extensions.NotRequired[str]
    """
    Version identifier of the model, typically with a date and a revision number.
    """

    model_id: typing_extensions.NotRequired[str]
    """
    Unique identifier for the model.
    """
