# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GetProjectBalanceV1Response(UniversalBaseModel):
    balance_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of the balance
    """

    amount: typing.Optional[float] = pydantic.Field(default=None)
    """
    The amount of the balance
    """

    units: typing.Optional[str] = pydantic.Field(default=None)
    """
    The units of the balance, such as "USD"
    """

    purchase_order_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description or reference of the purchase
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
