# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions


class CreateKeyV1ResponseParams(typing_extensions.TypedDict):
    """
    API key created
    """

    api_key_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the API key
    """

    key: typing_extensions.NotRequired[str]
    """
    The API key
    """

    comment: typing_extensions.NotRequired[str]
    """
    A comment for the API key
    """

    scopes: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The scopes for the API key
    """

    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The tags for the API key
    """

    expiration_date: typing_extensions.NotRequired[dt.datetime]
    """
    The expiration date of the API key
    """
