# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListenV1MetadataParams(typing_extensions.TypedDict):
    type: typing.Literal["Metadata"]
    """
    Message type identifier
    """

    transaction_key: str
    """
    The transaction key
    """

    request_id: str
    """
    The request ID
    """

    sha256: str
    """
    The sha256
    """

    created: str
    """
    The created
    """

    duration: float
    """
    The duration
    """

    channels: float
    """
    The channels
    """
