# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListenV2ConnectedParams(typing_extensions.TypedDict):
    type: typing.Literal["Connected"]
    """
    Message type identifier
    """

    request_id: str
    """
    The unique identifier of the request
    """

    sequence_id: float
    """
    Starts at `0` and increments for each message the server sends
    to the client.  This includes messages of other types, like
    `TurnInfo` messages.
    """
