# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1SettingsAgentListenProviderV1Params(typing_extensions.TypedDict):
    type: typing.Literal["deepgram"]
    """
    Provider type for speech-to-text
    """

    model: typing_extensions.NotRequired[str]
    """
    Model to use for speech to text using the V1 API (e.g. Nova-3, Nova-2)
    """

    language: typing_extensions.NotRequired[str]
    """
    Language code to use for speech-to-text. Can be a BCP-47 language tag (e.g. `en`), or `multi` for code-switching transcription
    """

    keyterms: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Prompt keyterm recognition to improve Keyword Recall Rate
    """

    smart_format: typing_extensions.NotRequired[bool]
    """
    Applies smart formatting to improve transcript readability
    """
