# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .shared_topics_results import SharedTopicsResultsParams


class SharedTopicsParams(typing_extensions.TypedDict):
    """
    Output whenever `topics=true` is used
    """

    results: typing_extensions.NotRequired[SharedTopicsResultsParams]
