# This file was auto-generated by Fern from our API Definition.

import typing

AgentThinkModelsV1ResponseModelsItemZeroId = typing.Union[
    typing.Literal[
        "gpt-5", "gpt-5-mini", "gpt-5-nano", "gpt-4.1", "gpt-4.1-mini", "gpt-4.1-nano", "gpt-4o", "gpt-4o-mini"
    ],
    typing.Any,
]
