# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ListenV1ResultsChannelAlternativesItemWordsItem(UniversalBaseModel):
    word: str = pydantic.Field()
    """
    The word of the transcription
    """

    start: float = pydantic.Field()
    """
    The start time of the word
    """

    end: float = pydantic.Field()
    """
    The end time of the word
    """

    confidence: float = pydantic.Field()
    """
    The confidence of the word
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    The language of the word
    """

    punctuated_word: typing.Optional[str] = pydantic.Field(default=None)
    """
    The punctuated word of the word
    """

    speaker: typing.Optional[float] = pydantic.Field(default=None)
    """
    The speaker of the word
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
