# This file was auto-generated by Fern from our API Definition.

import typing

from ....requests.think_settings_v1 import ThinkSettingsV1Params

AgentV1SettingsAgentThinkParams = typing.Union[ThinkSettingsV1Params, typing.Sequence[ThinkSettingsV1Params]]
