# This file was auto-generated by Fern from our API Definition.

import typing

ListenV1Redact = typing.Optional[
    typing.Union[
        typing.Literal["true", "false", "pci", "numbers", "aggressive_numbers", "ssn"],
        str,
        typing.Sequence[str],
    ]
]
