# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1InjectAgentMessageParams(typing_extensions.TypedDict):
    type: typing.Literal["InjectAgentMessage"]
    """
    Message type identifier for injecting an agent message
    """

    message: str
    """
    The statement that the agent should say
    """
