# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item_entities_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams,
)
from .listen_v1response_results_channels_item_alternatives_item_paragraphs import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams,
)
from .listen_v1response_results_channels_item_alternatives_item_summaries_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams,
)
from .listen_v1response_results_channels_item_alternatives_item_topics_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams,
)
from .listen_v1response_results_channels_item_alternatives_item_words_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams,
)


class ListenV1ResponseResultsChannelsItemAlternativesItemParams(typing_extensions.TypedDict):
    transcript: typing_extensions.NotRequired[str]
    confidence: typing_extensions.NotRequired[float]
    words: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams]
    ]
    paragraphs: typing_extensions.NotRequired[ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams]
    entities: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams]
    ]
    summaries: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams]
    ]
    topics: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams]
    ]
