# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_project_distribution_credentials_v1response_distribution_credentials import (
    GetProjectDistributionCredentialsV1ResponseDistributionCredentials,
)
from .get_project_distribution_credentials_v1response_member import GetProjectDistributionCredentialsV1ResponseMember


class GetProjectDistributionCredentialsV1Response(UniversalBaseModel):
    member: GetProjectDistributionCredentialsV1ResponseMember
    distribution_credentials: GetProjectDistributionCredentialsV1ResponseDistributionCredentials

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
