# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ThinkSettingsV1EndpointParams(typing_extensions.TypedDict):
    """
    Optional for non-Deepgram LLM providers. When present, must include url field and headers object
    """

    url: typing_extensions.NotRequired[str]
    """
    Custom LLM endpoint URL
    """

    headers: typing_extensions.NotRequired[typing.Dict[str, str]]
    """
    Custom headers for the endpoint
    """
