# This file was auto-generated by Fern from our API Definition.

import typing

from .listen_v1response_results_channels_item import ListenV1ResponseResultsChannelsItem

ListenV1ResponseResultsChannels = typing.List[ListenV1ResponseResultsChannelsItem]
