# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.aws_polly_speak_provider_credentials_type import AwsPollySpeakProviderCredentialsType


class AwsPollySpeakProviderCredentialsParams(typing_extensions.TypedDict):
    type: AwsPollySpeakProviderCredentialsType
    region: str
    access_key_id: str
    secret_access_key: str
    session_token: typing_extensions.NotRequired[str]
    """
    Required for STS only
    """
