# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_v1settings_agent_context_messages_item_content import AgentV1SettingsAgentContextMessagesItemContentParams
from .agent_v1settings_agent_context_messages_item_function_calls import (
    AgentV1SettingsAgentContextMessagesItemFunctionCallsParams,
)

AgentV1SettingsAgentContextMessagesItemParams = typing.Union[
    AgentV1SettingsAgentContextMessagesItemContentParams, AgentV1SettingsAgentContextMessagesItemFunctionCallsParams
]
