# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.agent_v1settings_audio_input_encoding import AgentV1SettingsAudioInputEncoding


class AgentV1SettingsAudioInputParams(typing_extensions.TypedDict):
    """
    Audio input configuration settings. If omitted, defaults to encoding=linear16 and sample_rate=24000. Higher sample rates like 44100 Hz provide better audio quality.
    """

    encoding: AgentV1SettingsAudioInputEncoding
    """
    Audio encoding format
    """

    sample_rate: float
    """
    Sample rate in Hz. Common values are 16000, 24000, 44100, 48000
    """
