# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1PromptUpdatedParams(typing_extensions.TypedDict):
    type: typing.Literal["PromptUpdated"]
    """
    Message type identifier for prompt update confirmation
    """
