# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.deepgram_speak_provider_model import DeepgramSpeakProviderModel


class DeepgramParams(typing_extensions.TypedDict):
    type: typing.Literal["deepgram"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the Deepgram text-to-speech API
    """

    model: DeepgramSpeakProviderModel
    """
    Deepgram TTS model
    """
