# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions


class GetProjectKeyV1ResponseItemMemberApiKeyParams(typing_extensions.TypedDict):
    api_key_id: typing_extensions.NotRequired[str]
    comment: typing_extensions.NotRequired[str]
    scopes: typing_extensions.NotRequired[typing.Sequence[str]]
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    expiration_date: typing_extensions.NotRequired[dt.datetime]
    created: typing_extensions.NotRequired[dt.datetime]
