# This file was auto-generated by Fern from our API Definition.

import typing

ElevenLabsSpeakProviderModelId = typing.Union[
    typing.Literal["eleven_turbo_v2_5", "eleven_monolingual_v1", "eleven_multilingual_v2"], typing.Any
]
