# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams(typing_extensions.TypedDict):
    confidence: typing_extensions.NotRequired[float]
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
    snippet: typing_extensions.NotRequired[str]
