# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .listen_v1response_metadata import ListenV1ResponseMetadataParams
from .listen_v1response_results import ListenV1ResponseResultsParams


class ListenV1ResponseParams(typing_extensions.TypedDict):
    """
    The standard transcription response
    """

    metadata: ListenV1ResponseMetadataParams
    results: ListenV1ResponseResultsParams
