# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .usage_fields_v1response_models_item import UsageFieldsV1ResponseModelsItemParams


class UsageFieldsV1ResponseParams(typing_extensions.TypedDict):
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    List of tags associated with the project
    """

    models: typing_extensions.NotRequired[typing.Sequence[UsageFieldsV1ResponseModelsItemParams]]
    """
    List of models available for the project.
    """

    processing_methods: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Processing methods supported by the API
    """

    features: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    API features available to the project
    """
