# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKey


class GetProjectKeyV1ResponseItemMember(UniversalBaseModel):
    member_id: typing.Optional[str] = None
    email: typing.Optional[str] = None
    first_name: typing.Optional[str] = None
    last_name: typing.Optional[str] = None
    api_key: typing.Optional[GetProjectKeyV1ResponseItemMemberApiKey] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
