# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .usage_breakdown_v1response_resolution import UsageBreakdownV1ResponseResolutionParams
from .usage_breakdown_v1response_results_item import UsageBreakdownV1ResponseResultsItemParams


class UsageBreakdownV1ResponseParams(typing_extensions.TypedDict):
    start: str
    """
    Start date of the usage period
    """

    end: str
    """
    End date of the usage period
    """

    resolution: UsageBreakdownV1ResponseResolutionParams
    results: typing.Sequence[UsageBreakdownV1ResponseResultsItemParams]
