# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1results_channel_alternatives_item import ListenV1ResultsChannelAlternativesItemParams


class ListenV1ResultsChannelParams(typing_extensions.TypedDict):
    alternatives: typing.Sequence[ListenV1ResultsChannelAlternativesItemParams]
