# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ListenV1Metadata(UniversalBaseModel):
    type: typing.Literal["Metadata"] = pydantic.Field(default="Metadata")
    """
    Message type identifier
    """

    transaction_key: str = pydantic.Field()
    """
    The transaction key
    """

    request_id: str = pydantic.Field()
    """
    The request ID
    """

    sha256: str = pydantic.Field()
    """
    The sha256
    """

    created: str = pydantic.Field()
    """
    The created
    """

    duration: float = pydantic.Field()
    """
    The duration
    """

    channels: float = pydantic.Field()
    """
    The channels
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
