# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ThinkSettingsV1FunctionsItemEndpoint(UniversalBaseModel):
    """
    The Function endpoint to call. if not passed, function is called client-side
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Endpoint URL
    """

    method: typing.Optional[str] = pydantic.Field(default=None)
    """
    HTTP method
    """

    headers: typing.Optional[typing.Dict[str, str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
