# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .shared_sentiments_average import SharedSentimentsAverageParams
from .shared_sentiments_segments_item import SharedSentimentsSegmentsItemParams


class SharedSentimentsParams(typing_extensions.TypedDict):
    """
    Output whenever `sentiment=true` is used
    """

    segments: typing_extensions.NotRequired[typing.Sequence[SharedSentimentsSegmentsItemParams]]
    average: typing_extensions.NotRequired[SharedSentimentsAverageParams]
