# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class DeepgramClientEnvironment:
    PRODUCTION: DeepgramClientEnvironment
    AGENT: DeepgramClientEnvironment

    def __init__(self, *, base: str, production: str, agent: str):
        self.base = base
        self.production = production
        self.agent = agent


DeepgramClientEnvironment.PRODUCTION = DeepgramClientEnvironment(
    base="https://api.deepgram.com", production="wss://api.deepgram.com", agent="wss://agent.deepgram.com"
)
DeepgramClientEnvironment.AGENT = DeepgramClientEnvironment(
    base="https://agent.deepgram.com", production="wss://api.deepgram.com", agent="wss://agent.deepgram.com"
)
