# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams,
)


class ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams(typing_extensions.TypedDict):
    sentences: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams]
    ]
    speaker: typing_extensions.NotRequired[float]
    num_words: typing_extensions.NotRequired[float]
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
