# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class CreateProjectInviteV1ResponseParams(typing_extensions.TypedDict):
    message: typing_extensions.NotRequired[str]
    """
    confirmation message
    """
