# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .deepgram_speak_provider_model import DeepgramSpeakProviderModel


class Deepgram(UniversalBaseModel):
    type: typing.Literal["deepgram"] = "deepgram"
    version: typing.Optional[typing.Literal["v1"]] = pydantic.Field(default=None)
    """
    The REST API version for the Deepgram text-to-speech API
    """

    model: DeepgramSpeakProviderModel = pydantic.Field()
    """
    Deepgram TTS model
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
