# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams,
)


class ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams(typing_extensions.TypedDict):
    transcript: typing_extensions.NotRequired[str]
    paragraphs: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams]
    ]
