# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.listen_v1response_results_utterances_item import ListenV1ResponseResultsUtterancesItem

ListenV1ResponseResultsUtterancesParams = typing.List[ListenV1ResponseResultsUtterancesItem]
