# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1KeepAliveParams(typing_extensions.TypedDict):
    """
    Send a control message to the agent
    """

    type: typing.Literal["KeepAlive"]
    """
    Message type identifier
    """
