# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .shared_topics_results_topics_segments_item_topics_item import (
    SharedTopicsResultsTopicsSegmentsItemTopicsItemParams,
)


class SharedTopicsResultsTopicsSegmentsItemParams(typing_extensions.TypedDict):
    text: typing_extensions.NotRequired[str]
    start_word: typing_extensions.NotRequired[float]
    end_word: typing_extensions.NotRequired[float]
    topics: typing_extensions.NotRequired[typing.Sequence[SharedTopicsResultsTopicsSegmentsItemTopicsItemParams]]
