# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_project_invites_v1response_invites_item import ListProjectInvitesV1ResponseInvitesItemParams


class ListProjectInvitesV1ResponseParams(typing_extensions.TypedDict):
    invites: typing_extensions.NotRequired[typing.Sequence[ListProjectInvitesV1ResponseInvitesItemParams]]
