# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .speak_settings_v1endpoint import SpeakSettingsV1EndpointParams
from .speak_settings_v1provider import SpeakSettingsV1ProviderParams


class SpeakSettingsV1Params(typing_extensions.TypedDict):
    provider: SpeakSettingsV1ProviderParams
    endpoint: typing_extensions.NotRequired[SpeakSettingsV1EndpointParams]
    """
    Optional if provider is Deepgram. Required for non-Deepgram TTS providers.
    When present, must include url field and headers object. Valid schemes are https and wss with wss only supported for Eleven Labs.
    """
