# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class ListModelsV1ResponseSttModelsParams(typing_extensions.TypedDict):
    name: typing_extensions.NotRequired[str]
    canonical_name: typing_extensions.NotRequired[str]
    architecture: typing_extensions.NotRequired[str]
    languages: typing_extensions.NotRequired[typing.Sequence[str]]
    version: typing_extensions.NotRequired[str]
    uuid_: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="uuid")]]
    batch: typing_extensions.NotRequired[bool]
    streaming: typing_extensions.NotRequired[bool]
    formatted_output: typing_extensions.NotRequired[bool]
