# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_metadata_metadata import ReadV1ResponseMetadataMetadataParams


class ReadV1ResponseMetadataParams(typing_extensions.TypedDict):
    metadata: typing_extensions.NotRequired[ReadV1ResponseMetadataMetadataParams]
