# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_projects_v1response_projects_item import ListProjectsV1ResponseProjectsItemParams


class ListProjectsV1ResponseParams(typing_extensions.TypedDict):
    projects: typing_extensions.NotRequired[typing.Sequence[ListProjectsV1ResponseProjectsItemParams]]
