# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.cartesia_speak_provider_model_id import CartesiaSpeakProviderModelId
from .cartesia_speak_provider_voice import CartesiaSpeakProviderVoiceParams


class CartesiaParams(typing_extensions.TypedDict):
    type: typing.Literal["cartesia"]
    version: typing_extensions.NotRequired[typing.Literal["2025-03-17"]]
    """
    The API version header for the Cartesia text-to-speech API
    """

    model_id: CartesiaSpeakProviderModelId
    """
    Cartesia model ID
    """

    voice: CartesiaSpeakProviderVoiceParams
    language: typing_extensions.NotRequired[str]
    """
    Cartesia language code
    """
