# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_v1settings_agent_context_messages_item_content import AgentV1SettingsAgentContextMessagesItemContent
from .agent_v1settings_agent_context_messages_item_function_calls import (
    AgentV1SettingsAgentContextMessagesItemFunctionCalls,
)

AgentV1SettingsAgentContextMessagesItem = typing.Union[
    AgentV1SettingsAgentContextMessagesItemContent, AgentV1SettingsAgentContextMessagesItemFunctionCalls
]
