# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.think_settings_v1 import ThinkSettingsV1

AgentV1SettingsAgentThink = typing.Union[ThinkSettingsV1, typing.List[ThinkSettingsV1]]
