# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_metadata import ReadV1ResponseMetadataParams
from .read_v1response_results import ReadV1ResponseResultsParams


class ReadV1ResponseParams(typing_extensions.TypedDict):
    """
    The standard text response
    """

    metadata: ReadV1ResponseMetadataParams
    results: ReadV1ResponseResultsParams
