# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_v1function_call_request_functions_item import AgentV1FunctionCallRequestFunctionsItemParams


class AgentV1FunctionCallRequestParams(typing_extensions.TypedDict):
    type: typing.Literal["FunctionCallRequest"]
    """
    Message type identifier for function call requests
    """

    functions: typing.Sequence[AgentV1FunctionCallRequestFunctionsItemParams]
    """
    Array of functions to be called
    """
