# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_project_keys_v1response_api_keys_item import ListProjectKeysV1ResponseApiKeysItemParams


class ListProjectKeysV1ResponseParams(typing_extensions.TypedDict):
    api_keys: typing_extensions.NotRequired[typing.Sequence[ListProjectKeysV1ResponseApiKeysItemParams]]
