# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.listen_v1response_results_channels_item import ListenV1ResponseResultsChannelsItem

ListenV1ResponseResultsChannelsParams = typing.List[ListenV1ResponseResultsChannelsItem]
