# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SharedSentimentsSegmentsItemParams(typing_extensions.TypedDict):
    text: typing_extensions.NotRequired[str]
    start_word: typing_extensions.NotRequired[float]
    end_word: typing_extensions.NotRequired[float]
    sentiment: typing_extensions.NotRequired[str]
    sentiment_score: typing_extensions.NotRequired[float]
