# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentV1SettingsAgentListenProviderV2(UniversalBaseModel):
    type: typing.Literal["deepgram"] = pydantic.Field(default="deepgram")
    """
    Provider type for speech-to-text
    """

    model: str = pydantic.Field()
    """
    Model to use for speech to text using the V2 API (e.g. flux-general-en)
    """

    keyterms: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Prompt keyterm recognition to improve Keyword Recall Rate
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
