# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UsageFieldsV1ResponseModelsItem(UniversalBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the model.
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    The language supported by the model (IETF language tag).
    """

    version: typing.Optional[str] = pydantic.Field(default=None)
    """
    Version identifier of the model, typically with a date and a revision number.
    """

    model_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier for the model.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
