# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .get_project_distribution_credentials_v1response_distribution_credentials import (
    GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams,
)
from .get_project_distribution_credentials_v1response_member import (
    GetProjectDistributionCredentialsV1ResponseMemberParams,
)


class GetProjectDistributionCredentialsV1ResponseParams(typing_extensions.TypedDict):
    member: GetProjectDistributionCredentialsV1ResponseMemberParams
    distribution_credentials: GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams
