# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class SpeakSettingsV1EndpointParams(typing_extensions.TypedDict):
    """
    Optional if provider is Deepgram. Required for non-Deepgram TTS providers.
    When present, must include url field and headers object. Valid schemes are https and wss with wss only supported for Eleven Labs.
    """

    url: typing_extensions.NotRequired[str]
    """
    Custom TTS endpoint URL. Cannot contain `output_format` or `model_id` query parameters when the provider is Eleven Labs.
    """

    headers: typing_extensions.NotRequired[typing.Dict[str, str]]
