# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1AgentAudioDoneParams(typing_extensions.TypedDict):
    type: typing.Literal["AgentAudioDone"]
    """
    Message type identifier indicating the agent has finished sending audio
    """
