# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .listen_v1response_results_channels import ListenV1ResponseResultsChannelsParams
from .listen_v1response_results_summary import ListenV1ResponseResultsSummaryParams
from .listen_v1response_results_utterances import ListenV1ResponseResultsUtterancesParams
from .shared_intents import SharedIntentsParams
from .shared_sentiments import SharedSentimentsParams
from .shared_topics import SharedTopicsParams


class ListenV1ResponseResultsParams(typing_extensions.TypedDict):
    channels: ListenV1ResponseResultsChannelsParams
    utterances: typing_extensions.NotRequired[ListenV1ResponseResultsUtterancesParams]
    summary: typing_extensions.NotRequired[ListenV1ResponseResultsSummaryParams]
    topics: typing_extensions.NotRequired[SharedTopicsParams]
    intents: typing_extensions.NotRequired[SharedIntentsParams]
    sentiments: typing_extensions.NotRequired[SharedSentimentsParams]
