# This file was auto-generated by Fern from our API Definition.

import typing

AwsPollySpeakProviderVoice = typing.Union[
    typing.Literal["Matthew", "Joanna", "Amy", "Emma", "Brian", "Arthur", "Aria", "Ayanda"], typing.Any
]
