# This file was auto-generated by Fern from our API Definition.

import datetime as dt

import typing_extensions


class ListProjectPurchasesV1ResponseOrdersItemParams(typing_extensions.TypedDict):
    order_id: typing_extensions.NotRequired[str]
    expiration: typing_extensions.NotRequired[dt.datetime]
    created: typing_extensions.NotRequired[dt.datetime]
    amount: typing_extensions.NotRequired[float]
    units: typing_extensions.NotRequired[str]
    order_type: typing_extensions.NotRequired[str]
