# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class GrantV1ResponseParams(typing_extensions.TypedDict):
    access_token: str
    """
    JSON Web Token (JWT)
    """

    expires_in: typing_extensions.NotRequired[float]
    """
    Time in seconds until the JWT expires
    """
