# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class CartesiaSpeakProviderVoiceParams(typing_extensions.TypedDict):
    mode: str
    """
    Cartesia voice mode
    """

    id: str
    """
    Cartesia voice ID
    """
