# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .listen_v1results_metadata_model_info import ListenV1ResultsMetadataModelInfo


class ListenV1ResultsMetadata(UniversalBaseModel):
    request_id: str = pydantic.Field()
    """
    The request ID
    """

    model_info: ListenV1ResultsMetadataModelInfo
    model_uuid: str = pydantic.Field()
    """
    The model UUID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
