"""Concrete transport implementations for the Deepgram Python SDK.

Custom transports can be passed to ``AsyncDeepgramClient(transport_factory=...)``
or ``DeepgramClient(transport_factory=...)``.

See ``deepgram.transport_interface`` for the protocol definitions.
"""

__all__: list = []
