# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.speak_v1close_type import SpeakV1CloseType


class SpeakV1CloseParams(typing_extensions.TypedDict):
    type: SpeakV1CloseType
    """
    Message type identifier
    """
