# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials import (
    ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials,
)
from .list_project_distribution_credentials_v1response_distribution_credentials_item_member import (
    ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember,
)


class ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem(UniversalBaseModel):
    member: ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember
    distribution_credentials: (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
