# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ReadV1RequestTextParams(typing_extensions.TypedDict):
    text: str
    """
    The plain text to analyze
    """
