# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1results_channel_alternatives_item_words_item import ListenV1ResultsChannelAlternativesItemWordsItemParams


class ListenV1ResultsChannelAlternativesItemParams(typing_extensions.TypedDict):
    transcript: str
    """
    The transcript of the transcription
    """

    confidence: float
    """
    The confidence of the transcription
    """

    languages: typing_extensions.NotRequired[typing.Sequence[str]]
    words: typing.Sequence[ListenV1ResultsChannelAlternativesItemWordsItemParams]
