# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.anthropic_think_provider_model import AnthropicThinkProviderModel


class AnthropicParams(typing_extensions.TypedDict):
    type: typing.Literal["anthropic"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the Anthropic Messages API
    """

    model: AnthropicThinkProviderModel
    """
    Anthropic model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    Anthropic temperature (0-1)
    """
