# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams(
    typing_extensions.TypedDict
):
    text: typing_extensions.NotRequired[str]
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
