# This file was auto-generated by Fern from our API Definition.

import typing

ListenV2TurnInfoEvent = typing.Union[
    typing.Literal["Update", "StartOfTurn", "EagerEndOfTurn", "TurnResumed", "EndOfTurn"], typing.Any
]
