# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class SpeakV1WarningParams(typing_extensions.TypedDict):
    type: typing.Literal["Warning"]
    """
    Message type identifier
    """

    description: str
    """
    A description of what went wrong
    """

    code: str
    """
    Error code identifying the type of error
    """
