# This file was auto-generated by Fern from our API Definition.

import typing

from .....requests.listen_v1accepted_response import ListenV1AcceptedResponseParams
from .....requests.listen_v1response import ListenV1ResponseParams

MediaTranscribeResponseParams = typing.Union[ListenV1ResponseParams, ListenV1AcceptedResponseParams]
