# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .think_settings_v1functions_item_endpoint import ThinkSettingsV1FunctionsItemEndpointParams


class ThinkSettingsV1FunctionsItemParams(typing_extensions.TypedDict):
    name: typing_extensions.NotRequired[str]
    """
    Function name
    """

    description: typing_extensions.NotRequired[str]
    """
    Function description
    """

    parameters: typing_extensions.NotRequired[typing.Dict[str, typing.Any]]
    """
    Function parameters
    """

    endpoint: typing_extensions.NotRequired[ThinkSettingsV1FunctionsItemEndpointParams]
    """
    The Function endpoint to call. if not passed, function is called client-side
    """
