# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ReadV1ResponseMetadataMetadataSummaryInfoParams(typing_extensions.TypedDict):
    model_uuid: typing_extensions.NotRequired[str]
    input_tokens: typing_extensions.NotRequired[float]
    output_tokens: typing_extensions.NotRequired[float]
