# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class AgentV1SettingsFlagsParams(typing_extensions.TypedDict):
    history: typing_extensions.NotRequired[bool]
    """
    Enable or disable history message reporting
    """
