# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams(typing_extensions.TypedDict):
    id: str
    """
    Unique identifier for the function call
    """

    name: str
    """
    Name of the function called
    """

    client_side: bool
    """
    Indicates if the call was client-side or server-side
    """

    arguments: str
    """
    Arguments passed to the function
    """

    response: str
    """
    Response from the function call
    """
