# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SpeakSettingsV1Endpoint(UniversalBaseModel):
    """
    Optional if provider is Deepgram. Required for non-Deepgram TTS providers.
    When present, must include url field and headers object. Valid schemes are https and wss with wss only supported for Eleven Labs.
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Custom TTS endpoint URL. Cannot contain `output_format` or `model_id` query parameters when the provider is Eleven Labs.
    """

    headers: typing.Optional[typing.Dict[str, str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
