# This file was auto-generated by Fern from our API Definition.

import typing

DistributionCredentialsCreateRequestScopesItem = typing.Union[
    typing.Literal[
        "self-hosted:products",
        "self-hosted:product:api",
        "self-hosted:product:engine",
        "self-hosted:product:license-proxy",
        "self-hosted:product:dgtools",
        "self-hosted:product:billing",
        "self-hosted:product:hotpepper",
        "self-hosted:product:metrics-server",
    ],
    typing.Any,
]
