# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions
from .listen_v1response_metadata_intents_info import ListenV1ResponseMetadataIntentsInfoParams
from .listen_v1response_metadata_sentiment_info import ListenV1ResponseMetadataSentimentInfoParams
from .listen_v1response_metadata_summary_info import ListenV1ResponseMetadataSummaryInfoParams
from .listen_v1response_metadata_topics_info import ListenV1ResponseMetadataTopicsInfoParams


class ListenV1ResponseMetadataParams(typing_extensions.TypedDict):
    transaction_key: typing_extensions.NotRequired[str]
    request_id: str
    sha256: str
    created: dt.datetime
    duration: float
    channels: float
    models: typing.Sequence[str]
    model_info: typing.Dict[str, typing.Any]
    summary_info: typing_extensions.NotRequired[ListenV1ResponseMetadataSummaryInfoParams]
    sentiment_info: typing_extensions.NotRequired[ListenV1ResponseMetadataSentimentInfoParams]
    topics_info: typing_extensions.NotRequired[ListenV1ResponseMetadataTopicsInfoParams]
    intents_info: typing_extensions.NotRequired[ListenV1ResponseMetadataIntentsInfoParams]
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
