# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.speak_v1flushed_type import SpeakV1FlushedType


class SpeakV1FlushedParams(typing_extensions.TypedDict):
    type: SpeakV1FlushedType
    """
    Message type identifier
    """

    sequence_id: float
    """
    The sequence ID of the response
    """
