# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_project_purchases_v1response_orders_item import ListProjectPurchasesV1ResponseOrdersItemParams


class ListProjectPurchasesV1ResponseParams(typing_extensions.TypedDict):
    orders: typing_extensions.NotRequired[typing.Sequence[ListProjectPurchasesV1ResponseOrdersItemParams]]
