# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions


class ProjectRequestResponseParams(typing_extensions.TypedDict):
    """
    A single request
    """

    request_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the request
    """

    project_uuid: typing_extensions.NotRequired[str]
    """
    The unique identifier of the project
    """

    created: typing_extensions.NotRequired[dt.datetime]
    """
    The date and time the request was created
    """

    path: typing_extensions.NotRequired[str]
    """
    The API path of the request
    """

    api_key_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the API key
    """

    response: typing_extensions.NotRequired[typing.Dict[str, typing.Any]]
    """
    The response of the request
    """

    code: typing_extensions.NotRequired[float]
    """
    The response code of the request
    """

    deployment: typing_extensions.NotRequired[str]
    """
    The deployment type
    """

    callback: typing_extensions.NotRequired[str]
    """
    The callback URL for the request
    """
