# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1settings_audio_output_encoding import AgentV1SettingsAudioOutputEncoding


class AgentV1SettingsAudioOutput(UniversalBaseModel):
    """
    Audio output configuration settings
    """

    encoding: typing.Optional[AgentV1SettingsAudioOutputEncoding] = pydantic.Field(default=None)
    """
    Audio encoding format for streaming TTS output
    """

    sample_rate: typing.Optional[float] = pydantic.Field(default=None)
    """
    Sample rate in Hz
    """

    bitrate: typing.Optional[float] = pydantic.Field(default=None)
    """
    Audio bitrate in bits per second
    """

    container: typing.Optional[str] = pydantic.Field(default=None)
    """
    Audio container format. If omitted, defaults to 'none'
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
