# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.listen_v1keep_alive_type import ListenV1KeepAliveType


class ListenV1KeepAliveParams(typing_extensions.TypedDict):
    type: ListenV1KeepAliveType
    """
    Message type identifier
    """
