# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .billing_breakdown_v1response_results_item_grouping import BillingBreakdownV1ResponseResultsItemGroupingParams


class BillingBreakdownV1ResponseResultsItemParams(typing_extensions.TypedDict):
    dollars: float
    """
    USD cost of the billing for this grouping
    """

    grouping: BillingBreakdownV1ResponseResultsItemGroupingParams
