# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_results_summary import ReadV1ResponseResultsSummaryParams
from .shared_intents import SharedIntentsParams
from .shared_sentiments import SharedSentimentsParams
from .shared_topics import SharedTopicsParams


class ReadV1ResponseResultsParams(typing_extensions.TypedDict):
    summary: typing_extensions.NotRequired[ReadV1ResponseResultsSummaryParams]
    topics: typing_extensions.NotRequired[SharedTopicsParams]
    intents: typing_extensions.NotRequired[SharedIntentsParams]
    sentiments: typing_extensions.NotRequired[SharedSentimentsParams]
