# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class UsageV1ResponseResolutionParams(typing_extensions.TypedDict):
    units: typing_extensions.NotRequired[str]
    amount: typing_extensions.NotRequired[float]
