# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.listen_v1finalize_type import ListenV1FinalizeType


class ListenV1FinalizeParams(typing_extensions.TypedDict):
    type: ListenV1FinalizeType
    """
    Message type identifier
    """
