# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions


class ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams(
    typing_extensions.TypedDict
):
    distribution_credentials_id: str
    """
    Unique identifier for the distribution credentials
    """

    provider: str
    """
    The provider of the distribution service
    """

    comment: typing_extensions.NotRequired[str]
    """
    Optional comment about the credentials
    """

    scopes: typing.Sequence[str]
    """
    List of permission scopes for the credentials
    """

    created: dt.datetime
    """
    Timestamp when the credentials were created
    """
