# This file was auto-generated by Fern from our API Definition.

import typing

from .read_v1request_text import ReadV1RequestText
from .read_v1request_url import ReadV1RequestUrl

ReadV1Request = typing.Union[ReadV1RequestUrl, ReadV1RequestText]
