# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class UsageBreakdownV1ResponseResultsItemGroupingParams(typing_extensions.TypedDict):
    start: typing_extensions.NotRequired[str]
    """
    Start date for this group
    """

    end: typing_extensions.NotRequired[str]
    """
    End date for this group
    """

    accessor: typing_extensions.NotRequired[str]
    """
    Optional accessor identifier
    """

    endpoint: typing_extensions.NotRequired[str]
    """
    Optional endpoint identifier
    """

    feature_set: typing_extensions.NotRequired[str]
    """
    Optional feature set identifier
    """

    models: typing_extensions.NotRequired[str]
    """
    Optional models identifier
    """

    method: typing_extensions.NotRequired[str]
    """
    Optional method identifier
    """

    tags: typing_extensions.NotRequired[str]
    """
    Optional tags
    """

    deployment: typing_extensions.NotRequired[str]
    """
    Optional deployment identifier
    """
