# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.error_response_text_error import ErrorResponseTextError
from .error_response_legacy_error import ErrorResponseLegacyErrorParams
from .error_response_modern_error import ErrorResponseModernErrorParams

ErrorResponseParams = typing.Union[
    ErrorResponseTextError, ErrorResponseLegacyErrorParams, ErrorResponseModernErrorParams
]
