# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.list_billing_fields_v1response_deployments_item import ListBillingFieldsV1ResponseDeploymentsItem


class ListBillingFieldsV1ResponseParams(typing_extensions.TypedDict):
    accessors: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    List of accessor UUIDs for the time period
    """

    deployments: typing_extensions.NotRequired[typing.Sequence[ListBillingFieldsV1ResponseDeploymentsItem]]
    """
    List of deployment types for the time period
    """

    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    List of tags for the time period
    """

    line_items: typing_extensions.NotRequired[typing.Dict[str, str]]
    """
    Map of line item names to human-readable descriptions for the time period
    """
