# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentThinkModelsV1ResponseModelsItemThreeParams(typing_extensions.TypedDict):
    """
    Groq models
    """

    id: typing.Literal["openai/gpt-oss-20b"]
    """
    The unique identifier of the Groq model
    """

    name: str
    """
    The display name of the model
    """

    provider: typing.Literal["groq"]
    """
    The provider of the model
    """
