# This file was auto-generated by Fern from our API Definition.

import typing

ListBillingFieldsV1ResponseDeploymentsItem = typing.Union[
    typing.Literal["hosted", "beta", "self-hosted", "dedicated"], typing.Any
]
