# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1WelcomeParams(typing_extensions.TypedDict):
    type: typing.Literal["Welcome"]
    """
    Message type identifier for welcome message
    """

    request_id: str
    """
    Unique identifier for the request
    """
