# This file was auto-generated by Fern from our API Definition.

import typing

AgentThinkModelsV1ResponseModelsItemTwoId = typing.Union[
    typing.Literal["gemini-2.5-flash", "gemini-2.0-flash", "gemini-2.0-flash-lite"], typing.Any
]
