# This file was auto-generated by Fern from our API Definition.

import typing

from ....requests.speak_settings_v1 import SpeakSettingsV1Params

AgentV1SettingsAgentSpeakParams = typing.Union[SpeakSettingsV1Params, typing.Sequence[SpeakSettingsV1Params]]
