# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1UserStartedSpeakingParams(typing_extensions.TypedDict):
    type: typing.Literal["UserStartedSpeaking"]
    """
    Message type identifier indicating that the user has begun speaking
    """
