# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.agent_think_models_v1response_models_item_one_id import AgentThinkModelsV1ResponseModelsItemOneId


class AgentThinkModelsV1ResponseModelsItemOneParams(typing_extensions.TypedDict):
    """
    Anthropic models
    """

    id: AgentThinkModelsV1ResponseModelsItemOneId
    """
    The unique identifier of the Anthropic model
    """

    name: str
    """
    The display name of the model
    """

    provider: typing.Literal["anthropic"]
    """
    The provider of the model
    """
