# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ErrorResponseModernErrorParams(typing_extensions.TypedDict):
    category: typing_extensions.NotRequired[str]
    """
    The category of the error
    """

    message: typing_extensions.NotRequired[str]
    """
    A message about the error
    """

    details: typing_extensions.NotRequired[str]
    """
    A description of the error
    """

    request_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the request
    """
