# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_project_distribution_credentials_v1response_distribution_credentials_item import (
    ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams,
)


class ListProjectDistributionCredentialsV1ResponseParams(typing_extensions.TypedDict):
    distribution_credentials: typing_extensions.NotRequired[
        typing.Sequence[ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams]
    ]
    """
    Array of distribution credentials with associated member information
    """
