# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.speak_v1clear_type import SpeakV1ClearType


class SpeakV1ClearParams(typing_extensions.TypedDict):
    type: SpeakV1ClearType
    """
    Message type identifier
    """
