# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ....requests.speak_settings_v1 import SpeakSettingsV1Params


class AgentV1UpdateSpeakParams(typing_extensions.TypedDict):
    type: typing.Literal["UpdateSpeak"]
    """
    Message type identifier for updating the speak model
    """

    speak: SpeakSettingsV1Params
