# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .list_project_keys_v1response_api_keys_item_api_key import ListProjectKeysV1ResponseApiKeysItemApiKeyParams
from .list_project_keys_v1response_api_keys_item_member import ListProjectKeysV1ResponseApiKeysItemMemberParams


class ListProjectKeysV1ResponseApiKeysItemParams(typing_extensions.TypedDict):
    member: typing_extensions.NotRequired[ListProjectKeysV1ResponseApiKeysItemMemberParams]
    api_key: typing_extensions.NotRequired[ListProjectKeysV1ResponseApiKeysItemApiKeyParams]
