# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1InjectUserMessageParams(typing_extensions.TypedDict):
    type: typing.Literal["InjectUserMessage"]
    """
    Message type identifier for injecting a user message
    """

    content: str
    """
    The specific phrase or statement the agent should respond to
    """
