# This file was auto-generated by Fern from our API Definition.

import typing

OpenAiSpeakProviderVoice = typing.Union[typing.Literal["alloy", "echo", "fable", "onyx", "nova", "shimmer"], typing.Any]
