# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class BillingBreakdownV1ResponseResolutionParams(typing_extensions.TypedDict):
    units: str
    """
    Time unit for the resolution
    """

    amount: float
    """
    Amount of units
    """
