# This file was auto-generated by Fern from our API Definition.

import typing

AwsPollySpeakProviderEngine = typing.Union[typing.Literal["generative", "long-form", "standard", "neural"], typing.Any]
