# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .shared_intents_results_intents import SharedIntentsResultsIntentsParams


class SharedIntentsResultsParams(typing_extensions.TypedDict):
    intents: typing_extensions.NotRequired[SharedIntentsResultsIntentsParams]
