# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .agent_v1settings_agent_listen_provider import AgentV1SettingsAgentListenProviderParams


class AgentV1SettingsAgentListenParams(typing_extensions.TypedDict):
    provider: typing_extensions.NotRequired[AgentV1SettingsAgentListenProviderParams]
