# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class GroqParams(typing_extensions.TypedDict):
    type: typing.Literal["groq"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the Groq's chat completions API (mostly OpenAI-compatible)
    """

    model: typing.Literal["openai/gpt-oss-20b"]
    """
    Groq model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    Groq temperature (0-2)
    """
