# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .usage_breakdown_v1response_resolution import UsageBreakdownV1ResponseResolution
from .usage_breakdown_v1response_results_item import UsageBreakdownV1ResponseResultsItem


class UsageBreakdownV1Response(UniversalBaseModel):
    start: str = pydantic.Field()
    """
    Start date of the usage period
    """

    end: str = pydantic.Field()
    """
    End date of the usage period
    """

    resolution: UsageBreakdownV1ResponseResolution
    results: typing.List[UsageBreakdownV1ResponseResultsItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
