# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_project_members_v1response_members_item import ListProjectMembersV1ResponseMembersItemParams


class ListProjectMembersV1ResponseParams(typing_extensions.TypedDict):
    members: typing_extensions.NotRequired[typing.Sequence[ListProjectMembersV1ResponseMembersItemParams]]
