# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.agent_think_models_v1response_models_item_two_id import AgentThinkModelsV1ResponseModelsItemTwoId


class AgentThinkModelsV1ResponseModelsItemTwoParams(typing_extensions.TypedDict):
    """
    Google models
    """

    id: AgentThinkModelsV1ResponseModelsItemTwoId
    """
    The unique identifier of the Google model
    """

    name: str
    """
    The display name of the model
    """

    provider: typing.Literal["google"]
    """
    The provider of the model
    """
