# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions


class AgentV1SettingsAgentListenProvider_V1Params(typing_extensions.TypedDict):
    version: typing.Literal["v1"]
    type: typing.Literal["deepgram"]
    model: typing_extensions.NotRequired[str]
    language: typing_extensions.NotRequired[str]
    keyterms: typing_extensions.NotRequired[typing.Sequence[str]]
    smart_format: typing_extensions.NotRequired[bool]


class AgentV1SettingsAgentListenProvider_V2Params(typing_extensions.TypedDict):
    version: typing.Literal["v2"]
    type: typing.Literal["deepgram"]
    model: str
    keyterms: typing_extensions.NotRequired[typing.Sequence[str]]


AgentV1SettingsAgentListenProviderParams = typing.Union[
    AgentV1SettingsAgentListenProvider_V1Params, AgentV1SettingsAgentListenProvider_V2Params
]
