# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV2TurnInfoWordsItemParams(typing_extensions.TypedDict):
    word: str
    """
    The individual punctuated, properly-cased word from the transcript
    """

    confidence: float
    """
    Confidence that this word was transcribed correctly
    """
