# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListProjectInvitesV1ResponseInvitesItemParams(typing_extensions.TypedDict):
    email: typing_extensions.NotRequired[str]
    """
    The email address of the invitee
    """

    scope: typing_extensions.NotRequired[str]
    """
    The scope of the invitee
    """
