# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SharedTopicsResultsTopicsSegmentsItemTopicsItemParams(typing_extensions.TypedDict):
    topic: typing_extensions.NotRequired[str]
    confidence_score: typing_extensions.NotRequired[float]
