# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1InjectionRefusedParams(typing_extensions.TypedDict):
    type: typing.Literal["InjectionRefused"]
    """
    Message type identifier for injection refused
    """

    message: str
    """
    Details about why the injection was refused
    """
