# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.eleven_labs_speak_provider_model_id import ElevenLabsSpeakProviderModelId


class ElevenLabsSpeakProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["eleven_labs"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the ElevenLabs text-to-speech API
    """

    model_id: ElevenLabsSpeakProviderModelId
    """
    Eleven Labs model ID
    """

    language: typing_extensions.NotRequired[str]
    """
    Optional language to use, e.g. 'en-US'. Corresponds to the `language_code` parameter in the ElevenLabs API
    """

    language_code: typing_extensions.NotRequired[str]
    """
    Use the `language` field instead.
    """
