# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1AcceptedResponseParams(typing_extensions.TypedDict):
    """
    Accepted response for asynchronous transcription requests
    """

    request_id: str
    """
    Unique identifier for tracking the asynchronous request
    """
