# This file was auto-generated by Fern from our API Definition.

import typing

AnthropicThinkProviderModel = typing.Union[
    typing.Literal["claude-3-5-haiku-latest", "claude-sonnet-4-20250514"], typing.Any
]
