# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .list_billing_fields_v1response_deployments_item import ListBillingFieldsV1ResponseDeploymentsItem


class ListBillingFieldsV1Response(UniversalBaseModel):
    accessors: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of accessor UUIDs for the time period
    """

    deployments: typing.Optional[typing.List[ListBillingFieldsV1ResponseDeploymentsItem]] = pydantic.Field(default=None)
    """
    List of deployment types for the time period
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of tags for the time period
    """

    line_items: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    Map of line item names to human-readable descriptions for the time period
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
