# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_think_models_v1response_models_item_id import AgentThinkModelsV1ResponseModelsItemId
from .agent_think_models_v1response_models_item_one import AgentThinkModelsV1ResponseModelsItemOne
from .agent_think_models_v1response_models_item_three import AgentThinkModelsV1ResponseModelsItemThree
from .agent_think_models_v1response_models_item_two import AgentThinkModelsV1ResponseModelsItemTwo
from .agent_think_models_v1response_models_item_zero import AgentThinkModelsV1ResponseModelsItemZero

AgentThinkModelsV1ResponseModelsItem = typing.Union[
    AgentThinkModelsV1ResponseModelsItemZero,
    AgentThinkModelsV1ResponseModelsItemOne,
    AgentThinkModelsV1ResponseModelsItemTwo,
    AgentThinkModelsV1ResponseModelsItemThree,
    AgentThinkModelsV1ResponseModelsItemId,
]
