# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.agent_v1settings_agent_context_messages_item_content_role import (
    AgentV1SettingsAgentContextMessagesItemContentRole,
)


class AgentV1SettingsAgentContextMessagesItemContentParams(typing_extensions.TypedDict):
    """
    Conversation text as part of the conversation history
    """

    type: typing.Literal["History"]
    """
    Message type identifier for conversation text
    """

    role: AgentV1SettingsAgentContextMessagesItemContentRole
    """
    Identifies who spoke the statement
    """

    content: str
    """
    The actual statement that was spoken
    """
