# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.aws_bedrock_think_provider_credentials_type import AwsBedrockThinkProviderCredentialsType


class AwsBedrockThinkProviderCredentialsParams(typing_extensions.TypedDict):
    """
    AWS credentials type (STS short-lived or IAM long-lived)
    """

    type: typing_extensions.NotRequired[AwsBedrockThinkProviderCredentialsType]
    """
    AWS credentials type (STS short-lived or IAM long-lived)
    """

    region: typing_extensions.NotRequired[str]
    """
    AWS region
    """

    access_key_id: typing_extensions.NotRequired[str]
    """
    AWS access key
    """

    secret_access_key: typing_extensions.NotRequired[str]
    """
    AWS secret access key
    """

    session_token: typing_extensions.NotRequired[str]
    """
    AWS session token (required for STS only)
    """
