# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AgentThinkModelsV1Response,
        AgentThinkModelsV1ResponseModelsItem,
        AgentThinkModelsV1ResponseModelsItemId,
        AgentThinkModelsV1ResponseModelsItemOne,
        AgentThinkModelsV1ResponseModelsItemOneId,
        AgentThinkModelsV1ResponseModelsItemThree,
        AgentThinkModelsV1ResponseModelsItemTwo,
        AgentThinkModelsV1ResponseModelsItemTwoId,
        AgentThinkModelsV1ResponseModelsItemZero,
        AgentThinkModelsV1ResponseModelsItemZeroId,
        Anthropic,
        AnthropicThinkProviderModel,
        AwsBedrockThinkProvider,
        AwsBedrockThinkProviderCredentials,
        AwsBedrockThinkProviderCredentialsType,
        AwsBedrockThinkProviderModel,
        AwsPollySpeakProvider,
        AwsPollySpeakProviderCredentials,
        AwsPollySpeakProviderCredentialsType,
        AwsPollySpeakProviderEngine,
        AwsPollySpeakProviderVoice,
        BillingBreakdownV1Response,
        BillingBreakdownV1ResponseResolution,
        BillingBreakdownV1ResponseResultsItem,
        BillingBreakdownV1ResponseResultsItemGrouping,
        Cartesia,
        CartesiaSpeakProviderModelId,
        CartesiaSpeakProviderVoice,
        CreateKeyV1RequestOne,
        CreateKeyV1Response,
        CreateProjectDistributionCredentialsV1Response,
        CreateProjectDistributionCredentialsV1ResponseDistributionCredentials,
        CreateProjectDistributionCredentialsV1ResponseMember,
        CreateProjectInviteV1Response,
        Deepgram,
        DeepgramSpeakProviderModel,
        DeleteProjectInviteV1Response,
        DeleteProjectKeyV1Response,
        DeleteProjectMemberV1Response,
        DeleteProjectV1Response,
        ElevenLabsSpeakProvider,
        ElevenLabsSpeakProviderModelId,
        ErrorResponse,
        ErrorResponseLegacyError,
        ErrorResponseModernError,
        ErrorResponseTextError,
        GetModelV1Response,
        GetModelV1ResponseBatch,
        GetModelV1ResponseMetadata,
        GetModelV1ResponseMetadataMetadata,
        GetProjectBalanceV1Response,
        GetProjectDistributionCredentialsV1Response,
        GetProjectDistributionCredentialsV1ResponseDistributionCredentials,
        GetProjectDistributionCredentialsV1ResponseMember,
        GetProjectKeyV1Response,
        GetProjectKeyV1ResponseItem,
        GetProjectKeyV1ResponseItemMember,
        GetProjectKeyV1ResponseItemMemberApiKey,
        GetProjectRequestV1Response,
        GetProjectV1Response,
        Google,
        GoogleThinkProviderModel,
        GrantV1Response,
        Groq,
        LeaveProjectV1Response,
        ListBillingFieldsV1Response,
        ListBillingFieldsV1ResponseDeploymentsItem,
        ListModelsV1Response,
        ListModelsV1ResponseSttModels,
        ListModelsV1ResponseTtsModels,
        ListModelsV1ResponseTtsModelsMetadata,
        ListProjectBalancesV1Response,
        ListProjectBalancesV1ResponseBalancesItem,
        ListProjectDistributionCredentialsV1Response,
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem,
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials,
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember,
        ListProjectInvitesV1Response,
        ListProjectInvitesV1ResponseInvitesItem,
        ListProjectKeysV1Response,
        ListProjectKeysV1ResponseApiKeysItem,
        ListProjectKeysV1ResponseApiKeysItemApiKey,
        ListProjectKeysV1ResponseApiKeysItemMember,
        ListProjectMemberScopesV1Response,
        ListProjectMembersV1Response,
        ListProjectMembersV1ResponseMembersItem,
        ListProjectPurchasesV1Response,
        ListProjectPurchasesV1ResponseOrdersItem,
        ListProjectRequestsV1Response,
        ListProjectsV1Response,
        ListProjectsV1ResponseProjectsItem,
        ListenV1AcceptedResponse,
        ListenV1Callback,
        ListenV1CallbackMethod,
        ListenV1Channels,
        ListenV1DetectEntities,
        ListenV1Diarize,
        ListenV1Dictation,
        ListenV1Encoding,
        ListenV1Endpointing,
        ListenV1Extra,
        ListenV1InterimResults,
        ListenV1Keyterm,
        ListenV1Keywords,
        ListenV1Language,
        ListenV1MipOptOut,
        ListenV1Model,
        ListenV1Multichannel,
        ListenV1Numerals,
        ListenV1ProfanityFilter,
        ListenV1Punctuate,
        ListenV1Redact,
        ListenV1Replace,
        ListenV1RequestFile,
        ListenV1Response,
        ListenV1ResponseMetadata,
        ListenV1ResponseMetadataIntentsInfo,
        ListenV1ResponseMetadataSentimentInfo,
        ListenV1ResponseMetadataSummaryInfo,
        ListenV1ResponseMetadataTopicsInfo,
        ListenV1ResponseResults,
        ListenV1ResponseResultsChannels,
        ListenV1ResponseResultsChannelsItem,
        ListenV1ResponseResultsChannelsItemAlternativesItem,
        ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem,
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs,
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem,
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem,
        ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem,
        ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem,
        ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem,
        ListenV1ResponseResultsChannelsItemSearchItem,
        ListenV1ResponseResultsChannelsItemSearchItemHitsItem,
        ListenV1ResponseResultsSummary,
        ListenV1ResponseResultsUtterances,
        ListenV1ResponseResultsUtterancesItem,
        ListenV1ResponseResultsUtterancesItemWordsItem,
        ListenV1SampleRate,
        ListenV1Search,
        ListenV1SmartFormat,
        ListenV1Tag,
        ListenV1UtteranceEndMs,
        ListenV1VadEvents,
        ListenV1Version,
        ListenV2EagerEotThreshold,
        ListenV2Encoding,
        ListenV2EotThreshold,
        ListenV2EotTimeoutMs,
        ListenV2Keyterm,
        ListenV2MipOptOut,
        ListenV2Model,
        ListenV2SampleRate,
        ListenV2Tag,
        OpenAiSpeakProvider,
        OpenAiSpeakProviderModel,
        OpenAiSpeakProviderVoice,
        OpenAiThinkProvider,
        OpenAiThinkProviderModel,
        ProjectRequestResponse,
        ReadV1Request,
        ReadV1RequestText,
        ReadV1RequestUrl,
        ReadV1Response,
        ReadV1ResponseMetadata,
        ReadV1ResponseMetadataMetadata,
        ReadV1ResponseMetadataMetadataIntentsInfo,
        ReadV1ResponseMetadataMetadataSentimentInfo,
        ReadV1ResponseMetadataMetadataSummaryInfo,
        ReadV1ResponseMetadataMetadataTopicsInfo,
        ReadV1ResponseResults,
        ReadV1ResponseResultsSummary,
        ReadV1ResponseResultsSummaryResults,
        ReadV1ResponseResultsSummaryResultsSummary,
        SharedIntents,
        SharedIntentsResults,
        SharedIntentsResultsIntents,
        SharedIntentsResultsIntentsSegmentsItem,
        SharedIntentsResultsIntentsSegmentsItemIntentsItem,
        SharedSentiments,
        SharedSentimentsAverage,
        SharedSentimentsSegmentsItem,
        SharedTopics,
        SharedTopicsResults,
        SharedTopicsResultsTopics,
        SharedTopicsResultsTopicsSegmentsItem,
        SharedTopicsResultsTopicsSegmentsItemTopicsItem,
        SpeakSettingsV1,
        SpeakSettingsV1Endpoint,
        SpeakSettingsV1Provider,
        SpeakSettingsV1Provider_AwsPolly,
        SpeakSettingsV1Provider_Cartesia,
        SpeakSettingsV1Provider_Deepgram,
        SpeakSettingsV1Provider_ElevenLabs,
        SpeakSettingsV1Provider_OpenAi,
        SpeakV1Encoding,
        SpeakV1MipOptOut,
        SpeakV1Model,
        SpeakV1Response,
        SpeakV1SampleRate,
        ThinkSettingsV1,
        ThinkSettingsV1ContextLength,
        ThinkSettingsV1Endpoint,
        ThinkSettingsV1FunctionsItem,
        ThinkSettingsV1FunctionsItemEndpoint,
        ThinkSettingsV1Provider,
        ThinkSettingsV1Provider_Anthropic,
        ThinkSettingsV1Provider_AwsBedrock,
        ThinkSettingsV1Provider_Google,
        ThinkSettingsV1Provider_Groq,
        ThinkSettingsV1Provider_OpenAi,
        UpdateProjectMemberScopesV1Response,
        UpdateProjectV1Response,
        UsageBreakdownV1Response,
        UsageBreakdownV1ResponseResolution,
        UsageBreakdownV1ResponseResultsItem,
        UsageBreakdownV1ResponseResultsItemGrouping,
        UsageFieldsV1Response,
        UsageFieldsV1ResponseModelsItem,
        UsageV1Response,
        UsageV1ResponseResolution,
    )
    from .errors import BadRequestError
    from . import agent, auth, listen, manage, read, self_hosted, speak
    from .client import AsyncDeepgramClient, DeepgramClient
    from .environment import DeepgramClientEnvironment
    from .requests import (
        AgentThinkModelsV1ResponseModelsItemIdParams,
        AgentThinkModelsV1ResponseModelsItemOneParams,
        AgentThinkModelsV1ResponseModelsItemParams,
        AgentThinkModelsV1ResponseModelsItemThreeParams,
        AgentThinkModelsV1ResponseModelsItemTwoParams,
        AgentThinkModelsV1ResponseModelsItemZeroParams,
        AgentThinkModelsV1ResponseParams,
        AnthropicParams,
        AwsBedrockThinkProviderCredentialsParams,
        AwsBedrockThinkProviderParams,
        AwsPollySpeakProviderCredentialsParams,
        AwsPollySpeakProviderParams,
        BillingBreakdownV1ResponseParams,
        BillingBreakdownV1ResponseResolutionParams,
        BillingBreakdownV1ResponseResultsItemGroupingParams,
        BillingBreakdownV1ResponseResultsItemParams,
        CartesiaParams,
        CartesiaSpeakProviderVoiceParams,
        CreateKeyV1ResponseParams,
        CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams,
        CreateProjectDistributionCredentialsV1ResponseMemberParams,
        CreateProjectDistributionCredentialsV1ResponseParams,
        CreateProjectInviteV1ResponseParams,
        DeepgramParams,
        DeleteProjectInviteV1ResponseParams,
        DeleteProjectKeyV1ResponseParams,
        DeleteProjectMemberV1ResponseParams,
        DeleteProjectV1ResponseParams,
        ElevenLabsSpeakProviderParams,
        ErrorResponseLegacyErrorParams,
        ErrorResponseModernErrorParams,
        ErrorResponseParams,
        GetModelV1ResponseBatchParams,
        GetModelV1ResponseMetadataMetadataParams,
        GetModelV1ResponseMetadataParams,
        GetModelV1ResponseParams,
        GetProjectBalanceV1ResponseParams,
        GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams,
        GetProjectDistributionCredentialsV1ResponseMemberParams,
        GetProjectDistributionCredentialsV1ResponseParams,
        GetProjectKeyV1ResponseItemMemberApiKeyParams,
        GetProjectKeyV1ResponseItemMemberParams,
        GetProjectKeyV1ResponseItemParams,
        GetProjectKeyV1ResponseParams,
        GetProjectRequestV1ResponseParams,
        GetProjectV1ResponseParams,
        GoogleParams,
        GrantV1ResponseParams,
        GroqParams,
        LeaveProjectV1ResponseParams,
        ListBillingFieldsV1ResponseParams,
        ListModelsV1ResponseParams,
        ListModelsV1ResponseSttModelsParams,
        ListModelsV1ResponseTtsModelsMetadataParams,
        ListModelsV1ResponseTtsModelsParams,
        ListProjectBalancesV1ResponseBalancesItemParams,
        ListProjectBalancesV1ResponseParams,
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams,
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams,
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams,
        ListProjectDistributionCredentialsV1ResponseParams,
        ListProjectInvitesV1ResponseInvitesItemParams,
        ListProjectInvitesV1ResponseParams,
        ListProjectKeysV1ResponseApiKeysItemApiKeyParams,
        ListProjectKeysV1ResponseApiKeysItemMemberParams,
        ListProjectKeysV1ResponseApiKeysItemParams,
        ListProjectKeysV1ResponseParams,
        ListProjectMemberScopesV1ResponseParams,
        ListProjectMembersV1ResponseMembersItemParams,
        ListProjectMembersV1ResponseParams,
        ListProjectPurchasesV1ResponseOrdersItemParams,
        ListProjectPurchasesV1ResponseParams,
        ListProjectRequestsV1ResponseParams,
        ListProjectsV1ResponseParams,
        ListProjectsV1ResponseProjectsItemParams,
        ListenV1AcceptedResponseParams,
        ListenV1ResponseMetadataIntentsInfoParams,
        ListenV1ResponseMetadataParams,
        ListenV1ResponseMetadataSentimentInfoParams,
        ListenV1ResponseMetadataSummaryInfoParams,
        ListenV1ResponseMetadataTopicsInfoParams,
        ListenV1ResponseParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams,
        ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams,
        ListenV1ResponseResultsChannelsItemParams,
        ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams,
        ListenV1ResponseResultsChannelsItemSearchItemParams,
        ListenV1ResponseResultsChannelsParams,
        ListenV1ResponseResultsParams,
        ListenV1ResponseResultsSummaryParams,
        ListenV1ResponseResultsUtterancesItemParams,
        ListenV1ResponseResultsUtterancesItemWordsItemParams,
        ListenV1ResponseResultsUtterancesParams,
        ListenV2KeytermParams,
        OpenAiSpeakProviderParams,
        OpenAiThinkProviderParams,
        ProjectRequestResponseParams,
        ReadV1RequestParams,
        ReadV1RequestTextParams,
        ReadV1RequestUrlParams,
        ReadV1ResponseMetadataMetadataIntentsInfoParams,
        ReadV1ResponseMetadataMetadataParams,
        ReadV1ResponseMetadataMetadataSentimentInfoParams,
        ReadV1ResponseMetadataMetadataSummaryInfoParams,
        ReadV1ResponseMetadataMetadataTopicsInfoParams,
        ReadV1ResponseMetadataParams,
        ReadV1ResponseParams,
        ReadV1ResponseResultsParams,
        ReadV1ResponseResultsSummaryParams,
        ReadV1ResponseResultsSummaryResultsParams,
        ReadV1ResponseResultsSummaryResultsSummaryParams,
        SharedIntentsParams,
        SharedIntentsResultsIntentsParams,
        SharedIntentsResultsIntentsSegmentsItemIntentsItemParams,
        SharedIntentsResultsIntentsSegmentsItemParams,
        SharedIntentsResultsParams,
        SharedSentimentsAverageParams,
        SharedSentimentsParams,
        SharedSentimentsSegmentsItemParams,
        SharedTopicsParams,
        SharedTopicsResultsParams,
        SharedTopicsResultsTopicsParams,
        SharedTopicsResultsTopicsSegmentsItemParams,
        SharedTopicsResultsTopicsSegmentsItemTopicsItemParams,
        SpeakSettingsV1EndpointParams,
        SpeakSettingsV1Params,
        SpeakSettingsV1ProviderParams,
        SpeakSettingsV1Provider_AwsPollyParams,
        SpeakSettingsV1Provider_CartesiaParams,
        SpeakSettingsV1Provider_DeepgramParams,
        SpeakSettingsV1Provider_ElevenLabsParams,
        SpeakSettingsV1Provider_OpenAiParams,
        ThinkSettingsV1ContextLengthParams,
        ThinkSettingsV1EndpointParams,
        ThinkSettingsV1FunctionsItemEndpointParams,
        ThinkSettingsV1FunctionsItemParams,
        ThinkSettingsV1Params,
        ThinkSettingsV1ProviderParams,
        ThinkSettingsV1Provider_AnthropicParams,
        ThinkSettingsV1Provider_AwsBedrockParams,
        ThinkSettingsV1Provider_GoogleParams,
        ThinkSettingsV1Provider_GroqParams,
        ThinkSettingsV1Provider_OpenAiParams,
        UpdateProjectMemberScopesV1ResponseParams,
        UpdateProjectV1ResponseParams,
        UsageBreakdownV1ResponseParams,
        UsageBreakdownV1ResponseResolutionParams,
        UsageBreakdownV1ResponseResultsItemGroupingParams,
        UsageBreakdownV1ResponseResultsItemParams,
        UsageFieldsV1ResponseModelsItemParams,
        UsageFieldsV1ResponseParams,
        UsageV1ResponseParams,
        UsageV1ResponseResolutionParams,
    )
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "AgentThinkModelsV1Response": ".types",
    "AgentThinkModelsV1ResponseModelsItem": ".types",
    "AgentThinkModelsV1ResponseModelsItemId": ".types",
    "AgentThinkModelsV1ResponseModelsItemIdParams": ".requests",
    "AgentThinkModelsV1ResponseModelsItemOne": ".types",
    "AgentThinkModelsV1ResponseModelsItemOneId": ".types",
    "AgentThinkModelsV1ResponseModelsItemOneParams": ".requests",
    "AgentThinkModelsV1ResponseModelsItemParams": ".requests",
    "AgentThinkModelsV1ResponseModelsItemThree": ".types",
    "AgentThinkModelsV1ResponseModelsItemThreeParams": ".requests",
    "AgentThinkModelsV1ResponseModelsItemTwo": ".types",
    "AgentThinkModelsV1ResponseModelsItemTwoId": ".types",
    "AgentThinkModelsV1ResponseModelsItemTwoParams": ".requests",
    "AgentThinkModelsV1ResponseModelsItemZero": ".types",
    "AgentThinkModelsV1ResponseModelsItemZeroId": ".types",
    "AgentThinkModelsV1ResponseModelsItemZeroParams": ".requests",
    "AgentThinkModelsV1ResponseParams": ".requests",
    "Anthropic": ".types",
    "AnthropicParams": ".requests",
    "AnthropicThinkProviderModel": ".types",
    "AsyncDeepgramClient": ".client",
    "AwsBedrockThinkProvider": ".types",
    "AwsBedrockThinkProviderCredentials": ".types",
    "AwsBedrockThinkProviderCredentialsParams": ".requests",
    "AwsBedrockThinkProviderCredentialsType": ".types",
    "AwsBedrockThinkProviderModel": ".types",
    "AwsBedrockThinkProviderParams": ".requests",
    "AwsPollySpeakProvider": ".types",
    "AwsPollySpeakProviderCredentials": ".types",
    "AwsPollySpeakProviderCredentialsParams": ".requests",
    "AwsPollySpeakProviderCredentialsType": ".types",
    "AwsPollySpeakProviderEngine": ".types",
    "AwsPollySpeakProviderParams": ".requests",
    "AwsPollySpeakProviderVoice": ".types",
    "BadRequestError": ".errors",
    "BillingBreakdownV1Response": ".types",
    "BillingBreakdownV1ResponseParams": ".requests",
    "BillingBreakdownV1ResponseResolution": ".types",
    "BillingBreakdownV1ResponseResolutionParams": ".requests",
    "BillingBreakdownV1ResponseResultsItem": ".types",
    "BillingBreakdownV1ResponseResultsItemGrouping": ".types",
    "BillingBreakdownV1ResponseResultsItemGroupingParams": ".requests",
    "BillingBreakdownV1ResponseResultsItemParams": ".requests",
    "Cartesia": ".types",
    "CartesiaParams": ".requests",
    "CartesiaSpeakProviderModelId": ".types",
    "CartesiaSpeakProviderVoice": ".types",
    "CartesiaSpeakProviderVoiceParams": ".requests",
    "CreateKeyV1RequestOne": ".types",
    "CreateKeyV1Response": ".types",
    "CreateKeyV1ResponseParams": ".requests",
    "CreateProjectDistributionCredentialsV1Response": ".types",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentials": ".types",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams": ".requests",
    "CreateProjectDistributionCredentialsV1ResponseMember": ".types",
    "CreateProjectDistributionCredentialsV1ResponseMemberParams": ".requests",
    "CreateProjectDistributionCredentialsV1ResponseParams": ".requests",
    "CreateProjectInviteV1Response": ".types",
    "CreateProjectInviteV1ResponseParams": ".requests",
    "Deepgram": ".types",
    "DeepgramClient": ".client",
    "DeepgramClientEnvironment": ".environment",
    "DeepgramParams": ".requests",
    "DeepgramSpeakProviderModel": ".types",
    "DeleteProjectInviteV1Response": ".types",
    "DeleteProjectInviteV1ResponseParams": ".requests",
    "DeleteProjectKeyV1Response": ".types",
    "DeleteProjectKeyV1ResponseParams": ".requests",
    "DeleteProjectMemberV1Response": ".types",
    "DeleteProjectMemberV1ResponseParams": ".requests",
    "DeleteProjectV1Response": ".types",
    "DeleteProjectV1ResponseParams": ".requests",
    "ElevenLabsSpeakProvider": ".types",
    "ElevenLabsSpeakProviderModelId": ".types",
    "ElevenLabsSpeakProviderParams": ".requests",
    "ErrorResponse": ".types",
    "ErrorResponseLegacyError": ".types",
    "ErrorResponseLegacyErrorParams": ".requests",
    "ErrorResponseModernError": ".types",
    "ErrorResponseModernErrorParams": ".requests",
    "ErrorResponseParams": ".requests",
    "ErrorResponseTextError": ".types",
    "GetModelV1Response": ".types",
    "GetModelV1ResponseBatch": ".types",
    "GetModelV1ResponseBatchParams": ".requests",
    "GetModelV1ResponseMetadata": ".types",
    "GetModelV1ResponseMetadataMetadata": ".types",
    "GetModelV1ResponseMetadataMetadataParams": ".requests",
    "GetModelV1ResponseMetadataParams": ".requests",
    "GetModelV1ResponseParams": ".requests",
    "GetProjectBalanceV1Response": ".types",
    "GetProjectBalanceV1ResponseParams": ".requests",
    "GetProjectDistributionCredentialsV1Response": ".types",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentials": ".types",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams": ".requests",
    "GetProjectDistributionCredentialsV1ResponseMember": ".types",
    "GetProjectDistributionCredentialsV1ResponseMemberParams": ".requests",
    "GetProjectDistributionCredentialsV1ResponseParams": ".requests",
    "GetProjectKeyV1Response": ".types",
    "GetProjectKeyV1ResponseItem": ".types",
    "GetProjectKeyV1ResponseItemMember": ".types",
    "GetProjectKeyV1ResponseItemMemberApiKey": ".types",
    "GetProjectKeyV1ResponseItemMemberApiKeyParams": ".requests",
    "GetProjectKeyV1ResponseItemMemberParams": ".requests",
    "GetProjectKeyV1ResponseItemParams": ".requests",
    "GetProjectKeyV1ResponseParams": ".requests",
    "GetProjectRequestV1Response": ".types",
    "GetProjectRequestV1ResponseParams": ".requests",
    "GetProjectV1Response": ".types",
    "GetProjectV1ResponseParams": ".requests",
    "Google": ".types",
    "GoogleParams": ".requests",
    "GoogleThinkProviderModel": ".types",
    "GrantV1Response": ".types",
    "GrantV1ResponseParams": ".requests",
    "Groq": ".types",
    "GroqParams": ".requests",
    "LeaveProjectV1Response": ".types",
    "LeaveProjectV1ResponseParams": ".requests",
    "ListBillingFieldsV1Response": ".types",
    "ListBillingFieldsV1ResponseDeploymentsItem": ".types",
    "ListBillingFieldsV1ResponseParams": ".requests",
    "ListModelsV1Response": ".types",
    "ListModelsV1ResponseParams": ".requests",
    "ListModelsV1ResponseSttModels": ".types",
    "ListModelsV1ResponseSttModelsParams": ".requests",
    "ListModelsV1ResponseTtsModels": ".types",
    "ListModelsV1ResponseTtsModelsMetadata": ".types",
    "ListModelsV1ResponseTtsModelsMetadataParams": ".requests",
    "ListModelsV1ResponseTtsModelsParams": ".requests",
    "ListProjectBalancesV1Response": ".types",
    "ListProjectBalancesV1ResponseBalancesItem": ".types",
    "ListProjectBalancesV1ResponseBalancesItemParams": ".requests",
    "ListProjectBalancesV1ResponseParams": ".requests",
    "ListProjectDistributionCredentialsV1Response": ".types",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem": ".types",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials": ".types",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams": ".requests",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember": ".types",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams": ".requests",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams": ".requests",
    "ListProjectDistributionCredentialsV1ResponseParams": ".requests",
    "ListProjectInvitesV1Response": ".types",
    "ListProjectInvitesV1ResponseInvitesItem": ".types",
    "ListProjectInvitesV1ResponseInvitesItemParams": ".requests",
    "ListProjectInvitesV1ResponseParams": ".requests",
    "ListProjectKeysV1Response": ".types",
    "ListProjectKeysV1ResponseApiKeysItem": ".types",
    "ListProjectKeysV1ResponseApiKeysItemApiKey": ".types",
    "ListProjectKeysV1ResponseApiKeysItemApiKeyParams": ".requests",
    "ListProjectKeysV1ResponseApiKeysItemMember": ".types",
    "ListProjectKeysV1ResponseApiKeysItemMemberParams": ".requests",
    "ListProjectKeysV1ResponseApiKeysItemParams": ".requests",
    "ListProjectKeysV1ResponseParams": ".requests",
    "ListProjectMemberScopesV1Response": ".types",
    "ListProjectMemberScopesV1ResponseParams": ".requests",
    "ListProjectMembersV1Response": ".types",
    "ListProjectMembersV1ResponseMembersItem": ".types",
    "ListProjectMembersV1ResponseMembersItemParams": ".requests",
    "ListProjectMembersV1ResponseParams": ".requests",
    "ListProjectPurchasesV1Response": ".types",
    "ListProjectPurchasesV1ResponseOrdersItem": ".types",
    "ListProjectPurchasesV1ResponseOrdersItemParams": ".requests",
    "ListProjectPurchasesV1ResponseParams": ".requests",
    "ListProjectRequestsV1Response": ".types",
    "ListProjectRequestsV1ResponseParams": ".requests",
    "ListProjectsV1Response": ".types",
    "ListProjectsV1ResponseParams": ".requests",
    "ListProjectsV1ResponseProjectsItem": ".types",
    "ListProjectsV1ResponseProjectsItemParams": ".requests",
    "ListenV1AcceptedResponse": ".types",
    "ListenV1AcceptedResponseParams": ".requests",
    "ListenV1Callback": ".types",
    "ListenV1CallbackMethod": ".types",
    "ListenV1Channels": ".types",
    "ListenV1DetectEntities": ".types",
    "ListenV1Diarize": ".types",
    "ListenV1Dictation": ".types",
    "ListenV1Encoding": ".types",
    "ListenV1Endpointing": ".types",
    "ListenV1Extra": ".types",
    "ListenV1InterimResults": ".types",
    "ListenV1Keyterm": ".types",
    "ListenV1Keywords": ".types",
    "ListenV1Language": ".types",
    "ListenV1MipOptOut": ".types",
    "ListenV1Model": ".types",
    "ListenV1Multichannel": ".types",
    "ListenV1Numerals": ".types",
    "ListenV1ProfanityFilter": ".types",
    "ListenV1Punctuate": ".types",
    "ListenV1Redact": ".types",
    "ListenV1Replace": ".types",
    "ListenV1RequestFile": ".types",
    "ListenV1Response": ".types",
    "ListenV1ResponseMetadata": ".types",
    "ListenV1ResponseMetadataIntentsInfo": ".types",
    "ListenV1ResponseMetadataIntentsInfoParams": ".requests",
    "ListenV1ResponseMetadataParams": ".requests",
    "ListenV1ResponseMetadataSentimentInfo": ".types",
    "ListenV1ResponseMetadataSentimentInfoParams": ".requests",
    "ListenV1ResponseMetadataSummaryInfo": ".types",
    "ListenV1ResponseMetadataSummaryInfoParams": ".requests",
    "ListenV1ResponseMetadataTopicsInfo": ".types",
    "ListenV1ResponseMetadataTopicsInfoParams": ".requests",
    "ListenV1ResponseParams": ".requests",
    "ListenV1ResponseResults": ".types",
    "ListenV1ResponseResultsChannels": ".types",
    "ListenV1ResponseResultsChannelsItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams": ".requests",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem": ".types",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemSearchItem": ".types",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItem": ".types",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams": ".requests",
    "ListenV1ResponseResultsChannelsItemSearchItemParams": ".requests",
    "ListenV1ResponseResultsChannelsParams": ".requests",
    "ListenV1ResponseResultsParams": ".requests",
    "ListenV1ResponseResultsSummary": ".types",
    "ListenV1ResponseResultsSummaryParams": ".requests",
    "ListenV1ResponseResultsUtterances": ".types",
    "ListenV1ResponseResultsUtterancesItem": ".types",
    "ListenV1ResponseResultsUtterancesItemParams": ".requests",
    "ListenV1ResponseResultsUtterancesItemWordsItem": ".types",
    "ListenV1ResponseResultsUtterancesItemWordsItemParams": ".requests",
    "ListenV1ResponseResultsUtterancesParams": ".requests",
    "ListenV1SampleRate": ".types",
    "ListenV1Search": ".types",
    "ListenV1SmartFormat": ".types",
    "ListenV1Tag": ".types",
    "ListenV1UtteranceEndMs": ".types",
    "ListenV1VadEvents": ".types",
    "ListenV1Version": ".types",
    "ListenV2EagerEotThreshold": ".types",
    "ListenV2Encoding": ".types",
    "ListenV2EotThreshold": ".types",
    "ListenV2EotTimeoutMs": ".types",
    "ListenV2Keyterm": ".types",
    "ListenV2KeytermParams": ".requests",
    "ListenV2MipOptOut": ".types",
    "ListenV2Model": ".types",
    "ListenV2SampleRate": ".types",
    "ListenV2Tag": ".types",
    "OpenAiSpeakProvider": ".types",
    "OpenAiSpeakProviderModel": ".types",
    "OpenAiSpeakProviderParams": ".requests",
    "OpenAiSpeakProviderVoice": ".types",
    "OpenAiThinkProvider": ".types",
    "OpenAiThinkProviderModel": ".types",
    "OpenAiThinkProviderParams": ".requests",
    "ProjectRequestResponse": ".types",
    "ProjectRequestResponseParams": ".requests",
    "ReadV1Request": ".types",
    "ReadV1RequestParams": ".requests",
    "ReadV1RequestText": ".types",
    "ReadV1RequestTextParams": ".requests",
    "ReadV1RequestUrl": ".types",
    "ReadV1RequestUrlParams": ".requests",
    "ReadV1Response": ".types",
    "ReadV1ResponseMetadata": ".types",
    "ReadV1ResponseMetadataMetadata": ".types",
    "ReadV1ResponseMetadataMetadataIntentsInfo": ".types",
    "ReadV1ResponseMetadataMetadataIntentsInfoParams": ".requests",
    "ReadV1ResponseMetadataMetadataParams": ".requests",
    "ReadV1ResponseMetadataMetadataSentimentInfo": ".types",
    "ReadV1ResponseMetadataMetadataSentimentInfoParams": ".requests",
    "ReadV1ResponseMetadataMetadataSummaryInfo": ".types",
    "ReadV1ResponseMetadataMetadataSummaryInfoParams": ".requests",
    "ReadV1ResponseMetadataMetadataTopicsInfo": ".types",
    "ReadV1ResponseMetadataMetadataTopicsInfoParams": ".requests",
    "ReadV1ResponseMetadataParams": ".requests",
    "ReadV1ResponseParams": ".requests",
    "ReadV1ResponseResults": ".types",
    "ReadV1ResponseResultsParams": ".requests",
    "ReadV1ResponseResultsSummary": ".types",
    "ReadV1ResponseResultsSummaryParams": ".requests",
    "ReadV1ResponseResultsSummaryResults": ".types",
    "ReadV1ResponseResultsSummaryResultsParams": ".requests",
    "ReadV1ResponseResultsSummaryResultsSummary": ".types",
    "ReadV1ResponseResultsSummaryResultsSummaryParams": ".requests",
    "SharedIntents": ".types",
    "SharedIntentsParams": ".requests",
    "SharedIntentsResults": ".types",
    "SharedIntentsResultsIntents": ".types",
    "SharedIntentsResultsIntentsParams": ".requests",
    "SharedIntentsResultsIntentsSegmentsItem": ".types",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItem": ".types",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItemParams": ".requests",
    "SharedIntentsResultsIntentsSegmentsItemParams": ".requests",
    "SharedIntentsResultsParams": ".requests",
    "SharedSentiments": ".types",
    "SharedSentimentsAverage": ".types",
    "SharedSentimentsAverageParams": ".requests",
    "SharedSentimentsParams": ".requests",
    "SharedSentimentsSegmentsItem": ".types",
    "SharedSentimentsSegmentsItemParams": ".requests",
    "SharedTopics": ".types",
    "SharedTopicsParams": ".requests",
    "SharedTopicsResults": ".types",
    "SharedTopicsResultsParams": ".requests",
    "SharedTopicsResultsTopics": ".types",
    "SharedTopicsResultsTopicsParams": ".requests",
    "SharedTopicsResultsTopicsSegmentsItem": ".types",
    "SharedTopicsResultsTopicsSegmentsItemParams": ".requests",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItem": ".types",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItemParams": ".requests",
    "SpeakSettingsV1": ".types",
    "SpeakSettingsV1Endpoint": ".types",
    "SpeakSettingsV1EndpointParams": ".requests",
    "SpeakSettingsV1Params": ".requests",
    "SpeakSettingsV1Provider": ".types",
    "SpeakSettingsV1ProviderParams": ".requests",
    "SpeakSettingsV1Provider_AwsPolly": ".types",
    "SpeakSettingsV1Provider_AwsPollyParams": ".requests",
    "SpeakSettingsV1Provider_Cartesia": ".types",
    "SpeakSettingsV1Provider_CartesiaParams": ".requests",
    "SpeakSettingsV1Provider_Deepgram": ".types",
    "SpeakSettingsV1Provider_DeepgramParams": ".requests",
    "SpeakSettingsV1Provider_ElevenLabs": ".types",
    "SpeakSettingsV1Provider_ElevenLabsParams": ".requests",
    "SpeakSettingsV1Provider_OpenAi": ".types",
    "SpeakSettingsV1Provider_OpenAiParams": ".requests",
    "SpeakV1Encoding": ".types",
    "SpeakV1MipOptOut": ".types",
    "SpeakV1Model": ".types",
    "SpeakV1Response": ".types",
    "SpeakV1SampleRate": ".types",
    "ThinkSettingsV1": ".types",
    "ThinkSettingsV1ContextLength": ".types",
    "ThinkSettingsV1ContextLengthParams": ".requests",
    "ThinkSettingsV1Endpoint": ".types",
    "ThinkSettingsV1EndpointParams": ".requests",
    "ThinkSettingsV1FunctionsItem": ".types",
    "ThinkSettingsV1FunctionsItemEndpoint": ".types",
    "ThinkSettingsV1FunctionsItemEndpointParams": ".requests",
    "ThinkSettingsV1FunctionsItemParams": ".requests",
    "ThinkSettingsV1Params": ".requests",
    "ThinkSettingsV1Provider": ".types",
    "ThinkSettingsV1ProviderParams": ".requests",
    "ThinkSettingsV1Provider_Anthropic": ".types",
    "ThinkSettingsV1Provider_AnthropicParams": ".requests",
    "ThinkSettingsV1Provider_AwsBedrock": ".types",
    "ThinkSettingsV1Provider_AwsBedrockParams": ".requests",
    "ThinkSettingsV1Provider_Google": ".types",
    "ThinkSettingsV1Provider_GoogleParams": ".requests",
    "ThinkSettingsV1Provider_Groq": ".types",
    "ThinkSettingsV1Provider_GroqParams": ".requests",
    "ThinkSettingsV1Provider_OpenAi": ".types",
    "ThinkSettingsV1Provider_OpenAiParams": ".requests",
    "UpdateProjectMemberScopesV1Response": ".types",
    "UpdateProjectMemberScopesV1ResponseParams": ".requests",
    "UpdateProjectV1Response": ".types",
    "UpdateProjectV1ResponseParams": ".requests",
    "UsageBreakdownV1Response": ".types",
    "UsageBreakdownV1ResponseParams": ".requests",
    "UsageBreakdownV1ResponseResolution": ".types",
    "UsageBreakdownV1ResponseResolutionParams": ".requests",
    "UsageBreakdownV1ResponseResultsItem": ".types",
    "UsageBreakdownV1ResponseResultsItemGrouping": ".types",
    "UsageBreakdownV1ResponseResultsItemGroupingParams": ".requests",
    "UsageBreakdownV1ResponseResultsItemParams": ".requests",
    "UsageFieldsV1Response": ".types",
    "UsageFieldsV1ResponseModelsItem": ".types",
    "UsageFieldsV1ResponseModelsItemParams": ".requests",
    "UsageFieldsV1ResponseParams": ".requests",
    "UsageV1Response": ".types",
    "UsageV1ResponseParams": ".requests",
    "UsageV1ResponseResolution": ".types",
    "UsageV1ResponseResolutionParams": ".requests",
    "__version__": ".version",
    "agent": ".agent",
    "auth": ".auth",
    "listen": ".listen",
    "manage": ".manage",
    "read": ".read",
    "self_hosted": ".self_hosted",
    "speak": ".speak",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentThinkModelsV1Response",
    "AgentThinkModelsV1ResponseModelsItem",
    "AgentThinkModelsV1ResponseModelsItemId",
    "AgentThinkModelsV1ResponseModelsItemIdParams",
    "AgentThinkModelsV1ResponseModelsItemOne",
    "AgentThinkModelsV1ResponseModelsItemOneId",
    "AgentThinkModelsV1ResponseModelsItemOneParams",
    "AgentThinkModelsV1ResponseModelsItemParams",
    "AgentThinkModelsV1ResponseModelsItemThree",
    "AgentThinkModelsV1ResponseModelsItemThreeParams",
    "AgentThinkModelsV1ResponseModelsItemTwo",
    "AgentThinkModelsV1ResponseModelsItemTwoId",
    "AgentThinkModelsV1ResponseModelsItemTwoParams",
    "AgentThinkModelsV1ResponseModelsItemZero",
    "AgentThinkModelsV1ResponseModelsItemZeroId",
    "AgentThinkModelsV1ResponseModelsItemZeroParams",
    "AgentThinkModelsV1ResponseParams",
    "Anthropic",
    "AnthropicParams",
    "AnthropicThinkProviderModel",
    "AsyncDeepgramClient",
    "AwsBedrockThinkProvider",
    "AwsBedrockThinkProviderCredentials",
    "AwsBedrockThinkProviderCredentialsParams",
    "AwsBedrockThinkProviderCredentialsType",
    "AwsBedrockThinkProviderModel",
    "AwsBedrockThinkProviderParams",
    "AwsPollySpeakProvider",
    "AwsPollySpeakProviderCredentials",
    "AwsPollySpeakProviderCredentialsParams",
    "AwsPollySpeakProviderCredentialsType",
    "AwsPollySpeakProviderEngine",
    "AwsPollySpeakProviderParams",
    "AwsPollySpeakProviderVoice",
    "BadRequestError",
    "BillingBreakdownV1Response",
    "BillingBreakdownV1ResponseParams",
    "BillingBreakdownV1ResponseResolution",
    "BillingBreakdownV1ResponseResolutionParams",
    "BillingBreakdownV1ResponseResultsItem",
    "BillingBreakdownV1ResponseResultsItemGrouping",
    "BillingBreakdownV1ResponseResultsItemGroupingParams",
    "BillingBreakdownV1ResponseResultsItemParams",
    "Cartesia",
    "CartesiaParams",
    "CartesiaSpeakProviderModelId",
    "CartesiaSpeakProviderVoice",
    "CartesiaSpeakProviderVoiceParams",
    "CreateKeyV1RequestOne",
    "CreateKeyV1Response",
    "CreateKeyV1ResponseParams",
    "CreateProjectDistributionCredentialsV1Response",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentials",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams",
    "CreateProjectDistributionCredentialsV1ResponseMember",
    "CreateProjectDistributionCredentialsV1ResponseMemberParams",
    "CreateProjectDistributionCredentialsV1ResponseParams",
    "CreateProjectInviteV1Response",
    "CreateProjectInviteV1ResponseParams",
    "Deepgram",
    "DeepgramClient",
    "DeepgramClientEnvironment",
    "DeepgramParams",
    "DeepgramSpeakProviderModel",
    "DeleteProjectInviteV1Response",
    "DeleteProjectInviteV1ResponseParams",
    "DeleteProjectKeyV1Response",
    "DeleteProjectKeyV1ResponseParams",
    "DeleteProjectMemberV1Response",
    "DeleteProjectMemberV1ResponseParams",
    "DeleteProjectV1Response",
    "DeleteProjectV1ResponseParams",
    "ElevenLabsSpeakProvider",
    "ElevenLabsSpeakProviderModelId",
    "ElevenLabsSpeakProviderParams",
    "ErrorResponse",
    "ErrorResponseLegacyError",
    "ErrorResponseLegacyErrorParams",
    "ErrorResponseModernError",
    "ErrorResponseModernErrorParams",
    "ErrorResponseParams",
    "ErrorResponseTextError",
    "GetModelV1Response",
    "GetModelV1ResponseBatch",
    "GetModelV1ResponseBatchParams",
    "GetModelV1ResponseMetadata",
    "GetModelV1ResponseMetadataMetadata",
    "GetModelV1ResponseMetadataMetadataParams",
    "GetModelV1ResponseMetadataParams",
    "GetModelV1ResponseParams",
    "GetProjectBalanceV1Response",
    "GetProjectBalanceV1ResponseParams",
    "GetProjectDistributionCredentialsV1Response",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentials",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams",
    "GetProjectDistributionCredentialsV1ResponseMember",
    "GetProjectDistributionCredentialsV1ResponseMemberParams",
    "GetProjectDistributionCredentialsV1ResponseParams",
    "GetProjectKeyV1Response",
    "GetProjectKeyV1ResponseItem",
    "GetProjectKeyV1ResponseItemMember",
    "GetProjectKeyV1ResponseItemMemberApiKey",
    "GetProjectKeyV1ResponseItemMemberApiKeyParams",
    "GetProjectKeyV1ResponseItemMemberParams",
    "GetProjectKeyV1ResponseItemParams",
    "GetProjectKeyV1ResponseParams",
    "GetProjectRequestV1Response",
    "GetProjectRequestV1ResponseParams",
    "GetProjectV1Response",
    "GetProjectV1ResponseParams",
    "Google",
    "GoogleParams",
    "GoogleThinkProviderModel",
    "GrantV1Response",
    "GrantV1ResponseParams",
    "Groq",
    "GroqParams",
    "LeaveProjectV1Response",
    "LeaveProjectV1ResponseParams",
    "ListBillingFieldsV1Response",
    "ListBillingFieldsV1ResponseDeploymentsItem",
    "ListBillingFieldsV1ResponseParams",
    "ListModelsV1Response",
    "ListModelsV1ResponseParams",
    "ListModelsV1ResponseSttModels",
    "ListModelsV1ResponseSttModelsParams",
    "ListModelsV1ResponseTtsModels",
    "ListModelsV1ResponseTtsModelsMetadata",
    "ListModelsV1ResponseTtsModelsMetadataParams",
    "ListModelsV1ResponseTtsModelsParams",
    "ListProjectBalancesV1Response",
    "ListProjectBalancesV1ResponseBalancesItem",
    "ListProjectBalancesV1ResponseBalancesItemParams",
    "ListProjectBalancesV1ResponseParams",
    "ListProjectDistributionCredentialsV1Response",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams",
    "ListProjectDistributionCredentialsV1ResponseParams",
    "ListProjectInvitesV1Response",
    "ListProjectInvitesV1ResponseInvitesItem",
    "ListProjectInvitesV1ResponseInvitesItemParams",
    "ListProjectInvitesV1ResponseParams",
    "ListProjectKeysV1Response",
    "ListProjectKeysV1ResponseApiKeysItem",
    "ListProjectKeysV1ResponseApiKeysItemApiKey",
    "ListProjectKeysV1ResponseApiKeysItemApiKeyParams",
    "ListProjectKeysV1ResponseApiKeysItemMember",
    "ListProjectKeysV1ResponseApiKeysItemMemberParams",
    "ListProjectKeysV1ResponseApiKeysItemParams",
    "ListProjectKeysV1ResponseParams",
    "ListProjectMemberScopesV1Response",
    "ListProjectMemberScopesV1ResponseParams",
    "ListProjectMembersV1Response",
    "ListProjectMembersV1ResponseMembersItem",
    "ListProjectMembersV1ResponseMembersItemParams",
    "ListProjectMembersV1ResponseParams",
    "ListProjectPurchasesV1Response",
    "ListProjectPurchasesV1ResponseOrdersItem",
    "ListProjectPurchasesV1ResponseOrdersItemParams",
    "ListProjectPurchasesV1ResponseParams",
    "ListProjectRequestsV1Response",
    "ListProjectRequestsV1ResponseParams",
    "ListProjectsV1Response",
    "ListProjectsV1ResponseParams",
    "ListProjectsV1ResponseProjectsItem",
    "ListProjectsV1ResponseProjectsItemParams",
    "ListenV1AcceptedResponse",
    "ListenV1AcceptedResponseParams",
    "ListenV1Callback",
    "ListenV1CallbackMethod",
    "ListenV1Channels",
    "ListenV1DetectEntities",
    "ListenV1Diarize",
    "ListenV1Dictation",
    "ListenV1Encoding",
    "ListenV1Endpointing",
    "ListenV1Extra",
    "ListenV1InterimResults",
    "ListenV1Keyterm",
    "ListenV1Keywords",
    "ListenV1Language",
    "ListenV1MipOptOut",
    "ListenV1Model",
    "ListenV1Multichannel",
    "ListenV1Numerals",
    "ListenV1ProfanityFilter",
    "ListenV1Punctuate",
    "ListenV1Redact",
    "ListenV1Replace",
    "ListenV1RequestFile",
    "ListenV1Response",
    "ListenV1ResponseMetadata",
    "ListenV1ResponseMetadataIntentsInfo",
    "ListenV1ResponseMetadataIntentsInfoParams",
    "ListenV1ResponseMetadataParams",
    "ListenV1ResponseMetadataSentimentInfo",
    "ListenV1ResponseMetadataSentimentInfoParams",
    "ListenV1ResponseMetadataSummaryInfo",
    "ListenV1ResponseMetadataSummaryInfoParams",
    "ListenV1ResponseMetadataTopicsInfo",
    "ListenV1ResponseMetadataTopicsInfoParams",
    "ListenV1ResponseParams",
    "ListenV1ResponseResults",
    "ListenV1ResponseResultsChannels",
    "ListenV1ResponseResultsChannelsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams",
    "ListenV1ResponseResultsChannelsItemParams",
    "ListenV1ResponseResultsChannelsItemSearchItem",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItem",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams",
    "ListenV1ResponseResultsChannelsItemSearchItemParams",
    "ListenV1ResponseResultsChannelsParams",
    "ListenV1ResponseResultsParams",
    "ListenV1ResponseResultsSummary",
    "ListenV1ResponseResultsSummaryParams",
    "ListenV1ResponseResultsUtterances",
    "ListenV1ResponseResultsUtterancesItem",
    "ListenV1ResponseResultsUtterancesItemParams",
    "ListenV1ResponseResultsUtterancesItemWordsItem",
    "ListenV1ResponseResultsUtterancesItemWordsItemParams",
    "ListenV1ResponseResultsUtterancesParams",
    "ListenV1SampleRate",
    "ListenV1Search",
    "ListenV1SmartFormat",
    "ListenV1Tag",
    "ListenV1UtteranceEndMs",
    "ListenV1VadEvents",
    "ListenV1Version",
    "ListenV2EagerEotThreshold",
    "ListenV2Encoding",
    "ListenV2EotThreshold",
    "ListenV2EotTimeoutMs",
    "ListenV2Keyterm",
    "ListenV2KeytermParams",
    "ListenV2MipOptOut",
    "ListenV2Model",
    "ListenV2SampleRate",
    "ListenV2Tag",
    "OpenAiSpeakProvider",
    "OpenAiSpeakProviderModel",
    "OpenAiSpeakProviderParams",
    "OpenAiSpeakProviderVoice",
    "OpenAiThinkProvider",
    "OpenAiThinkProviderModel",
    "OpenAiThinkProviderParams",
    "ProjectRequestResponse",
    "ProjectRequestResponseParams",
    "ReadV1Request",
    "ReadV1RequestParams",
    "ReadV1RequestText",
    "ReadV1RequestTextParams",
    "ReadV1RequestUrl",
    "ReadV1RequestUrlParams",
    "ReadV1Response",
    "ReadV1ResponseMetadata",
    "ReadV1ResponseMetadataMetadata",
    "ReadV1ResponseMetadataMetadataIntentsInfo",
    "ReadV1ResponseMetadataMetadataIntentsInfoParams",
    "ReadV1ResponseMetadataMetadataParams",
    "ReadV1ResponseMetadataMetadataSentimentInfo",
    "ReadV1ResponseMetadataMetadataSentimentInfoParams",
    "ReadV1ResponseMetadataMetadataSummaryInfo",
    "ReadV1ResponseMetadataMetadataSummaryInfoParams",
    "ReadV1ResponseMetadataMetadataTopicsInfo",
    "ReadV1ResponseMetadataMetadataTopicsInfoParams",
    "ReadV1ResponseMetadataParams",
    "ReadV1ResponseParams",
    "ReadV1ResponseResults",
    "ReadV1ResponseResultsParams",
    "ReadV1ResponseResultsSummary",
    "ReadV1ResponseResultsSummaryParams",
    "ReadV1ResponseResultsSummaryResults",
    "ReadV1ResponseResultsSummaryResultsParams",
    "ReadV1ResponseResultsSummaryResultsSummary",
    "ReadV1ResponseResultsSummaryResultsSummaryParams",
    "SharedIntents",
    "SharedIntentsParams",
    "SharedIntentsResults",
    "SharedIntentsResultsIntents",
    "SharedIntentsResultsIntentsParams",
    "SharedIntentsResultsIntentsSegmentsItem",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItem",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItemParams",
    "SharedIntentsResultsIntentsSegmentsItemParams",
    "SharedIntentsResultsParams",
    "SharedSentiments",
    "SharedSentimentsAverage",
    "SharedSentimentsAverageParams",
    "SharedSentimentsParams",
    "SharedSentimentsSegmentsItem",
    "SharedSentimentsSegmentsItemParams",
    "SharedTopics",
    "SharedTopicsParams",
    "SharedTopicsResults",
    "SharedTopicsResultsParams",
    "SharedTopicsResultsTopics",
    "SharedTopicsResultsTopicsParams",
    "SharedTopicsResultsTopicsSegmentsItem",
    "SharedTopicsResultsTopicsSegmentsItemParams",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItem",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItemParams",
    "SpeakSettingsV1",
    "SpeakSettingsV1Endpoint",
    "SpeakSettingsV1EndpointParams",
    "SpeakSettingsV1Params",
    "SpeakSettingsV1Provider",
    "SpeakSettingsV1ProviderParams",
    "SpeakSettingsV1Provider_AwsPolly",
    "SpeakSettingsV1Provider_AwsPollyParams",
    "SpeakSettingsV1Provider_Cartesia",
    "SpeakSettingsV1Provider_CartesiaParams",
    "SpeakSettingsV1Provider_Deepgram",
    "SpeakSettingsV1Provider_DeepgramParams",
    "SpeakSettingsV1Provider_ElevenLabs",
    "SpeakSettingsV1Provider_ElevenLabsParams",
    "SpeakSettingsV1Provider_OpenAi",
    "SpeakSettingsV1Provider_OpenAiParams",
    "SpeakV1Encoding",
    "SpeakV1MipOptOut",
    "SpeakV1Model",
    "SpeakV1Response",
    "SpeakV1SampleRate",
    "ThinkSettingsV1",
    "ThinkSettingsV1ContextLength",
    "ThinkSettingsV1ContextLengthParams",
    "ThinkSettingsV1Endpoint",
    "ThinkSettingsV1EndpointParams",
    "ThinkSettingsV1FunctionsItem",
    "ThinkSettingsV1FunctionsItemEndpoint",
    "ThinkSettingsV1FunctionsItemEndpointParams",
    "ThinkSettingsV1FunctionsItemParams",
    "ThinkSettingsV1Params",
    "ThinkSettingsV1Provider",
    "ThinkSettingsV1ProviderParams",
    "ThinkSettingsV1Provider_Anthropic",
    "ThinkSettingsV1Provider_AnthropicParams",
    "ThinkSettingsV1Provider_AwsBedrock",
    "ThinkSettingsV1Provider_AwsBedrockParams",
    "ThinkSettingsV1Provider_Google",
    "ThinkSettingsV1Provider_GoogleParams",
    "ThinkSettingsV1Provider_Groq",
    "ThinkSettingsV1Provider_GroqParams",
    "ThinkSettingsV1Provider_OpenAi",
    "ThinkSettingsV1Provider_OpenAiParams",
    "UpdateProjectMemberScopesV1Response",
    "UpdateProjectMemberScopesV1ResponseParams",
    "UpdateProjectV1Response",
    "UpdateProjectV1ResponseParams",
    "UsageBreakdownV1Response",
    "UsageBreakdownV1ResponseParams",
    "UsageBreakdownV1ResponseResolution",
    "UsageBreakdownV1ResponseResolutionParams",
    "UsageBreakdownV1ResponseResultsItem",
    "UsageBreakdownV1ResponseResultsItemGrouping",
    "UsageBreakdownV1ResponseResultsItemGroupingParams",
    "UsageBreakdownV1ResponseResultsItemParams",
    "UsageFieldsV1Response",
    "UsageFieldsV1ResponseModelsItem",
    "UsageFieldsV1ResponseModelsItemParams",
    "UsageFieldsV1ResponseParams",
    "UsageV1Response",
    "UsageV1ResponseParams",
    "UsageV1ResponseResolution",
    "UsageV1ResponseResolutionParams",
    "__version__",
    "agent",
    "auth",
    "listen",
    "manage",
    "read",
    "self_hosted",
    "speak",
]
