# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams(typing_extensions.TypedDict):
    label: typing_extensions.NotRequired[str]
    value: typing_extensions.NotRequired[str]
    raw_value: typing_extensions.NotRequired[str]
    confidence: typing_extensions.NotRequired[float]
    start_word: typing_extensions.NotRequired[float]
    end_word: typing_extensions.NotRequired[float]
