# This file was auto-generated by Fern from our API Definition.

import typing

from .get_model_v1response_batch import GetModelV1ResponseBatchParams
from .get_model_v1response_metadata import GetModelV1ResponseMetadataParams

GetModelV1ResponseParams = typing.Union[GetModelV1ResponseBatchParams, GetModelV1ResponseMetadataParams]
