# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.agent_think_models_v1response_models_item_zero_id import AgentThinkModelsV1ResponseModelsItemZeroId


class AgentThinkModelsV1ResponseModelsItemZeroParams(typing_extensions.TypedDict):
    """
    OpenAI models
    """

    id: AgentThinkModelsV1ResponseModelsItemZeroId
    """
    The unique identifier of the OpenAI model
    """

    name: str
    """
    The display name of the model
    """

    provider: typing.Literal["open_ai"]
    """
    The provider of the model
    """
