# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_project_balances_v1response_balances_item import ListProjectBalancesV1ResponseBalancesItemParams


class ListProjectBalancesV1ResponseParams(typing_extensions.TypedDict):
    balances: typing_extensions.NotRequired[typing.Sequence[ListProjectBalancesV1ResponseBalancesItemParams]]
