# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1UpdatePromptParams(typing_extensions.TypedDict):
    type: typing.Literal["UpdatePrompt"]
    """
    Message type identifier for prompt update request
    """

    prompt: str
    """
    The new system prompt to be used by the agent
    """
