# This file was auto-generated by Fern from our API Definition.

import typing

AudioGenerateRequestEncoding = typing.Union[
    typing.Literal["linear16", "flac", "mulaw", "alaw", "mp3", "opus", "aac"], typing.Any
]
