# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials import (
    ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams,
)
from .list_project_distribution_credentials_v1response_distribution_credentials_item_member import (
    ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams,
)


class ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams(typing_extensions.TypedDict):
    member: ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams
    distribution_credentials: (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams
    )
