# This file was auto-generated by Fern from our API Definition.

import typing

ListenV2Encoding = typing.Union[typing.Literal["linear16", "linear32", "mulaw", "alaw", "opus", "ogg-opus"], typing.Any]
