# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .shared_topics_results_topics_segments_item import SharedTopicsResultsTopicsSegmentsItemParams


class SharedTopicsResultsTopicsParams(typing_extensions.TypedDict):
    segments: typing_extensions.NotRequired[typing.Sequence[SharedTopicsResultsTopicsSegmentsItemParams]]
