# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .project_request_response import ProjectRequestResponse


class ListProjectRequestsV1Response(UniversalBaseModel):
    page: typing.Optional[float] = pydantic.Field(default=None)
    """
    The page number of the paginated response
    """

    limit: typing.Optional[float] = pydantic.Field(default=None)
    """
    The number of results per page
    """

    requests: typing.Optional[typing.List[ProjectRequestResponse]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
