# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class SpeakV1TextParams(typing_extensions.TypedDict):
    type: typing.Literal["Speak"]
    """
    Message type identifier
    """

    text: str
    """
    The input text to be converted to speech
    """
