# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResponseResultsSummaryParams(typing_extensions.TypedDict):
    result: typing_extensions.NotRequired[str]
    short: typing_extensions.NotRequired[str]
