# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1WarningParams(typing_extensions.TypedDict):
    """
    Notifies the client of non-fatal errors or warnings
    """

    type: typing.Literal["Warning"]
    """
    Message type identifier for warnings
    """

    description: str
    """
    Description of the warning
    """

    code: str
    """
    Warning code identifier
    """
