# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_v1settings_agent_context_messages_item_function_calls_function_calls_item import (
    AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams,
)


class AgentV1SettingsAgentContextMessagesItemFunctionCallsParams(typing_extensions.TypedDict):
    """
    Client-side or server-side function call request and response as part of the conversation history
    """

    type: typing.Literal["History"]
    function_calls: typing.Sequence[AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams]
    """
    List of function call objects
    """
