# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class DeleteProjectV1ResponseParams(typing_extensions.TypedDict):
    message: typing_extensions.NotRequired[str]
    """
    Confirmation message
    """
