# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .billing_breakdown_v1response_resolution import BillingBreakdownV1ResponseResolutionParams
from .billing_breakdown_v1response_results_item import BillingBreakdownV1ResponseResultsItemParams


class BillingBreakdownV1ResponseParams(typing_extensions.TypedDict):
    start: str
    """
    Start date of the billing summmary period
    """

    end: str
    """
    End date of the billing summary period
    """

    resolution: BillingBreakdownV1ResponseResolutionParams
    results: typing.Sequence[BillingBreakdownV1ResponseResultsItemParams]
