# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListProjectMembersV1ResponseMembersItemParams(typing_extensions.TypedDict):
    member_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the member
    """

    email: typing_extensions.NotRequired[str]
