# This file was auto-generated by Fern from our API Definition.

import datetime as dt

import typing_extensions
from .read_v1response_metadata_metadata_intents_info import ReadV1ResponseMetadataMetadataIntentsInfoParams
from .read_v1response_metadata_metadata_sentiment_info import ReadV1ResponseMetadataMetadataSentimentInfoParams
from .read_v1response_metadata_metadata_summary_info import ReadV1ResponseMetadataMetadataSummaryInfoParams
from .read_v1response_metadata_metadata_topics_info import ReadV1ResponseMetadataMetadataTopicsInfoParams


class ReadV1ResponseMetadataMetadataParams(typing_extensions.TypedDict):
    request_id: typing_extensions.NotRequired[str]
    created: typing_extensions.NotRequired[dt.datetime]
    language: typing_extensions.NotRequired[str]
    summary_info: typing_extensions.NotRequired[ReadV1ResponseMetadataMetadataSummaryInfoParams]
    sentiment_info: typing_extensions.NotRequired[ReadV1ResponseMetadataMetadataSentimentInfoParams]
    topics_info: typing_extensions.NotRequired[ReadV1ResponseMetadataMetadataTopicsInfoParams]
    intents_info: typing_extensions.NotRequired[ReadV1ResponseMetadataMetadataIntentsInfoParams]
