# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListProjectMemberScopesV1ResponseParams(typing_extensions.TypedDict):
    scopes: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The API scopes of the member
    """
