# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .usage_v1response_resolution import UsageV1ResponseResolutionParams


class UsageV1ResponseParams(typing_extensions.TypedDict):
    start: typing_extensions.NotRequired[str]
    end: typing_extensions.NotRequired[str]
    resolution: typing_extensions.NotRequired[UsageV1ResponseResolutionParams]
