# This file was auto-generated by Fern from our API Definition.

import typing

AgentV1SettingsAudioInputEncoding = typing.Union[
    typing.Literal[
        "linear16", "linear32", "flac", "alaw", "mulaw", "amr-nb", "amr-wb", "opus", "ogg-opus", "speex", "g729"
    ],
    typing.Any,
]
