# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class SpeakV1MetadataParams(typing_extensions.TypedDict):
    type: typing.Literal["Metadata"]
    """
    Message type identifier
    """

    request_id: str
    """
    Unique identifier for the request
    """

    model_name: str
    """
    Name of the model being used
    """

    model_version: str
    """
    Version of the model being used
    """

    model_uuid: str
    """
    Unique identifier for the model
    """
