# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListenV1SpeechStartedParams(typing_extensions.TypedDict):
    type: typing.Literal["SpeechStarted"]
    """
    Message type identifier
    """

    channel: typing.Sequence[float]
    """
    The channel
    """

    timestamp: float
    """
    The timestamp
    """
