# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .get_project_key_v1response_item import GetProjectKeyV1ResponseItemParams


class GetProjectKeyV1ResponseParams(typing_extensions.TypedDict):
    item: typing_extensions.NotRequired[GetProjectKeyV1ResponseItemParams]
