# This file was auto-generated by Fern from our API Definition.

import typing

MediaTranscribeRequestEncoding = typing.Union[
    typing.Literal["linear16", "flac", "mulaw", "amr-nb", "amr-wb", "opus", "speex", "g729"], typing.Any
]
