# This file was auto-generated by Fern from our API Definition.

import typing

from .....types.listen_v1accepted_response import ListenV1AcceptedResponse
from .....types.listen_v1response import ListenV1Response

MediaTranscribeResponse = typing.Union[ListenV1Response, ListenV1AcceptedResponse]
