# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class GetModelV1ResponseMetadataMetadataParams(typing_extensions.TypedDict):
    accent: typing_extensions.NotRequired[str]
    age: typing_extensions.NotRequired[str]
    color: typing_extensions.NotRequired[str]
    image: typing_extensions.NotRequired[str]
    sample: typing_extensions.NotRequired[str]
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    use_cases: typing_extensions.NotRequired[typing.Sequence[str]]
