# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .usage_breakdown_v1response_results_item_grouping import UsageBreakdownV1ResponseResultsItemGroupingParams


class UsageBreakdownV1ResponseResultsItemParams(typing_extensions.TypedDict):
    hours: float
    """
    Audio hours processed
    """

    total_hours: float
    """
    Total hours including all processing
    """

    agent_hours: float
    """
    Agent hours used
    """

    tokens_in: float
    """
    Number of input tokens
    """

    tokens_out: float
    """
    Number of output tokens
    """

    tts_characters: float
    """
    Number of text-to-speech characters processed
    """

    requests: float
    """
    Number of requests
    """

    grouping: UsageBreakdownV1ResponseResultsItemGroupingParams
