# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .shared_intents_results_intents_segments_item_intents_item import (
    SharedIntentsResultsIntentsSegmentsItemIntentsItemParams,
)


class SharedIntentsResultsIntentsSegmentsItemParams(typing_extensions.TypedDict):
    text: typing_extensions.NotRequired[str]
    start_word: typing_extensions.NotRequired[float]
    end_word: typing_extensions.NotRequired[float]
    intents: typing_extensions.NotRequired[typing.Sequence[SharedIntentsResultsIntentsSegmentsItemIntentsItemParams]]
