# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_results_summary_results_summary import ReadV1ResponseResultsSummaryResultsSummaryParams


class ReadV1ResponseResultsSummaryResultsParams(typing_extensions.TypedDict):
    summary: typing_extensions.NotRequired[ReadV1ResponseResultsSummaryResultsSummaryParams]
