# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .project_request_response import ProjectRequestResponseParams


class ListProjectRequestsV1ResponseParams(typing_extensions.TypedDict):
    page: typing_extensions.NotRequired[float]
    """
    The page number of the paginated response
    """

    limit: typing_extensions.NotRequired[float]
    """
    The number of results per page
    """

    requests: typing_extensions.NotRequired[typing.Sequence[ProjectRequestResponseParams]]
