# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class BillingBreakdownV1ResponseResultsItemGroupingParams(typing_extensions.TypedDict):
    start: typing_extensions.NotRequired[str]
    """
    Start date for this group
    """

    end: typing_extensions.NotRequired[str]
    """
    End date for this group
    """

    accessor: typing_extensions.NotRequired[str]
    """
    Optional accessor identifier, null unless grouped by accessor.
    """

    deployment: typing_extensions.NotRequired[str]
    """
    Optional deployment identifier, null unless grouped by deployment.
    """

    line_item: typing_extensions.NotRequired[str]
    """
    Optional line item identifier, null unless grouped by line item.
    """

    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Optional list of tags, null unless grouped by tags.
    """
