# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResultsEntitiesItemParams(typing_extensions.TypedDict):
    label: str
    """
    The type/category of the entity (e.g., NAME, PHONE_NUMBER, EMAIL_ADDRESS, ORGANIZATION, CARDINAL)
    """

    value: str
    """
    The formatted text representation of the entity
    """

    raw_value: str
    """
    The original spoken text of the entity (present when formatting is enabled)
    """

    confidence: float
    """
    The confidence score of the entity detection
    """

    start_word: int
    """
    The index of the first word of the entity in the transcript (inclusive)
    """

    end_word: int
    """
    The index of the last word of the entity in the transcript (exclusive)
    """
