# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentV1AgentStartedSpeaking(UniversalBaseModel):
    type: typing.Literal["AgentStartedSpeaking"] = pydantic.Field(default="AgentStartedSpeaking")
    """
    Message type identifier for agent started speaking
    """

    total_latency: float = pydantic.Field()
    """
    Seconds from receiving the user's utterance to producing the agent's reply
    """

    tts_latency: float = pydantic.Field()
    """
    The portion of total latency attributable to text-to-speech
    """

    ttt_latency: float = pydantic.Field()
    """
    The portion of total latency attributable to text-to-text (usually an LLM)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
