# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .shared_topics_results_topics import SharedTopicsResultsTopicsParams


class SharedTopicsResultsParams(typing_extensions.TypedDict):
    topics: typing_extensions.NotRequired[SharedTopicsResultsTopicsParams]
