# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ReadV1RequestUrlParams(typing_extensions.TypedDict):
    url: str
    """
    A URL pointing to the text source
    """
