# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1AgentThinkingParams(typing_extensions.TypedDict):
    type: typing.Literal["AgentThinking"]
    """
    Message type identifier for agent thinking
    """

    content: str
    """
    The text of the agent's thought process
    """
