# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class GetProjectDistributionCredentialsV1ResponseMemberParams(typing_extensions.TypedDict):
    member_id: str
    """
    Unique identifier for the member
    """

    email: str
    """
    Email address of the member
    """
