# This file was auto-generated by Fern from our API Definition.

import typing

AwsBedrockThinkProviderModel = typing.Union[
    typing.Literal["anthropic/claude-3-5-sonnet-20240620-v1:0", "anthropic/claude-3-5-haiku-20240307-v1:0"], typing.Any
]
