# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKeyParams


class GetProjectKeyV1ResponseItemMemberParams(typing_extensions.TypedDict):
    member_id: typing_extensions.NotRequired[str]
    email: typing_extensions.NotRequired[str]
    first_name: typing_extensions.NotRequired[str]
    last_name: typing_extensions.NotRequired[str]
    api_key: typing_extensions.NotRequired[GetProjectKeyV1ResponseItemMemberApiKeyParams]
