# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListProjectsV1ResponseProjectsItemParams(typing_extensions.TypedDict):
    project_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the project
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of the project
    """
