# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentThinkModelsV1ResponseModelsItemIdParams(typing_extensions.TypedDict):
    """
    AWS Bedrock models (custom models accepted)
    """

    id: str
    """
    The unique identifier of the AWS Bedrock model (any model string accepted for BYO LLMs)
    """

    name: str
    """
    The display name of the model
    """

    provider: typing.Literal["aws_bedrock"]
    """
    The provider of the model
    """
