# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.agent_v1conversation_text_role import AgentV1ConversationTextRole


class AgentV1ConversationTextParams(typing_extensions.TypedDict):
    type: typing.Literal["ConversationText"]
    """
    Message type identifier for conversation text
    """

    role: AgentV1ConversationTextRole
    """
    Identifies who spoke the statement
    """

    content: str
    """
    The actual statement that was spoken
    """
