# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.speak_settings_v1 import SpeakSettingsV1

AgentV1SettingsAgentSpeak = typing.Union[SpeakSettingsV1, typing.List[SpeakSettingsV1]]
