# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_v1settings_agent_context_messages_item import AgentV1SettingsAgentContextMessagesItemParams


class AgentV1SettingsAgentContextParams(typing_extensions.TypedDict):
    """
    Conversation context including the history of messages and function calls
    """

    messages: typing_extensions.NotRequired[typing.Sequence[AgentV1SettingsAgentContextMessagesItemParams]]
    """
    Conversation history as a list of messages and function calls
    """
