# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.google_think_provider_model import GoogleThinkProviderModel


class GoogleParams(typing_extensions.TypedDict):
    type: typing.Literal["google"]
    version: typing_extensions.NotRequired[typing.Literal["v1beta"]]
    """
    The REST API version for the Google generative language API
    """

    model: GoogleThinkProviderModel
    """
    Google model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    Google temperature (0-2)
    """
