# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentV1Warning(UniversalBaseModel):
    """
    Notifies the client of non-fatal errors or warnings
    """

    type: typing.Literal["Warning"] = pydantic.Field(default="Warning")
    """
    Message type identifier for warnings
    """

    description: str = pydantic.Field()
    """
    Description of the warning
    """

    code: str = pydantic.Field()
    """
    Warning code identifier
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
