# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1SettingsAgentListenProviderV2Params(typing_extensions.TypedDict):
    type: typing.Literal["deepgram"]
    """
    Provider type for speech-to-text
    """

    model: str
    """
    Model to use for speech to text using the V2 API (e.g. flux-general-en)
    """

    keyterms: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Prompt keyterm recognition to improve Keyword Recall Rate
    """
