# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.aws_polly_speak_provider_engine import AwsPollySpeakProviderEngine
from ..types.aws_polly_speak_provider_voice import AwsPollySpeakProviderVoice
from .aws_polly_speak_provider_credentials import AwsPollySpeakProviderCredentialsParams


class AwsPollySpeakProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["aws_polly"]
    voice: AwsPollySpeakProviderVoice
    """
    AWS Polly voice name
    """

    language: str
    """
    Language code to use, e.g. 'en-US'. Corresponds to the `language_code` parameter in the AWS Polly API
    """

    language_code: typing_extensions.NotRequired[str]
    """
    Use the `language` field instead.
    """

    engine: AwsPollySpeakProviderEngine
    credentials: AwsPollySpeakProviderCredentialsParams
