# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ReadV1ResponseResultsSummaryResultsSummaryParams(typing_extensions.TypedDict):
    text: typing_extensions.NotRequired[str]
