# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams(typing_extensions.TypedDict):
    word: typing_extensions.NotRequired[str]
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
    confidence: typing_extensions.NotRequired[float]
