# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.open_ai_speak_provider_model import OpenAiSpeakProviderModel
from ..types.open_ai_speak_provider_voice import OpenAiSpeakProviderVoice


class OpenAiSpeakProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["open_ai"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the OpenAI text-to-speech API
    """

    model: OpenAiSpeakProviderModel
    """
    OpenAI TTS model
    """

    voice: OpenAiSpeakProviderVoice
    """
    OpenAI voice
    """
