# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .project_request_response import ProjectRequestResponseParams


class GetProjectRequestV1ResponseParams(typing_extensions.TypedDict):
    request: typing_extensions.NotRequired[ProjectRequestResponseParams]
