# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class AgentV1FunctionCallRequestFunctionsItemParams(typing_extensions.TypedDict):
    id: str
    """
    Unique identifier for the function call
    """

    name: str
    """
    The name of the function to call
    """

    arguments: str
    """
    JSON string containing the function arguments
    """

    client_side: bool
    """
    Whether the function should be executed client-side
    """
