# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .agent_v1settings_audio_input import AgentV1SettingsAudioInputParams
from .agent_v1settings_audio_output import AgentV1SettingsAudioOutputParams


class AgentV1SettingsAudioParams(typing_extensions.TypedDict):
    input: typing_extensions.NotRequired[AgentV1SettingsAudioInputParams]
    """
    Audio input configuration settings. If omitted, defaults to encoding=linear16 and sample_rate=24000. Higher sample rates like 44100 Hz provide better audio quality.
    """

    output: typing_extensions.NotRequired[AgentV1SettingsAudioOutputParams]
    """
    Audio output configuration settings
    """
