# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParams,
)
from .listen_v1response_results_channels_item_search_item import ListenV1ResponseResultsChannelsItemSearchItemParams


class ListenV1ResponseResultsChannelsItemParams(typing_extensions.TypedDict):
    search: typing_extensions.NotRequired[typing.Sequence[ListenV1ResponseResultsChannelsItemSearchItemParams]]
    alternatives: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemParams]
    ]
    detected_language: typing_extensions.NotRequired[str]
