# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResultsChannelAlternativesItemWordsItemParams(typing_extensions.TypedDict):
    word: str
    """
    The word of the transcription
    """

    start: float
    """
    The start time of the word
    """

    end: float
    """
    The end time of the word
    """

    confidence: float
    """
    The confidence of the word
    """

    language: typing_extensions.NotRequired[str]
    """
    The language of the word
    """

    punctuated_word: typing_extensions.NotRequired[str]
    """
    The punctuated word of the word
    """

    speaker: typing_extensions.NotRequired[float]
    """
    The speaker of the word
    """
