# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CreateProjectDistributionCredentialsV1ResponseDistributionCredentials(UniversalBaseModel):
    distribution_credentials_id: str = pydantic.Field()
    """
    Unique identifier for the distribution credentials
    """

    provider: str = pydantic.Field()
    """
    The provider of the distribution service
    """

    comment: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional comment about the credentials
    """

    scopes: typing.List[str] = pydantic.Field()
    """
    List of permission scopes for the credentials
    """

    created: dt.datetime = pydantic.Field()
    """
    Timestamp when the credentials were created
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
