# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ThinkSettingsV1FunctionsItemEndpointParams(typing_extensions.TypedDict):
    """
    The Function endpoint to call. if not passed, function is called client-side
    """

    url: typing_extensions.NotRequired[str]
    """
    Endpoint URL
    """

    method: typing_extensions.NotRequired[str]
    """
    HTTP method
    """

    headers: typing_extensions.NotRequired[typing.Dict[str, str]]
