# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentThinkModelsV1ResponseModelsItemThree(UniversalBaseModel):
    """
    Groq models
    """

    id: typing.Literal["openai/gpt-oss-20b"] = pydantic.Field(default="openai/gpt-oss-20b")
    """
    The unique identifier of the Groq model
    """

    name: str = pydantic.Field()
    """
    The display name of the model
    """

    provider: typing.Literal["groq"] = pydantic.Field(default="groq")
    """
    The provider of the model
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
