# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.speak_v1flush_type import SpeakV1FlushType


class SpeakV1FlushParams(typing_extensions.TypedDict):
    type: SpeakV1FlushType
    """
    Message type identifier
    """
