# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1settings_agent_context_messages_item_function_calls_function_calls_item import (
    AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItem,
)


class AgentV1SettingsAgentContextMessagesItemFunctionCalls(UniversalBaseModel):
    """
    Client-side or server-side function call request and response as part of the conversation history
    """

    type: typing.Literal["History"] = "History"
    function_calls: typing.List[AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItem] = (
        pydantic.Field()
    )
    """
    List of function call objects
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
