# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .agent_think_models_v1response import AgentThinkModelsV1ResponseParams
    from .agent_think_models_v1response_models_item import AgentThinkModelsV1ResponseModelsItemParams
    from .agent_think_models_v1response_models_item_id import AgentThinkModelsV1ResponseModelsItemIdParams
    from .agent_think_models_v1response_models_item_one import AgentThinkModelsV1ResponseModelsItemOneParams
    from .agent_think_models_v1response_models_item_three import AgentThinkModelsV1ResponseModelsItemThreeParams
    from .agent_think_models_v1response_models_item_two import AgentThinkModelsV1ResponseModelsItemTwoParams
    from .agent_think_models_v1response_models_item_zero import AgentThinkModelsV1ResponseModelsItemZeroParams
    from .anthropic import AnthropicParams
    from .aws_bedrock_think_provider import AwsBedrockThinkProviderParams
    from .aws_bedrock_think_provider_credentials import AwsBedrockThinkProviderCredentialsParams
    from .aws_polly_speak_provider import AwsPollySpeakProviderParams
    from .aws_polly_speak_provider_credentials import AwsPollySpeakProviderCredentialsParams
    from .billing_breakdown_v1response import BillingBreakdownV1ResponseParams
    from .billing_breakdown_v1response_resolution import BillingBreakdownV1ResponseResolutionParams
    from .billing_breakdown_v1response_results_item import BillingBreakdownV1ResponseResultsItemParams
    from .billing_breakdown_v1response_results_item_grouping import BillingBreakdownV1ResponseResultsItemGroupingParams
    from .cartesia import CartesiaParams
    from .cartesia_speak_provider_voice import CartesiaSpeakProviderVoiceParams
    from .create_key_v1response import CreateKeyV1ResponseParams
    from .create_project_distribution_credentials_v1response import CreateProjectDistributionCredentialsV1ResponseParams
    from .create_project_distribution_credentials_v1response_distribution_credentials import (
        CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams,
    )
    from .create_project_distribution_credentials_v1response_member import (
        CreateProjectDistributionCredentialsV1ResponseMemberParams,
    )
    from .create_project_invite_v1response import CreateProjectInviteV1ResponseParams
    from .deepgram import DeepgramParams
    from .delete_project_invite_v1response import DeleteProjectInviteV1ResponseParams
    from .delete_project_key_v1response import DeleteProjectKeyV1ResponseParams
    from .delete_project_member_v1response import DeleteProjectMemberV1ResponseParams
    from .delete_project_v1response import DeleteProjectV1ResponseParams
    from .eleven_labs_speak_provider import ElevenLabsSpeakProviderParams
    from .error_response import ErrorResponseParams
    from .error_response_legacy_error import ErrorResponseLegacyErrorParams
    from .error_response_modern_error import ErrorResponseModernErrorParams
    from .get_model_v1response import GetModelV1ResponseParams
    from .get_model_v1response_batch import GetModelV1ResponseBatchParams
    from .get_model_v1response_metadata import GetModelV1ResponseMetadataParams
    from .get_model_v1response_metadata_metadata import GetModelV1ResponseMetadataMetadataParams
    from .get_project_balance_v1response import GetProjectBalanceV1ResponseParams
    from .get_project_distribution_credentials_v1response import GetProjectDistributionCredentialsV1ResponseParams
    from .get_project_distribution_credentials_v1response_distribution_credentials import (
        GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams,
    )
    from .get_project_distribution_credentials_v1response_member import (
        GetProjectDistributionCredentialsV1ResponseMemberParams,
    )
    from .get_project_key_v1response import GetProjectKeyV1ResponseParams
    from .get_project_key_v1response_item import GetProjectKeyV1ResponseItemParams
    from .get_project_key_v1response_item_member import GetProjectKeyV1ResponseItemMemberParams
    from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKeyParams
    from .get_project_request_v1response import GetProjectRequestV1ResponseParams
    from .get_project_v1response import GetProjectV1ResponseParams
    from .google import GoogleParams
    from .grant_v1response import GrantV1ResponseParams
    from .groq import GroqParams
    from .leave_project_v1response import LeaveProjectV1ResponseParams
    from .list_billing_fields_v1response import ListBillingFieldsV1ResponseParams
    from .list_models_v1response import ListModelsV1ResponseParams
    from .list_models_v1response_stt_models import ListModelsV1ResponseSttModelsParams
    from .list_models_v1response_tts_models import ListModelsV1ResponseTtsModelsParams
    from .list_models_v1response_tts_models_metadata import ListModelsV1ResponseTtsModelsMetadataParams
    from .list_project_balances_v1response import ListProjectBalancesV1ResponseParams
    from .list_project_balances_v1response_balances_item import ListProjectBalancesV1ResponseBalancesItemParams
    from .list_project_distribution_credentials_v1response import ListProjectDistributionCredentialsV1ResponseParams
    from .list_project_distribution_credentials_v1response_distribution_credentials_item import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_member import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams,
    )
    from .list_project_invites_v1response import ListProjectInvitesV1ResponseParams
    from .list_project_invites_v1response_invites_item import ListProjectInvitesV1ResponseInvitesItemParams
    from .list_project_keys_v1response import ListProjectKeysV1ResponseParams
    from .list_project_keys_v1response_api_keys_item import ListProjectKeysV1ResponseApiKeysItemParams
    from .list_project_keys_v1response_api_keys_item_api_key import ListProjectKeysV1ResponseApiKeysItemApiKeyParams
    from .list_project_keys_v1response_api_keys_item_member import ListProjectKeysV1ResponseApiKeysItemMemberParams
    from .list_project_member_scopes_v1response import ListProjectMemberScopesV1ResponseParams
    from .list_project_members_v1response import ListProjectMembersV1ResponseParams
    from .list_project_members_v1response_members_item import ListProjectMembersV1ResponseMembersItemParams
    from .list_project_purchases_v1response import ListProjectPurchasesV1ResponseParams
    from .list_project_purchases_v1response_orders_item import ListProjectPurchasesV1ResponseOrdersItemParams
    from .list_project_requests_v1response import ListProjectRequestsV1ResponseParams
    from .list_projects_v1response import ListProjectsV1ResponseParams
    from .list_projects_v1response_projects_item import ListProjectsV1ResponseProjectsItemParams
    from .listen_v1accepted_response import ListenV1AcceptedResponseParams
    from .listen_v1response import ListenV1ResponseParams
    from .listen_v1response_metadata import ListenV1ResponseMetadataParams
    from .listen_v1response_metadata_intents_info import ListenV1ResponseMetadataIntentsInfoParams
    from .listen_v1response_metadata_sentiment_info import ListenV1ResponseMetadataSentimentInfoParams
    from .listen_v1response_metadata_summary_info import ListenV1ResponseMetadataSummaryInfoParams
    from .listen_v1response_metadata_topics_info import ListenV1ResponseMetadataTopicsInfoParams
    from .listen_v1response_results import ListenV1ResponseResultsParams
    from .listen_v1response_results_channels import ListenV1ResponseResultsChannelsParams
    from .listen_v1response_results_channels_item import ListenV1ResponseResultsChannelsItemParams
    from .listen_v1response_results_channels_item_alternatives_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_entities_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_summaries_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_topics_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_words_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams,
    )
    from .listen_v1response_results_channels_item_search_item import ListenV1ResponseResultsChannelsItemSearchItemParams
    from .listen_v1response_results_channels_item_search_item_hits_item import (
        ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams,
    )
    from .listen_v1response_results_summary import ListenV1ResponseResultsSummaryParams
    from .listen_v1response_results_utterances import ListenV1ResponseResultsUtterancesParams
    from .listen_v1response_results_utterances_item import ListenV1ResponseResultsUtterancesItemParams
    from .listen_v1response_results_utterances_item_words_item import (
        ListenV1ResponseResultsUtterancesItemWordsItemParams,
    )
    from .listen_v2keyterm import ListenV2KeytermParams
    from .open_ai_speak_provider import OpenAiSpeakProviderParams
    from .open_ai_think_provider import OpenAiThinkProviderParams
    from .project_request_response import ProjectRequestResponseParams
    from .read_v1request import ReadV1RequestParams
    from .read_v1request_text import ReadV1RequestTextParams
    from .read_v1request_url import ReadV1RequestUrlParams
    from .read_v1response import ReadV1ResponseParams
    from .read_v1response_metadata import ReadV1ResponseMetadataParams
    from .read_v1response_metadata_metadata import ReadV1ResponseMetadataMetadataParams
    from .read_v1response_metadata_metadata_intents_info import ReadV1ResponseMetadataMetadataIntentsInfoParams
    from .read_v1response_metadata_metadata_sentiment_info import ReadV1ResponseMetadataMetadataSentimentInfoParams
    from .read_v1response_metadata_metadata_summary_info import ReadV1ResponseMetadataMetadataSummaryInfoParams
    from .read_v1response_metadata_metadata_topics_info import ReadV1ResponseMetadataMetadataTopicsInfoParams
    from .read_v1response_results import ReadV1ResponseResultsParams
    from .read_v1response_results_summary import ReadV1ResponseResultsSummaryParams
    from .read_v1response_results_summary_results import ReadV1ResponseResultsSummaryResultsParams
    from .read_v1response_results_summary_results_summary import ReadV1ResponseResultsSummaryResultsSummaryParams
    from .shared_intents import SharedIntentsParams
    from .shared_intents_results import SharedIntentsResultsParams
    from .shared_intents_results_intents import SharedIntentsResultsIntentsParams
    from .shared_intents_results_intents_segments_item import SharedIntentsResultsIntentsSegmentsItemParams
    from .shared_intents_results_intents_segments_item_intents_item import (
        SharedIntentsResultsIntentsSegmentsItemIntentsItemParams,
    )
    from .shared_sentiments import SharedSentimentsParams
    from .shared_sentiments_average import SharedSentimentsAverageParams
    from .shared_sentiments_segments_item import SharedSentimentsSegmentsItemParams
    from .shared_topics import SharedTopicsParams
    from .shared_topics_results import SharedTopicsResultsParams
    from .shared_topics_results_topics import SharedTopicsResultsTopicsParams
    from .shared_topics_results_topics_segments_item import SharedTopicsResultsTopicsSegmentsItemParams
    from .shared_topics_results_topics_segments_item_topics_item import (
        SharedTopicsResultsTopicsSegmentsItemTopicsItemParams,
    )
    from .speak_settings_v1 import SpeakSettingsV1Params
    from .speak_settings_v1endpoint import SpeakSettingsV1EndpointParams
    from .speak_settings_v1provider import (
        SpeakSettingsV1ProviderParams,
        SpeakSettingsV1Provider_AwsPollyParams,
        SpeakSettingsV1Provider_CartesiaParams,
        SpeakSettingsV1Provider_DeepgramParams,
        SpeakSettingsV1Provider_ElevenLabsParams,
        SpeakSettingsV1Provider_OpenAiParams,
    )
    from .think_settings_v1 import ThinkSettingsV1Params
    from .think_settings_v1context_length import ThinkSettingsV1ContextLengthParams
    from .think_settings_v1endpoint import ThinkSettingsV1EndpointParams
    from .think_settings_v1functions_item import ThinkSettingsV1FunctionsItemParams
    from .think_settings_v1functions_item_endpoint import ThinkSettingsV1FunctionsItemEndpointParams
    from .think_settings_v1provider import (
        ThinkSettingsV1ProviderParams,
        ThinkSettingsV1Provider_AnthropicParams,
        ThinkSettingsV1Provider_AwsBedrockParams,
        ThinkSettingsV1Provider_GoogleParams,
        ThinkSettingsV1Provider_GroqParams,
        ThinkSettingsV1Provider_OpenAiParams,
    )
    from .update_project_member_scopes_v1response import UpdateProjectMemberScopesV1ResponseParams
    from .update_project_v1response import UpdateProjectV1ResponseParams
    from .usage_breakdown_v1response import UsageBreakdownV1ResponseParams
    from .usage_breakdown_v1response_resolution import UsageBreakdownV1ResponseResolutionParams
    from .usage_breakdown_v1response_results_item import UsageBreakdownV1ResponseResultsItemParams
    from .usage_breakdown_v1response_results_item_grouping import UsageBreakdownV1ResponseResultsItemGroupingParams
    from .usage_fields_v1response import UsageFieldsV1ResponseParams
    from .usage_fields_v1response_models_item import UsageFieldsV1ResponseModelsItemParams
    from .usage_v1response import UsageV1ResponseParams
    from .usage_v1response_resolution import UsageV1ResponseResolutionParams
_dynamic_imports: typing.Dict[str, str] = {
    "AgentThinkModelsV1ResponseModelsItemIdParams": ".agent_think_models_v1response_models_item_id",
    "AgentThinkModelsV1ResponseModelsItemOneParams": ".agent_think_models_v1response_models_item_one",
    "AgentThinkModelsV1ResponseModelsItemParams": ".agent_think_models_v1response_models_item",
    "AgentThinkModelsV1ResponseModelsItemThreeParams": ".agent_think_models_v1response_models_item_three",
    "AgentThinkModelsV1ResponseModelsItemTwoParams": ".agent_think_models_v1response_models_item_two",
    "AgentThinkModelsV1ResponseModelsItemZeroParams": ".agent_think_models_v1response_models_item_zero",
    "AgentThinkModelsV1ResponseParams": ".agent_think_models_v1response",
    "AnthropicParams": ".anthropic",
    "AwsBedrockThinkProviderCredentialsParams": ".aws_bedrock_think_provider_credentials",
    "AwsBedrockThinkProviderParams": ".aws_bedrock_think_provider",
    "AwsPollySpeakProviderCredentialsParams": ".aws_polly_speak_provider_credentials",
    "AwsPollySpeakProviderParams": ".aws_polly_speak_provider",
    "BillingBreakdownV1ResponseParams": ".billing_breakdown_v1response",
    "BillingBreakdownV1ResponseResolutionParams": ".billing_breakdown_v1response_resolution",
    "BillingBreakdownV1ResponseResultsItemGroupingParams": ".billing_breakdown_v1response_results_item_grouping",
    "BillingBreakdownV1ResponseResultsItemParams": ".billing_breakdown_v1response_results_item",
    "CartesiaParams": ".cartesia",
    "CartesiaSpeakProviderVoiceParams": ".cartesia_speak_provider_voice",
    "CreateKeyV1ResponseParams": ".create_key_v1response",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams": ".create_project_distribution_credentials_v1response_distribution_credentials",
    "CreateProjectDistributionCredentialsV1ResponseMemberParams": ".create_project_distribution_credentials_v1response_member",
    "CreateProjectDistributionCredentialsV1ResponseParams": ".create_project_distribution_credentials_v1response",
    "CreateProjectInviteV1ResponseParams": ".create_project_invite_v1response",
    "DeepgramParams": ".deepgram",
    "DeleteProjectInviteV1ResponseParams": ".delete_project_invite_v1response",
    "DeleteProjectKeyV1ResponseParams": ".delete_project_key_v1response",
    "DeleteProjectMemberV1ResponseParams": ".delete_project_member_v1response",
    "DeleteProjectV1ResponseParams": ".delete_project_v1response",
    "ElevenLabsSpeakProviderParams": ".eleven_labs_speak_provider",
    "ErrorResponseLegacyErrorParams": ".error_response_legacy_error",
    "ErrorResponseModernErrorParams": ".error_response_modern_error",
    "ErrorResponseParams": ".error_response",
    "GetModelV1ResponseBatchParams": ".get_model_v1response_batch",
    "GetModelV1ResponseMetadataMetadataParams": ".get_model_v1response_metadata_metadata",
    "GetModelV1ResponseMetadataParams": ".get_model_v1response_metadata",
    "GetModelV1ResponseParams": ".get_model_v1response",
    "GetProjectBalanceV1ResponseParams": ".get_project_balance_v1response",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams": ".get_project_distribution_credentials_v1response_distribution_credentials",
    "GetProjectDistributionCredentialsV1ResponseMemberParams": ".get_project_distribution_credentials_v1response_member",
    "GetProjectDistributionCredentialsV1ResponseParams": ".get_project_distribution_credentials_v1response",
    "GetProjectKeyV1ResponseItemMemberApiKeyParams": ".get_project_key_v1response_item_member_api_key",
    "GetProjectKeyV1ResponseItemMemberParams": ".get_project_key_v1response_item_member",
    "GetProjectKeyV1ResponseItemParams": ".get_project_key_v1response_item",
    "GetProjectKeyV1ResponseParams": ".get_project_key_v1response",
    "GetProjectRequestV1ResponseParams": ".get_project_request_v1response",
    "GetProjectV1ResponseParams": ".get_project_v1response",
    "GoogleParams": ".google",
    "GrantV1ResponseParams": ".grant_v1response",
    "GroqParams": ".groq",
    "LeaveProjectV1ResponseParams": ".leave_project_v1response",
    "ListBillingFieldsV1ResponseParams": ".list_billing_fields_v1response",
    "ListModelsV1ResponseParams": ".list_models_v1response",
    "ListModelsV1ResponseSttModelsParams": ".list_models_v1response_stt_models",
    "ListModelsV1ResponseTtsModelsMetadataParams": ".list_models_v1response_tts_models_metadata",
    "ListModelsV1ResponseTtsModelsParams": ".list_models_v1response_tts_models",
    "ListProjectBalancesV1ResponseBalancesItemParams": ".list_project_balances_v1response_balances_item",
    "ListProjectBalancesV1ResponseParams": ".list_project_balances_v1response",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams": ".list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams": ".list_project_distribution_credentials_v1response_distribution_credentials_item_member",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams": ".list_project_distribution_credentials_v1response_distribution_credentials_item",
    "ListProjectDistributionCredentialsV1ResponseParams": ".list_project_distribution_credentials_v1response",
    "ListProjectInvitesV1ResponseInvitesItemParams": ".list_project_invites_v1response_invites_item",
    "ListProjectInvitesV1ResponseParams": ".list_project_invites_v1response",
    "ListProjectKeysV1ResponseApiKeysItemApiKeyParams": ".list_project_keys_v1response_api_keys_item_api_key",
    "ListProjectKeysV1ResponseApiKeysItemMemberParams": ".list_project_keys_v1response_api_keys_item_member",
    "ListProjectKeysV1ResponseApiKeysItemParams": ".list_project_keys_v1response_api_keys_item",
    "ListProjectKeysV1ResponseParams": ".list_project_keys_v1response",
    "ListProjectMemberScopesV1ResponseParams": ".list_project_member_scopes_v1response",
    "ListProjectMembersV1ResponseMembersItemParams": ".list_project_members_v1response_members_item",
    "ListProjectMembersV1ResponseParams": ".list_project_members_v1response",
    "ListProjectPurchasesV1ResponseOrdersItemParams": ".list_project_purchases_v1response_orders_item",
    "ListProjectPurchasesV1ResponseParams": ".list_project_purchases_v1response",
    "ListProjectRequestsV1ResponseParams": ".list_project_requests_v1response",
    "ListProjectsV1ResponseParams": ".list_projects_v1response",
    "ListProjectsV1ResponseProjectsItemParams": ".list_projects_v1response_projects_item",
    "ListenV1AcceptedResponseParams": ".listen_v1accepted_response",
    "ListenV1ResponseMetadataIntentsInfoParams": ".listen_v1response_metadata_intents_info",
    "ListenV1ResponseMetadataParams": ".listen_v1response_metadata",
    "ListenV1ResponseMetadataSentimentInfoParams": ".listen_v1response_metadata_sentiment_info",
    "ListenV1ResponseMetadataSummaryInfoParams": ".listen_v1response_metadata_summary_info",
    "ListenV1ResponseMetadataTopicsInfoParams": ".listen_v1response_metadata_topics_info",
    "ListenV1ResponseParams": ".listen_v1response",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams": ".listen_v1response_results_channels_item_alternatives_item_entities_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams": ".listen_v1response_results_channels_item_alternatives_item_paragraphs",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParams": ".listen_v1response_results_channels_item_alternatives_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams": ".listen_v1response_results_channels_item_alternatives_item_summaries_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams": ".listen_v1response_results_channels_item_alternatives_item_topics_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams": ".listen_v1response_results_channels_item_alternatives_item_words_item",
    "ListenV1ResponseResultsChannelsItemParams": ".listen_v1response_results_channels_item",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams": ".listen_v1response_results_channels_item_search_item_hits_item",
    "ListenV1ResponseResultsChannelsItemSearchItemParams": ".listen_v1response_results_channels_item_search_item",
    "ListenV1ResponseResultsChannelsParams": ".listen_v1response_results_channels",
    "ListenV1ResponseResultsParams": ".listen_v1response_results",
    "ListenV1ResponseResultsSummaryParams": ".listen_v1response_results_summary",
    "ListenV1ResponseResultsUtterancesItemParams": ".listen_v1response_results_utterances_item",
    "ListenV1ResponseResultsUtterancesItemWordsItemParams": ".listen_v1response_results_utterances_item_words_item",
    "ListenV1ResponseResultsUtterancesParams": ".listen_v1response_results_utterances",
    "ListenV2KeytermParams": ".listen_v2keyterm",
    "OpenAiSpeakProviderParams": ".open_ai_speak_provider",
    "OpenAiThinkProviderParams": ".open_ai_think_provider",
    "ProjectRequestResponseParams": ".project_request_response",
    "ReadV1RequestParams": ".read_v1request",
    "ReadV1RequestTextParams": ".read_v1request_text",
    "ReadV1RequestUrlParams": ".read_v1request_url",
    "ReadV1ResponseMetadataMetadataIntentsInfoParams": ".read_v1response_metadata_metadata_intents_info",
    "ReadV1ResponseMetadataMetadataParams": ".read_v1response_metadata_metadata",
    "ReadV1ResponseMetadataMetadataSentimentInfoParams": ".read_v1response_metadata_metadata_sentiment_info",
    "ReadV1ResponseMetadataMetadataSummaryInfoParams": ".read_v1response_metadata_metadata_summary_info",
    "ReadV1ResponseMetadataMetadataTopicsInfoParams": ".read_v1response_metadata_metadata_topics_info",
    "ReadV1ResponseMetadataParams": ".read_v1response_metadata",
    "ReadV1ResponseParams": ".read_v1response",
    "ReadV1ResponseResultsParams": ".read_v1response_results",
    "ReadV1ResponseResultsSummaryParams": ".read_v1response_results_summary",
    "ReadV1ResponseResultsSummaryResultsParams": ".read_v1response_results_summary_results",
    "ReadV1ResponseResultsSummaryResultsSummaryParams": ".read_v1response_results_summary_results_summary",
    "SharedIntentsParams": ".shared_intents",
    "SharedIntentsResultsIntentsParams": ".shared_intents_results_intents",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItemParams": ".shared_intents_results_intents_segments_item_intents_item",
    "SharedIntentsResultsIntentsSegmentsItemParams": ".shared_intents_results_intents_segments_item",
    "SharedIntentsResultsParams": ".shared_intents_results",
    "SharedSentimentsAverageParams": ".shared_sentiments_average",
    "SharedSentimentsParams": ".shared_sentiments",
    "SharedSentimentsSegmentsItemParams": ".shared_sentiments_segments_item",
    "SharedTopicsParams": ".shared_topics",
    "SharedTopicsResultsParams": ".shared_topics_results",
    "SharedTopicsResultsTopicsParams": ".shared_topics_results_topics",
    "SharedTopicsResultsTopicsSegmentsItemParams": ".shared_topics_results_topics_segments_item",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItemParams": ".shared_topics_results_topics_segments_item_topics_item",
    "SpeakSettingsV1EndpointParams": ".speak_settings_v1endpoint",
    "SpeakSettingsV1Params": ".speak_settings_v1",
    "SpeakSettingsV1ProviderParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_AwsPollyParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_CartesiaParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_DeepgramParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_ElevenLabsParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_OpenAiParams": ".speak_settings_v1provider",
    "ThinkSettingsV1ContextLengthParams": ".think_settings_v1context_length",
    "ThinkSettingsV1EndpointParams": ".think_settings_v1endpoint",
    "ThinkSettingsV1FunctionsItemEndpointParams": ".think_settings_v1functions_item_endpoint",
    "ThinkSettingsV1FunctionsItemParams": ".think_settings_v1functions_item",
    "ThinkSettingsV1Params": ".think_settings_v1",
    "ThinkSettingsV1ProviderParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_AnthropicParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_AwsBedrockParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_GoogleParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_GroqParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_OpenAiParams": ".think_settings_v1provider",
    "UpdateProjectMemberScopesV1ResponseParams": ".update_project_member_scopes_v1response",
    "UpdateProjectV1ResponseParams": ".update_project_v1response",
    "UsageBreakdownV1ResponseParams": ".usage_breakdown_v1response",
    "UsageBreakdownV1ResponseResolutionParams": ".usage_breakdown_v1response_resolution",
    "UsageBreakdownV1ResponseResultsItemGroupingParams": ".usage_breakdown_v1response_results_item_grouping",
    "UsageBreakdownV1ResponseResultsItemParams": ".usage_breakdown_v1response_results_item",
    "UsageFieldsV1ResponseModelsItemParams": ".usage_fields_v1response_models_item",
    "UsageFieldsV1ResponseParams": ".usage_fields_v1response",
    "UsageV1ResponseParams": ".usage_v1response",
    "UsageV1ResponseResolutionParams": ".usage_v1response_resolution",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentThinkModelsV1ResponseModelsItemIdParams",
    "AgentThinkModelsV1ResponseModelsItemOneParams",
    "AgentThinkModelsV1ResponseModelsItemParams",
    "AgentThinkModelsV1ResponseModelsItemThreeParams",
    "AgentThinkModelsV1ResponseModelsItemTwoParams",
    "AgentThinkModelsV1ResponseModelsItemZeroParams",
    "AgentThinkModelsV1ResponseParams",
    "AnthropicParams",
    "AwsBedrockThinkProviderCredentialsParams",
    "AwsBedrockThinkProviderParams",
    "AwsPollySpeakProviderCredentialsParams",
    "AwsPollySpeakProviderParams",
    "BillingBreakdownV1ResponseParams",
    "BillingBreakdownV1ResponseResolutionParams",
    "BillingBreakdownV1ResponseResultsItemGroupingParams",
    "BillingBreakdownV1ResponseResultsItemParams",
    "CartesiaParams",
    "CartesiaSpeakProviderVoiceParams",
    "CreateKeyV1ResponseParams",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams",
    "CreateProjectDistributionCredentialsV1ResponseMemberParams",
    "CreateProjectDistributionCredentialsV1ResponseParams",
    "CreateProjectInviteV1ResponseParams",
    "DeepgramParams",
    "DeleteProjectInviteV1ResponseParams",
    "DeleteProjectKeyV1ResponseParams",
    "DeleteProjectMemberV1ResponseParams",
    "DeleteProjectV1ResponseParams",
    "ElevenLabsSpeakProviderParams",
    "ErrorResponseLegacyErrorParams",
    "ErrorResponseModernErrorParams",
    "ErrorResponseParams",
    "GetModelV1ResponseBatchParams",
    "GetModelV1ResponseMetadataMetadataParams",
    "GetModelV1ResponseMetadataParams",
    "GetModelV1ResponseParams",
    "GetProjectBalanceV1ResponseParams",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams",
    "GetProjectDistributionCredentialsV1ResponseMemberParams",
    "GetProjectDistributionCredentialsV1ResponseParams",
    "GetProjectKeyV1ResponseItemMemberApiKeyParams",
    "GetProjectKeyV1ResponseItemMemberParams",
    "GetProjectKeyV1ResponseItemParams",
    "GetProjectKeyV1ResponseParams",
    "GetProjectRequestV1ResponseParams",
    "GetProjectV1ResponseParams",
    "GoogleParams",
    "GrantV1ResponseParams",
    "GroqParams",
    "LeaveProjectV1ResponseParams",
    "ListBillingFieldsV1ResponseParams",
    "ListModelsV1ResponseParams",
    "ListModelsV1ResponseSttModelsParams",
    "ListModelsV1ResponseTtsModelsMetadataParams",
    "ListModelsV1ResponseTtsModelsParams",
    "ListProjectBalancesV1ResponseBalancesItemParams",
    "ListProjectBalancesV1ResponseParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams",
    "ListProjectDistributionCredentialsV1ResponseParams",
    "ListProjectInvitesV1ResponseInvitesItemParams",
    "ListProjectInvitesV1ResponseParams",
    "ListProjectKeysV1ResponseApiKeysItemApiKeyParams",
    "ListProjectKeysV1ResponseApiKeysItemMemberParams",
    "ListProjectKeysV1ResponseApiKeysItemParams",
    "ListProjectKeysV1ResponseParams",
    "ListProjectMemberScopesV1ResponseParams",
    "ListProjectMembersV1ResponseMembersItemParams",
    "ListProjectMembersV1ResponseParams",
    "ListProjectPurchasesV1ResponseOrdersItemParams",
    "ListProjectPurchasesV1ResponseParams",
    "ListProjectRequestsV1ResponseParams",
    "ListProjectsV1ResponseParams",
    "ListProjectsV1ResponseProjectsItemParams",
    "ListenV1AcceptedResponseParams",
    "ListenV1ResponseMetadataIntentsInfoParams",
    "ListenV1ResponseMetadataParams",
    "ListenV1ResponseMetadataSentimentInfoParams",
    "ListenV1ResponseMetadataSummaryInfoParams",
    "ListenV1ResponseMetadataTopicsInfoParams",
    "ListenV1ResponseParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams",
    "ListenV1ResponseResultsChannelsItemParams",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams",
    "ListenV1ResponseResultsChannelsItemSearchItemParams",
    "ListenV1ResponseResultsChannelsParams",
    "ListenV1ResponseResultsParams",
    "ListenV1ResponseResultsSummaryParams",
    "ListenV1ResponseResultsUtterancesItemParams",
    "ListenV1ResponseResultsUtterancesItemWordsItemParams",
    "ListenV1ResponseResultsUtterancesParams",
    "ListenV2KeytermParams",
    "OpenAiSpeakProviderParams",
    "OpenAiThinkProviderParams",
    "ProjectRequestResponseParams",
    "ReadV1RequestParams",
    "ReadV1RequestTextParams",
    "ReadV1RequestUrlParams",
    "ReadV1ResponseMetadataMetadataIntentsInfoParams",
    "ReadV1ResponseMetadataMetadataParams",
    "ReadV1ResponseMetadataMetadataSentimentInfoParams",
    "ReadV1ResponseMetadataMetadataSummaryInfoParams",
    "ReadV1ResponseMetadataMetadataTopicsInfoParams",
    "ReadV1ResponseMetadataParams",
    "ReadV1ResponseParams",
    "ReadV1ResponseResultsParams",
    "ReadV1ResponseResultsSummaryParams",
    "ReadV1ResponseResultsSummaryResultsParams",
    "ReadV1ResponseResultsSummaryResultsSummaryParams",
    "SharedIntentsParams",
    "SharedIntentsResultsIntentsParams",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItemParams",
    "SharedIntentsResultsIntentsSegmentsItemParams",
    "SharedIntentsResultsParams",
    "SharedSentimentsAverageParams",
    "SharedSentimentsParams",
    "SharedSentimentsSegmentsItemParams",
    "SharedTopicsParams",
    "SharedTopicsResultsParams",
    "SharedTopicsResultsTopicsParams",
    "SharedTopicsResultsTopicsSegmentsItemParams",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItemParams",
    "SpeakSettingsV1EndpointParams",
    "SpeakSettingsV1Params",
    "SpeakSettingsV1ProviderParams",
    "SpeakSettingsV1Provider_AwsPollyParams",
    "SpeakSettingsV1Provider_CartesiaParams",
    "SpeakSettingsV1Provider_DeepgramParams",
    "SpeakSettingsV1Provider_ElevenLabsParams",
    "SpeakSettingsV1Provider_OpenAiParams",
    "ThinkSettingsV1ContextLengthParams",
    "ThinkSettingsV1EndpointParams",
    "ThinkSettingsV1FunctionsItemEndpointParams",
    "ThinkSettingsV1FunctionsItemParams",
    "ThinkSettingsV1Params",
    "ThinkSettingsV1ProviderParams",
    "ThinkSettingsV1Provider_AnthropicParams",
    "ThinkSettingsV1Provider_AwsBedrockParams",
    "ThinkSettingsV1Provider_GoogleParams",
    "ThinkSettingsV1Provider_GroqParams",
    "ThinkSettingsV1Provider_OpenAiParams",
    "UpdateProjectMemberScopesV1ResponseParams",
    "UpdateProjectV1ResponseParams",
    "UsageBreakdownV1ResponseParams",
    "UsageBreakdownV1ResponseResolutionParams",
    "UsageBreakdownV1ResponseResultsItemGroupingParams",
    "UsageBreakdownV1ResponseResultsItemParams",
    "UsageFieldsV1ResponseModelsItemParams",
    "UsageFieldsV1ResponseParams",
    "UsageV1ResponseParams",
    "UsageV1ResponseResolutionParams",
]
