# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.agent_v1settings_audio_output_encoding import AgentV1SettingsAudioOutputEncoding


class AgentV1SettingsAudioOutputParams(typing_extensions.TypedDict):
    """
    Audio output configuration settings
    """

    encoding: typing_extensions.NotRequired[AgentV1SettingsAudioOutputEncoding]
    """
    Audio encoding format for streaming TTS output
    """

    sample_rate: typing_extensions.NotRequired[float]
    """
    Sample rate in Hz
    """

    bitrate: typing_extensions.NotRequired[float]
    """
    Audio bitrate in bits per second
    """

    container: typing_extensions.NotRequired[str]
    """
    Audio container format. If omitted, defaults to 'none'
    """
