# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResultsMetadataModelInfoParams(typing_extensions.TypedDict):
    name: str
    """
    The name of the model
    """

    version: str
    """
    The version of the model
    """

    arch: str
    """
    The arch of the model
    """
