# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_v1settings_agent import AgentV1SettingsAgentParams
from .agent_v1settings_audio import AgentV1SettingsAudioParams
from .agent_v1settings_flags import AgentV1SettingsFlagsParams


class AgentV1SettingsParams(typing_extensions.TypedDict):
    type: typing.Literal["Settings"]
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Tags to associate with the request
    """

    experimental: typing_extensions.NotRequired[bool]
    """
    To enable experimental features
    """

    flags: typing_extensions.NotRequired[AgentV1SettingsFlagsParams]
    mip_opt_out: typing_extensions.NotRequired[bool]
    """
    To opt out of Deepgram Model Improvement Program
    """

    audio: AgentV1SettingsAudioParams
    agent: AgentV1SettingsAgentParams
