# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class GetProjectBalanceV1ResponseParams(typing_extensions.TypedDict):
    balance_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the balance
    """

    amount: typing_extensions.NotRequired[float]
    """
    The amount of the balance
    """

    units: typing_extensions.NotRequired[str]
    """
    The units of the balance, such as "USD"
    """

    purchase_order_id: typing_extensions.NotRequired[str]
    """
    Description or reference of the purchase
    """
