# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.listen_v1close_stream_type import ListenV1CloseStreamType


class ListenV1CloseStreamParams(typing_extensions.TypedDict):
    type: ListenV1CloseStreamType
    """
    Message type identifier
    """
