# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_think_models_v1response_models_item import AgentThinkModelsV1ResponseModelsItemParams


class AgentThinkModelsV1ResponseParams(typing_extensions.TypedDict):
    models: typing.Sequence[AgentThinkModelsV1ResponseModelsItemParams]
