# This file was auto-generated by Fern from our API Definition.

import typing

BreakdownListRequestGroupingItem = typing.Union[
    typing.Literal["accessor", "deployment", "line_item", "tags"], typing.Any
]
