# This file was auto-generated by Fern from our API Definition.

import typing

BreakdownGetRequestGrouping = typing.Union[
    typing.Literal["accessor", "endpoint", "feature_set", "models", "method", "tags", "deployment"], typing.Any
]
