# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .listen_v1results_metadata_model_info import ListenV1ResultsMetadataModelInfoParams


class ListenV1ResultsMetadataParams(typing_extensions.TypedDict):
    request_id: str
    """
    The request ID
    """

    model_info: ListenV1ResultsMetadataModelInfoParams
    model_uuid: str
    """
    The model UUID
    """
