# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_search_item_hits_item import (
    ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams,
)


class ListenV1ResponseResultsChannelsItemSearchItemParams(typing_extensions.TypedDict):
    query: typing_extensions.NotRequired[str]
    hits: typing_extensions.NotRequired[typing.Sequence[ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams]]
