# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_think_models_v1response_models_item_id import AgentThinkModelsV1ResponseModelsItemIdParams
from .agent_think_models_v1response_models_item_one import AgentThinkModelsV1ResponseModelsItemOneParams
from .agent_think_models_v1response_models_item_three import AgentThinkModelsV1ResponseModelsItemThreeParams
from .agent_think_models_v1response_models_item_two import AgentThinkModelsV1ResponseModelsItemTwoParams
from .agent_think_models_v1response_models_item_zero import AgentThinkModelsV1ResponseModelsItemZeroParams

AgentThinkModelsV1ResponseModelsItemParams = typing.Union[
    AgentThinkModelsV1ResponseModelsItemZeroParams,
    AgentThinkModelsV1ResponseModelsItemOneParams,
    AgentThinkModelsV1ResponseModelsItemTwoParams,
    AgentThinkModelsV1ResponseModelsItemThreeParams,
    AgentThinkModelsV1ResponseModelsItemIdParams,
]
