# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListProjectKeysV1ResponseApiKeysItemMemberParams(typing_extensions.TypedDict):
    member_id: typing_extensions.NotRequired[str]
    email: typing_extensions.NotRequired[str]
