# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.aws_bedrock_think_provider_model import AwsBedrockThinkProviderModel
from .aws_bedrock_think_provider_credentials import AwsBedrockThinkProviderCredentialsParams


class AwsBedrockThinkProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["aws_bedrock"]
    model: AwsBedrockThinkProviderModel
    """
    AWS Bedrock model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    AWS Bedrock temperature (0-2)
    """

    credentials: typing_extensions.NotRequired[AwsBedrockThinkProviderCredentialsParams]
    """
    AWS credentials type (STS short-lived or IAM long-lived)
    """
