# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_results_summary_results import ReadV1ResponseResultsSummaryResultsParams


class ReadV1ResponseResultsSummaryParams(typing_extensions.TypedDict):
    """
    Output whenever `summary=true` is used
    """

    results: typing_extensions.NotRequired[ReadV1ResponseResultsSummaryResultsParams]
