# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SharedSentimentsAverageParams(typing_extensions.TypedDict):
    sentiment: typing_extensions.NotRequired[str]
    sentiment_score: typing_extensions.NotRequired[float]
