# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1AgentStartedSpeakingParams(typing_extensions.TypedDict):
    type: typing.Literal["AgentStartedSpeaking"]
    """
    Message type identifier for agent started speaking
    """

    total_latency: float
    """
    Seconds from receiving the user's utterance to producing the agent's reply
    """

    tts_latency: float
    """
    The portion of total latency attributable to text-to-speech
    """

    ttt_latency: float
    """
    The portion of total latency attributable to text-to-text (usually an LLM)
    """
