# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .aws_polly_speak_provider_credentials_type import AwsPollySpeakProviderCredentialsType


class AwsPollySpeakProviderCredentials(UniversalBaseModel):
    type: AwsPollySpeakProviderCredentialsType
    region: str
    access_key_id: str
    secret_access_key: str
    session_token: typing.Optional[str] = pydantic.Field(default=None)
    """
    Required for STS only
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
