# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .get_project_key_v1response_item_member import GetProjectKeyV1ResponseItemMemberParams


class GetProjectKeyV1ResponseItemParams(typing_extensions.TypedDict):
    member: typing_extensions.NotRequired[GetProjectKeyV1ResponseItemMemberParams]
