# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .agent_think_models_v1response import AgentThinkModelsV1Response
    from .agent_think_models_v1response_models_item import AgentThinkModelsV1ResponseModelsItem
    from .agent_think_models_v1response_models_item_id import AgentThinkModelsV1ResponseModelsItemId
    from .agent_think_models_v1response_models_item_one import AgentThinkModelsV1ResponseModelsItemOne
    from .agent_think_models_v1response_models_item_one_id import AgentThinkModelsV1ResponseModelsItemOneId
    from .agent_think_models_v1response_models_item_three import AgentThinkModelsV1ResponseModelsItemThree
    from .agent_think_models_v1response_models_item_two import AgentThinkModelsV1ResponseModelsItemTwo
    from .agent_think_models_v1response_models_item_two_id import AgentThinkModelsV1ResponseModelsItemTwoId
    from .agent_think_models_v1response_models_item_zero import AgentThinkModelsV1ResponseModelsItemZero
    from .agent_think_models_v1response_models_item_zero_id import AgentThinkModelsV1ResponseModelsItemZeroId
    from .anthropic import Anthropic
    from .anthropic_think_provider_model import AnthropicThinkProviderModel
    from .aws_bedrock_think_provider import AwsBedrockThinkProvider
    from .aws_bedrock_think_provider_credentials import AwsBedrockThinkProviderCredentials
    from .aws_bedrock_think_provider_credentials_type import AwsBedrockThinkProviderCredentialsType
    from .aws_bedrock_think_provider_model import AwsBedrockThinkProviderModel
    from .aws_polly_speak_provider import AwsPollySpeakProvider
    from .aws_polly_speak_provider_credentials import AwsPollySpeakProviderCredentials
    from .aws_polly_speak_provider_credentials_type import AwsPollySpeakProviderCredentialsType
    from .aws_polly_speak_provider_engine import AwsPollySpeakProviderEngine
    from .aws_polly_speak_provider_voice import AwsPollySpeakProviderVoice
    from .billing_breakdown_v1response import BillingBreakdownV1Response
    from .billing_breakdown_v1response_resolution import BillingBreakdownV1ResponseResolution
    from .billing_breakdown_v1response_results_item import BillingBreakdownV1ResponseResultsItem
    from .billing_breakdown_v1response_results_item_grouping import BillingBreakdownV1ResponseResultsItemGrouping
    from .cartesia import Cartesia
    from .cartesia_speak_provider_model_id import CartesiaSpeakProviderModelId
    from .cartesia_speak_provider_voice import CartesiaSpeakProviderVoice
    from .create_key_v1request_one import CreateKeyV1RequestOne
    from .create_key_v1response import CreateKeyV1Response
    from .create_project_distribution_credentials_v1response import CreateProjectDistributionCredentialsV1Response
    from .create_project_distribution_credentials_v1response_distribution_credentials import (
        CreateProjectDistributionCredentialsV1ResponseDistributionCredentials,
    )
    from .create_project_distribution_credentials_v1response_member import (
        CreateProjectDistributionCredentialsV1ResponseMember,
    )
    from .create_project_invite_v1response import CreateProjectInviteV1Response
    from .deepgram import Deepgram
    from .deepgram_speak_provider_model import DeepgramSpeakProviderModel
    from .delete_project_invite_v1response import DeleteProjectInviteV1Response
    from .delete_project_key_v1response import DeleteProjectKeyV1Response
    from .delete_project_member_v1response import DeleteProjectMemberV1Response
    from .delete_project_v1response import DeleteProjectV1Response
    from .eleven_labs_speak_provider import ElevenLabsSpeakProvider
    from .eleven_labs_speak_provider_model_id import ElevenLabsSpeakProviderModelId
    from .error_response import ErrorResponse
    from .error_response_legacy_error import ErrorResponseLegacyError
    from .error_response_modern_error import ErrorResponseModernError
    from .error_response_text_error import ErrorResponseTextError
    from .get_model_v1response import GetModelV1Response
    from .get_model_v1response_batch import GetModelV1ResponseBatch
    from .get_model_v1response_metadata import GetModelV1ResponseMetadata
    from .get_model_v1response_metadata_metadata import GetModelV1ResponseMetadataMetadata
    from .get_project_balance_v1response import GetProjectBalanceV1Response
    from .get_project_distribution_credentials_v1response import GetProjectDistributionCredentialsV1Response
    from .get_project_distribution_credentials_v1response_distribution_credentials import (
        GetProjectDistributionCredentialsV1ResponseDistributionCredentials,
    )
    from .get_project_distribution_credentials_v1response_member import (
        GetProjectDistributionCredentialsV1ResponseMember,
    )
    from .get_project_key_v1response import GetProjectKeyV1Response
    from .get_project_key_v1response_item import GetProjectKeyV1ResponseItem
    from .get_project_key_v1response_item_member import GetProjectKeyV1ResponseItemMember
    from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKey
    from .get_project_request_v1response import GetProjectRequestV1Response
    from .get_project_v1response import GetProjectV1Response
    from .google import Google
    from .google_think_provider_model import GoogleThinkProviderModel
    from .grant_v1response import GrantV1Response
    from .groq import Groq
    from .leave_project_v1response import LeaveProjectV1Response
    from .list_billing_fields_v1response import ListBillingFieldsV1Response
    from .list_billing_fields_v1response_deployments_item import ListBillingFieldsV1ResponseDeploymentsItem
    from .list_models_v1response import ListModelsV1Response
    from .list_models_v1response_stt_models import ListModelsV1ResponseSttModels
    from .list_models_v1response_tts_models import ListModelsV1ResponseTtsModels
    from .list_models_v1response_tts_models_metadata import ListModelsV1ResponseTtsModelsMetadata
    from .list_project_balances_v1response import ListProjectBalancesV1Response
    from .list_project_balances_v1response_balances_item import ListProjectBalancesV1ResponseBalancesItem
    from .list_project_distribution_credentials_v1response import ListProjectDistributionCredentialsV1Response
    from .list_project_distribution_credentials_v1response_distribution_credentials_item import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_member import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember,
    )
    from .list_project_invites_v1response import ListProjectInvitesV1Response
    from .list_project_invites_v1response_invites_item import ListProjectInvitesV1ResponseInvitesItem
    from .list_project_keys_v1response import ListProjectKeysV1Response
    from .list_project_keys_v1response_api_keys_item import ListProjectKeysV1ResponseApiKeysItem
    from .list_project_keys_v1response_api_keys_item_api_key import ListProjectKeysV1ResponseApiKeysItemApiKey
    from .list_project_keys_v1response_api_keys_item_member import ListProjectKeysV1ResponseApiKeysItemMember
    from .list_project_member_scopes_v1response import ListProjectMemberScopesV1Response
    from .list_project_members_v1response import ListProjectMembersV1Response
    from .list_project_members_v1response_members_item import ListProjectMembersV1ResponseMembersItem
    from .list_project_purchases_v1response import ListProjectPurchasesV1Response
    from .list_project_purchases_v1response_orders_item import ListProjectPurchasesV1ResponseOrdersItem
    from .list_project_requests_v1response import ListProjectRequestsV1Response
    from .list_projects_v1response import ListProjectsV1Response
    from .list_projects_v1response_projects_item import ListProjectsV1ResponseProjectsItem
    from .listen_v1accepted_response import ListenV1AcceptedResponse
    from .listen_v1callback import ListenV1Callback
    from .listen_v1callback_method import ListenV1CallbackMethod
    from .listen_v1channels import ListenV1Channels
    from .listen_v1detect_entities import ListenV1DetectEntities
    from .listen_v1diarize import ListenV1Diarize
    from .listen_v1dictation import ListenV1Dictation
    from .listen_v1encoding import ListenV1Encoding
    from .listen_v1endpointing import ListenV1Endpointing
    from .listen_v1extra import ListenV1Extra
    from .listen_v1interim_results import ListenV1InterimResults
    from .listen_v1keyterm import ListenV1Keyterm
    from .listen_v1keywords import ListenV1Keywords
    from .listen_v1language import ListenV1Language
    from .listen_v1mip_opt_out import ListenV1MipOptOut
    from .listen_v1model import ListenV1Model
    from .listen_v1multichannel import ListenV1Multichannel
    from .listen_v1numerals import ListenV1Numerals
    from .listen_v1profanity_filter import ListenV1ProfanityFilter
    from .listen_v1punctuate import ListenV1Punctuate
    from .listen_v1redact import ListenV1Redact
    from .listen_v1replace import ListenV1Replace
    from .listen_v1request_file import ListenV1RequestFile
    from .listen_v1response import ListenV1Response
    from .listen_v1response_metadata import ListenV1ResponseMetadata
    from .listen_v1response_metadata_intents_info import ListenV1ResponseMetadataIntentsInfo
    from .listen_v1response_metadata_sentiment_info import ListenV1ResponseMetadataSentimentInfo
    from .listen_v1response_metadata_summary_info import ListenV1ResponseMetadataSummaryInfo
    from .listen_v1response_metadata_topics_info import ListenV1ResponseMetadataTopicsInfo
    from .listen_v1response_results import ListenV1ResponseResults
    from .listen_v1response_results_channels import ListenV1ResponseResultsChannels
    from .listen_v1response_results_channels_item import ListenV1ResponseResultsChannelsItem
    from .listen_v1response_results_channels_item_alternatives_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_entities_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_summaries_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_topics_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_words_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem,
    )
    from .listen_v1response_results_channels_item_search_item import ListenV1ResponseResultsChannelsItemSearchItem
    from .listen_v1response_results_channels_item_search_item_hits_item import (
        ListenV1ResponseResultsChannelsItemSearchItemHitsItem,
    )
    from .listen_v1response_results_summary import ListenV1ResponseResultsSummary
    from .listen_v1response_results_utterances import ListenV1ResponseResultsUtterances
    from .listen_v1response_results_utterances_item import ListenV1ResponseResultsUtterancesItem
    from .listen_v1response_results_utterances_item_words_item import ListenV1ResponseResultsUtterancesItemWordsItem
    from .listen_v1sample_rate import ListenV1SampleRate
    from .listen_v1search import ListenV1Search
    from .listen_v1smart_format import ListenV1SmartFormat
    from .listen_v1tag import ListenV1Tag
    from .listen_v1utterance_end_ms import ListenV1UtteranceEndMs
    from .listen_v1vad_events import ListenV1VadEvents
    from .listen_v1version import ListenV1Version
    from .listen_v2eager_eot_threshold import ListenV2EagerEotThreshold
    from .listen_v2encoding import ListenV2Encoding
    from .listen_v2eot_threshold import ListenV2EotThreshold
    from .listen_v2eot_timeout_ms import ListenV2EotTimeoutMs
    from .listen_v2keyterm import ListenV2Keyterm
    from .listen_v2mip_opt_out import ListenV2MipOptOut
    from .listen_v2model import ListenV2Model
    from .listen_v2sample_rate import ListenV2SampleRate
    from .listen_v2tag import ListenV2Tag
    from .open_ai_speak_provider import OpenAiSpeakProvider
    from .open_ai_speak_provider_model import OpenAiSpeakProviderModel
    from .open_ai_speak_provider_voice import OpenAiSpeakProviderVoice
    from .open_ai_think_provider import OpenAiThinkProvider
    from .open_ai_think_provider_model import OpenAiThinkProviderModel
    from .project_request_response import ProjectRequestResponse
    from .read_v1request import ReadV1Request
    from .read_v1request_text import ReadV1RequestText
    from .read_v1request_url import ReadV1RequestUrl
    from .read_v1response import ReadV1Response
    from .read_v1response_metadata import ReadV1ResponseMetadata
    from .read_v1response_metadata_metadata import ReadV1ResponseMetadataMetadata
    from .read_v1response_metadata_metadata_intents_info import ReadV1ResponseMetadataMetadataIntentsInfo
    from .read_v1response_metadata_metadata_sentiment_info import ReadV1ResponseMetadataMetadataSentimentInfo
    from .read_v1response_metadata_metadata_summary_info import ReadV1ResponseMetadataMetadataSummaryInfo
    from .read_v1response_metadata_metadata_topics_info import ReadV1ResponseMetadataMetadataTopicsInfo
    from .read_v1response_results import ReadV1ResponseResults
    from .read_v1response_results_summary import ReadV1ResponseResultsSummary
    from .read_v1response_results_summary_results import ReadV1ResponseResultsSummaryResults
    from .read_v1response_results_summary_results_summary import ReadV1ResponseResultsSummaryResultsSummary
    from .shared_intents import SharedIntents
    from .shared_intents_results import SharedIntentsResults
    from .shared_intents_results_intents import SharedIntentsResultsIntents
    from .shared_intents_results_intents_segments_item import SharedIntentsResultsIntentsSegmentsItem
    from .shared_intents_results_intents_segments_item_intents_item import (
        SharedIntentsResultsIntentsSegmentsItemIntentsItem,
    )
    from .shared_sentiments import SharedSentiments
    from .shared_sentiments_average import SharedSentimentsAverage
    from .shared_sentiments_segments_item import SharedSentimentsSegmentsItem
    from .shared_topics import SharedTopics
    from .shared_topics_results import SharedTopicsResults
    from .shared_topics_results_topics import SharedTopicsResultsTopics
    from .shared_topics_results_topics_segments_item import SharedTopicsResultsTopicsSegmentsItem
    from .shared_topics_results_topics_segments_item_topics_item import SharedTopicsResultsTopicsSegmentsItemTopicsItem
    from .speak_settings_v1 import SpeakSettingsV1
    from .speak_settings_v1endpoint import SpeakSettingsV1Endpoint
    from .speak_settings_v1provider import (
        SpeakSettingsV1Provider,
        SpeakSettingsV1Provider_AwsPolly,
        SpeakSettingsV1Provider_Cartesia,
        SpeakSettingsV1Provider_Deepgram,
        SpeakSettingsV1Provider_ElevenLabs,
        SpeakSettingsV1Provider_OpenAi,
    )
    from .speak_v1encoding import SpeakV1Encoding
    from .speak_v1mip_opt_out import SpeakV1MipOptOut
    from .speak_v1model import SpeakV1Model
    from .speak_v1response import SpeakV1Response
    from .speak_v1sample_rate import SpeakV1SampleRate
    from .think_settings_v1 import ThinkSettingsV1
    from .think_settings_v1context_length import ThinkSettingsV1ContextLength
    from .think_settings_v1endpoint import ThinkSettingsV1Endpoint
    from .think_settings_v1functions_item import ThinkSettingsV1FunctionsItem
    from .think_settings_v1functions_item_endpoint import ThinkSettingsV1FunctionsItemEndpoint
    from .think_settings_v1provider import (
        ThinkSettingsV1Provider,
        ThinkSettingsV1Provider_Anthropic,
        ThinkSettingsV1Provider_AwsBedrock,
        ThinkSettingsV1Provider_Google,
        ThinkSettingsV1Provider_Groq,
        ThinkSettingsV1Provider_OpenAi,
    )
    from .update_project_member_scopes_v1response import UpdateProjectMemberScopesV1Response
    from .update_project_v1response import UpdateProjectV1Response
    from .usage_breakdown_v1response import UsageBreakdownV1Response
    from .usage_breakdown_v1response_resolution import UsageBreakdownV1ResponseResolution
    from .usage_breakdown_v1response_results_item import UsageBreakdownV1ResponseResultsItem
    from .usage_breakdown_v1response_results_item_grouping import UsageBreakdownV1ResponseResultsItemGrouping
    from .usage_fields_v1response import UsageFieldsV1Response
    from .usage_fields_v1response_models_item import UsageFieldsV1ResponseModelsItem
    from .usage_v1response import UsageV1Response
    from .usage_v1response_resolution import UsageV1ResponseResolution
_dynamic_imports: typing.Dict[str, str] = {
    "AgentThinkModelsV1Response": ".agent_think_models_v1response",
    "AgentThinkModelsV1ResponseModelsItem": ".agent_think_models_v1response_models_item",
    "AgentThinkModelsV1ResponseModelsItemId": ".agent_think_models_v1response_models_item_id",
    "AgentThinkModelsV1ResponseModelsItemOne": ".agent_think_models_v1response_models_item_one",
    "AgentThinkModelsV1ResponseModelsItemOneId": ".agent_think_models_v1response_models_item_one_id",
    "AgentThinkModelsV1ResponseModelsItemThree": ".agent_think_models_v1response_models_item_three",
    "AgentThinkModelsV1ResponseModelsItemTwo": ".agent_think_models_v1response_models_item_two",
    "AgentThinkModelsV1ResponseModelsItemTwoId": ".agent_think_models_v1response_models_item_two_id",
    "AgentThinkModelsV1ResponseModelsItemZero": ".agent_think_models_v1response_models_item_zero",
    "AgentThinkModelsV1ResponseModelsItemZeroId": ".agent_think_models_v1response_models_item_zero_id",
    "Anthropic": ".anthropic",
    "AnthropicThinkProviderModel": ".anthropic_think_provider_model",
    "AwsBedrockThinkProvider": ".aws_bedrock_think_provider",
    "AwsBedrockThinkProviderCredentials": ".aws_bedrock_think_provider_credentials",
    "AwsBedrockThinkProviderCredentialsType": ".aws_bedrock_think_provider_credentials_type",
    "AwsBedrockThinkProviderModel": ".aws_bedrock_think_provider_model",
    "AwsPollySpeakProvider": ".aws_polly_speak_provider",
    "AwsPollySpeakProviderCredentials": ".aws_polly_speak_provider_credentials",
    "AwsPollySpeakProviderCredentialsType": ".aws_polly_speak_provider_credentials_type",
    "AwsPollySpeakProviderEngine": ".aws_polly_speak_provider_engine",
    "AwsPollySpeakProviderVoice": ".aws_polly_speak_provider_voice",
    "BillingBreakdownV1Response": ".billing_breakdown_v1response",
    "BillingBreakdownV1ResponseResolution": ".billing_breakdown_v1response_resolution",
    "BillingBreakdownV1ResponseResultsItem": ".billing_breakdown_v1response_results_item",
    "BillingBreakdownV1ResponseResultsItemGrouping": ".billing_breakdown_v1response_results_item_grouping",
    "Cartesia": ".cartesia",
    "CartesiaSpeakProviderModelId": ".cartesia_speak_provider_model_id",
    "CartesiaSpeakProviderVoice": ".cartesia_speak_provider_voice",
    "CreateKeyV1RequestOne": ".create_key_v1request_one",
    "CreateKeyV1Response": ".create_key_v1response",
    "CreateProjectDistributionCredentialsV1Response": ".create_project_distribution_credentials_v1response",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentials": ".create_project_distribution_credentials_v1response_distribution_credentials",
    "CreateProjectDistributionCredentialsV1ResponseMember": ".create_project_distribution_credentials_v1response_member",
    "CreateProjectInviteV1Response": ".create_project_invite_v1response",
    "Deepgram": ".deepgram",
    "DeepgramSpeakProviderModel": ".deepgram_speak_provider_model",
    "DeleteProjectInviteV1Response": ".delete_project_invite_v1response",
    "DeleteProjectKeyV1Response": ".delete_project_key_v1response",
    "DeleteProjectMemberV1Response": ".delete_project_member_v1response",
    "DeleteProjectV1Response": ".delete_project_v1response",
    "ElevenLabsSpeakProvider": ".eleven_labs_speak_provider",
    "ElevenLabsSpeakProviderModelId": ".eleven_labs_speak_provider_model_id",
    "ErrorResponse": ".error_response",
    "ErrorResponseLegacyError": ".error_response_legacy_error",
    "ErrorResponseModernError": ".error_response_modern_error",
    "ErrorResponseTextError": ".error_response_text_error",
    "GetModelV1Response": ".get_model_v1response",
    "GetModelV1ResponseBatch": ".get_model_v1response_batch",
    "GetModelV1ResponseMetadata": ".get_model_v1response_metadata",
    "GetModelV1ResponseMetadataMetadata": ".get_model_v1response_metadata_metadata",
    "GetProjectBalanceV1Response": ".get_project_balance_v1response",
    "GetProjectDistributionCredentialsV1Response": ".get_project_distribution_credentials_v1response",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentials": ".get_project_distribution_credentials_v1response_distribution_credentials",
    "GetProjectDistributionCredentialsV1ResponseMember": ".get_project_distribution_credentials_v1response_member",
    "GetProjectKeyV1Response": ".get_project_key_v1response",
    "GetProjectKeyV1ResponseItem": ".get_project_key_v1response_item",
    "GetProjectKeyV1ResponseItemMember": ".get_project_key_v1response_item_member",
    "GetProjectKeyV1ResponseItemMemberApiKey": ".get_project_key_v1response_item_member_api_key",
    "GetProjectRequestV1Response": ".get_project_request_v1response",
    "GetProjectV1Response": ".get_project_v1response",
    "Google": ".google",
    "GoogleThinkProviderModel": ".google_think_provider_model",
    "GrantV1Response": ".grant_v1response",
    "Groq": ".groq",
    "LeaveProjectV1Response": ".leave_project_v1response",
    "ListBillingFieldsV1Response": ".list_billing_fields_v1response",
    "ListBillingFieldsV1ResponseDeploymentsItem": ".list_billing_fields_v1response_deployments_item",
    "ListModelsV1Response": ".list_models_v1response",
    "ListModelsV1ResponseSttModels": ".list_models_v1response_stt_models",
    "ListModelsV1ResponseTtsModels": ".list_models_v1response_tts_models",
    "ListModelsV1ResponseTtsModelsMetadata": ".list_models_v1response_tts_models_metadata",
    "ListProjectBalancesV1Response": ".list_project_balances_v1response",
    "ListProjectBalancesV1ResponseBalancesItem": ".list_project_balances_v1response_balances_item",
    "ListProjectDistributionCredentialsV1Response": ".list_project_distribution_credentials_v1response",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem": ".list_project_distribution_credentials_v1response_distribution_credentials_item",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials": ".list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember": ".list_project_distribution_credentials_v1response_distribution_credentials_item_member",
    "ListProjectInvitesV1Response": ".list_project_invites_v1response",
    "ListProjectInvitesV1ResponseInvitesItem": ".list_project_invites_v1response_invites_item",
    "ListProjectKeysV1Response": ".list_project_keys_v1response",
    "ListProjectKeysV1ResponseApiKeysItem": ".list_project_keys_v1response_api_keys_item",
    "ListProjectKeysV1ResponseApiKeysItemApiKey": ".list_project_keys_v1response_api_keys_item_api_key",
    "ListProjectKeysV1ResponseApiKeysItemMember": ".list_project_keys_v1response_api_keys_item_member",
    "ListProjectMemberScopesV1Response": ".list_project_member_scopes_v1response",
    "ListProjectMembersV1Response": ".list_project_members_v1response",
    "ListProjectMembersV1ResponseMembersItem": ".list_project_members_v1response_members_item",
    "ListProjectPurchasesV1Response": ".list_project_purchases_v1response",
    "ListProjectPurchasesV1ResponseOrdersItem": ".list_project_purchases_v1response_orders_item",
    "ListProjectRequestsV1Response": ".list_project_requests_v1response",
    "ListProjectsV1Response": ".list_projects_v1response",
    "ListProjectsV1ResponseProjectsItem": ".list_projects_v1response_projects_item",
    "ListenV1AcceptedResponse": ".listen_v1accepted_response",
    "ListenV1Callback": ".listen_v1callback",
    "ListenV1CallbackMethod": ".listen_v1callback_method",
    "ListenV1Channels": ".listen_v1channels",
    "ListenV1DetectEntities": ".listen_v1detect_entities",
    "ListenV1Diarize": ".listen_v1diarize",
    "ListenV1Dictation": ".listen_v1dictation",
    "ListenV1Encoding": ".listen_v1encoding",
    "ListenV1Endpointing": ".listen_v1endpointing",
    "ListenV1Extra": ".listen_v1extra",
    "ListenV1InterimResults": ".listen_v1interim_results",
    "ListenV1Keyterm": ".listen_v1keyterm",
    "ListenV1Keywords": ".listen_v1keywords",
    "ListenV1Language": ".listen_v1language",
    "ListenV1MipOptOut": ".listen_v1mip_opt_out",
    "ListenV1Model": ".listen_v1model",
    "ListenV1Multichannel": ".listen_v1multichannel",
    "ListenV1Numerals": ".listen_v1numerals",
    "ListenV1ProfanityFilter": ".listen_v1profanity_filter",
    "ListenV1Punctuate": ".listen_v1punctuate",
    "ListenV1Redact": ".listen_v1redact",
    "ListenV1Replace": ".listen_v1replace",
    "ListenV1RequestFile": ".listen_v1request_file",
    "ListenV1Response": ".listen_v1response",
    "ListenV1ResponseMetadata": ".listen_v1response_metadata",
    "ListenV1ResponseMetadataIntentsInfo": ".listen_v1response_metadata_intents_info",
    "ListenV1ResponseMetadataSentimentInfo": ".listen_v1response_metadata_sentiment_info",
    "ListenV1ResponseMetadataSummaryInfo": ".listen_v1response_metadata_summary_info",
    "ListenV1ResponseMetadataTopicsInfo": ".listen_v1response_metadata_topics_info",
    "ListenV1ResponseResults": ".listen_v1response_results",
    "ListenV1ResponseResultsChannels": ".listen_v1response_results_channels",
    "ListenV1ResponseResultsChannelsItem": ".listen_v1response_results_channels_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItem": ".listen_v1response_results_channels_item_alternatives_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem": ".listen_v1response_results_channels_item_alternatives_item_entities_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs": ".listen_v1response_results_channels_item_alternatives_item_paragraphs",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem": ".listen_v1response_results_channels_item_alternatives_item_summaries_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem": ".listen_v1response_results_channels_item_alternatives_item_topics_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem": ".listen_v1response_results_channels_item_alternatives_item_words_item",
    "ListenV1ResponseResultsChannelsItemSearchItem": ".listen_v1response_results_channels_item_search_item",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItem": ".listen_v1response_results_channels_item_search_item_hits_item",
    "ListenV1ResponseResultsSummary": ".listen_v1response_results_summary",
    "ListenV1ResponseResultsUtterances": ".listen_v1response_results_utterances",
    "ListenV1ResponseResultsUtterancesItem": ".listen_v1response_results_utterances_item",
    "ListenV1ResponseResultsUtterancesItemWordsItem": ".listen_v1response_results_utterances_item_words_item",
    "ListenV1SampleRate": ".listen_v1sample_rate",
    "ListenV1Search": ".listen_v1search",
    "ListenV1SmartFormat": ".listen_v1smart_format",
    "ListenV1Tag": ".listen_v1tag",
    "ListenV1UtteranceEndMs": ".listen_v1utterance_end_ms",
    "ListenV1VadEvents": ".listen_v1vad_events",
    "ListenV1Version": ".listen_v1version",
    "ListenV2EagerEotThreshold": ".listen_v2eager_eot_threshold",
    "ListenV2Encoding": ".listen_v2encoding",
    "ListenV2EotThreshold": ".listen_v2eot_threshold",
    "ListenV2EotTimeoutMs": ".listen_v2eot_timeout_ms",
    "ListenV2Keyterm": ".listen_v2keyterm",
    "ListenV2MipOptOut": ".listen_v2mip_opt_out",
    "ListenV2Model": ".listen_v2model",
    "ListenV2SampleRate": ".listen_v2sample_rate",
    "ListenV2Tag": ".listen_v2tag",
    "OpenAiSpeakProvider": ".open_ai_speak_provider",
    "OpenAiSpeakProviderModel": ".open_ai_speak_provider_model",
    "OpenAiSpeakProviderVoice": ".open_ai_speak_provider_voice",
    "OpenAiThinkProvider": ".open_ai_think_provider",
    "OpenAiThinkProviderModel": ".open_ai_think_provider_model",
    "ProjectRequestResponse": ".project_request_response",
    "ReadV1Request": ".read_v1request",
    "ReadV1RequestText": ".read_v1request_text",
    "ReadV1RequestUrl": ".read_v1request_url",
    "ReadV1Response": ".read_v1response",
    "ReadV1ResponseMetadata": ".read_v1response_metadata",
    "ReadV1ResponseMetadataMetadata": ".read_v1response_metadata_metadata",
    "ReadV1ResponseMetadataMetadataIntentsInfo": ".read_v1response_metadata_metadata_intents_info",
    "ReadV1ResponseMetadataMetadataSentimentInfo": ".read_v1response_metadata_metadata_sentiment_info",
    "ReadV1ResponseMetadataMetadataSummaryInfo": ".read_v1response_metadata_metadata_summary_info",
    "ReadV1ResponseMetadataMetadataTopicsInfo": ".read_v1response_metadata_metadata_topics_info",
    "ReadV1ResponseResults": ".read_v1response_results",
    "ReadV1ResponseResultsSummary": ".read_v1response_results_summary",
    "ReadV1ResponseResultsSummaryResults": ".read_v1response_results_summary_results",
    "ReadV1ResponseResultsSummaryResultsSummary": ".read_v1response_results_summary_results_summary",
    "SharedIntents": ".shared_intents",
    "SharedIntentsResults": ".shared_intents_results",
    "SharedIntentsResultsIntents": ".shared_intents_results_intents",
    "SharedIntentsResultsIntentsSegmentsItem": ".shared_intents_results_intents_segments_item",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItem": ".shared_intents_results_intents_segments_item_intents_item",
    "SharedSentiments": ".shared_sentiments",
    "SharedSentimentsAverage": ".shared_sentiments_average",
    "SharedSentimentsSegmentsItem": ".shared_sentiments_segments_item",
    "SharedTopics": ".shared_topics",
    "SharedTopicsResults": ".shared_topics_results",
    "SharedTopicsResultsTopics": ".shared_topics_results_topics",
    "SharedTopicsResultsTopicsSegmentsItem": ".shared_topics_results_topics_segments_item",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItem": ".shared_topics_results_topics_segments_item_topics_item",
    "SpeakSettingsV1": ".speak_settings_v1",
    "SpeakSettingsV1Endpoint": ".speak_settings_v1endpoint",
    "SpeakSettingsV1Provider": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_AwsPolly": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_Cartesia": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_Deepgram": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_ElevenLabs": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_OpenAi": ".speak_settings_v1provider",
    "SpeakV1Encoding": ".speak_v1encoding",
    "SpeakV1MipOptOut": ".speak_v1mip_opt_out",
    "SpeakV1Model": ".speak_v1model",
    "SpeakV1Response": ".speak_v1response",
    "SpeakV1SampleRate": ".speak_v1sample_rate",
    "ThinkSettingsV1": ".think_settings_v1",
    "ThinkSettingsV1ContextLength": ".think_settings_v1context_length",
    "ThinkSettingsV1Endpoint": ".think_settings_v1endpoint",
    "ThinkSettingsV1FunctionsItem": ".think_settings_v1functions_item",
    "ThinkSettingsV1FunctionsItemEndpoint": ".think_settings_v1functions_item_endpoint",
    "ThinkSettingsV1Provider": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_Anthropic": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_AwsBedrock": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_Google": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_Groq": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_OpenAi": ".think_settings_v1provider",
    "UpdateProjectMemberScopesV1Response": ".update_project_member_scopes_v1response",
    "UpdateProjectV1Response": ".update_project_v1response",
    "UsageBreakdownV1Response": ".usage_breakdown_v1response",
    "UsageBreakdownV1ResponseResolution": ".usage_breakdown_v1response_resolution",
    "UsageBreakdownV1ResponseResultsItem": ".usage_breakdown_v1response_results_item",
    "UsageBreakdownV1ResponseResultsItemGrouping": ".usage_breakdown_v1response_results_item_grouping",
    "UsageFieldsV1Response": ".usage_fields_v1response",
    "UsageFieldsV1ResponseModelsItem": ".usage_fields_v1response_models_item",
    "UsageV1Response": ".usage_v1response",
    "UsageV1ResponseResolution": ".usage_v1response_resolution",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentThinkModelsV1Response",
    "AgentThinkModelsV1ResponseModelsItem",
    "AgentThinkModelsV1ResponseModelsItemId",
    "AgentThinkModelsV1ResponseModelsItemOne",
    "AgentThinkModelsV1ResponseModelsItemOneId",
    "AgentThinkModelsV1ResponseModelsItemThree",
    "AgentThinkModelsV1ResponseModelsItemTwo",
    "AgentThinkModelsV1ResponseModelsItemTwoId",
    "AgentThinkModelsV1ResponseModelsItemZero",
    "AgentThinkModelsV1ResponseModelsItemZeroId",
    "Anthropic",
    "AnthropicThinkProviderModel",
    "AwsBedrockThinkProvider",
    "AwsBedrockThinkProviderCredentials",
    "AwsBedrockThinkProviderCredentialsType",
    "AwsBedrockThinkProviderModel",
    "AwsPollySpeakProvider",
    "AwsPollySpeakProviderCredentials",
    "AwsPollySpeakProviderCredentialsType",
    "AwsPollySpeakProviderEngine",
    "AwsPollySpeakProviderVoice",
    "BillingBreakdownV1Response",
    "BillingBreakdownV1ResponseResolution",
    "BillingBreakdownV1ResponseResultsItem",
    "BillingBreakdownV1ResponseResultsItemGrouping",
    "Cartesia",
    "CartesiaSpeakProviderModelId",
    "CartesiaSpeakProviderVoice",
    "CreateKeyV1RequestOne",
    "CreateKeyV1Response",
    "CreateProjectDistributionCredentialsV1Response",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentials",
    "CreateProjectDistributionCredentialsV1ResponseMember",
    "CreateProjectInviteV1Response",
    "Deepgram",
    "DeepgramSpeakProviderModel",
    "DeleteProjectInviteV1Response",
    "DeleteProjectKeyV1Response",
    "DeleteProjectMemberV1Response",
    "DeleteProjectV1Response",
    "ElevenLabsSpeakProvider",
    "ElevenLabsSpeakProviderModelId",
    "ErrorResponse",
    "ErrorResponseLegacyError",
    "ErrorResponseModernError",
    "ErrorResponseTextError",
    "GetModelV1Response",
    "GetModelV1ResponseBatch",
    "GetModelV1ResponseMetadata",
    "GetModelV1ResponseMetadataMetadata",
    "GetProjectBalanceV1Response",
    "GetProjectDistributionCredentialsV1Response",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentials",
    "GetProjectDistributionCredentialsV1ResponseMember",
    "GetProjectKeyV1Response",
    "GetProjectKeyV1ResponseItem",
    "GetProjectKeyV1ResponseItemMember",
    "GetProjectKeyV1ResponseItemMemberApiKey",
    "GetProjectRequestV1Response",
    "GetProjectV1Response",
    "Google",
    "GoogleThinkProviderModel",
    "GrantV1Response",
    "Groq",
    "LeaveProjectV1Response",
    "ListBillingFieldsV1Response",
    "ListBillingFieldsV1ResponseDeploymentsItem",
    "ListModelsV1Response",
    "ListModelsV1ResponseSttModels",
    "ListModelsV1ResponseTtsModels",
    "ListModelsV1ResponseTtsModelsMetadata",
    "ListProjectBalancesV1Response",
    "ListProjectBalancesV1ResponseBalancesItem",
    "ListProjectDistributionCredentialsV1Response",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember",
    "ListProjectInvitesV1Response",
    "ListProjectInvitesV1ResponseInvitesItem",
    "ListProjectKeysV1Response",
    "ListProjectKeysV1ResponseApiKeysItem",
    "ListProjectKeysV1ResponseApiKeysItemApiKey",
    "ListProjectKeysV1ResponseApiKeysItemMember",
    "ListProjectMemberScopesV1Response",
    "ListProjectMembersV1Response",
    "ListProjectMembersV1ResponseMembersItem",
    "ListProjectPurchasesV1Response",
    "ListProjectPurchasesV1ResponseOrdersItem",
    "ListProjectRequestsV1Response",
    "ListProjectsV1Response",
    "ListProjectsV1ResponseProjectsItem",
    "ListenV1AcceptedResponse",
    "ListenV1Callback",
    "ListenV1CallbackMethod",
    "ListenV1Channels",
    "ListenV1DetectEntities",
    "ListenV1Diarize",
    "ListenV1Dictation",
    "ListenV1Encoding",
    "ListenV1Endpointing",
    "ListenV1Extra",
    "ListenV1InterimResults",
    "ListenV1Keyterm",
    "ListenV1Keywords",
    "ListenV1Language",
    "ListenV1MipOptOut",
    "ListenV1Model",
    "ListenV1Multichannel",
    "ListenV1Numerals",
    "ListenV1ProfanityFilter",
    "ListenV1Punctuate",
    "ListenV1Redact",
    "ListenV1Replace",
    "ListenV1RequestFile",
    "ListenV1Response",
    "ListenV1ResponseMetadata",
    "ListenV1ResponseMetadataIntentsInfo",
    "ListenV1ResponseMetadataSentimentInfo",
    "ListenV1ResponseMetadataSummaryInfo",
    "ListenV1ResponseMetadataTopicsInfo",
    "ListenV1ResponseResults",
    "ListenV1ResponseResultsChannels",
    "ListenV1ResponseResultsChannelsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem",
    "ListenV1ResponseResultsChannelsItemSearchItem",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItem",
    "ListenV1ResponseResultsSummary",
    "ListenV1ResponseResultsUtterances",
    "ListenV1ResponseResultsUtterancesItem",
    "ListenV1ResponseResultsUtterancesItemWordsItem",
    "ListenV1SampleRate",
    "ListenV1Search",
    "ListenV1SmartFormat",
    "ListenV1Tag",
    "ListenV1UtteranceEndMs",
    "ListenV1VadEvents",
    "ListenV1Version",
    "ListenV2EagerEotThreshold",
    "ListenV2Encoding",
    "ListenV2EotThreshold",
    "ListenV2EotTimeoutMs",
    "ListenV2Keyterm",
    "ListenV2MipOptOut",
    "ListenV2Model",
    "ListenV2SampleRate",
    "ListenV2Tag",
    "OpenAiSpeakProvider",
    "OpenAiSpeakProviderModel",
    "OpenAiSpeakProviderVoice",
    "OpenAiThinkProvider",
    "OpenAiThinkProviderModel",
    "ProjectRequestResponse",
    "ReadV1Request",
    "ReadV1RequestText",
    "ReadV1RequestUrl",
    "ReadV1Response",
    "ReadV1ResponseMetadata",
    "ReadV1ResponseMetadataMetadata",
    "ReadV1ResponseMetadataMetadataIntentsInfo",
    "ReadV1ResponseMetadataMetadataSentimentInfo",
    "ReadV1ResponseMetadataMetadataSummaryInfo",
    "ReadV1ResponseMetadataMetadataTopicsInfo",
    "ReadV1ResponseResults",
    "ReadV1ResponseResultsSummary",
    "ReadV1ResponseResultsSummaryResults",
    "ReadV1ResponseResultsSummaryResultsSummary",
    "SharedIntents",
    "SharedIntentsResults",
    "SharedIntentsResultsIntents",
    "SharedIntentsResultsIntentsSegmentsItem",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItem",
    "SharedSentiments",
    "SharedSentimentsAverage",
    "SharedSentimentsSegmentsItem",
    "SharedTopics",
    "SharedTopicsResults",
    "SharedTopicsResultsTopics",
    "SharedTopicsResultsTopicsSegmentsItem",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItem",
    "SpeakSettingsV1",
    "SpeakSettingsV1Endpoint",
    "SpeakSettingsV1Provider",
    "SpeakSettingsV1Provider_AwsPolly",
    "SpeakSettingsV1Provider_Cartesia",
    "SpeakSettingsV1Provider_Deepgram",
    "SpeakSettingsV1Provider_ElevenLabs",
    "SpeakSettingsV1Provider_OpenAi",
    "SpeakV1Encoding",
    "SpeakV1MipOptOut",
    "SpeakV1Model",
    "SpeakV1Response",
    "SpeakV1SampleRate",
    "ThinkSettingsV1",
    "ThinkSettingsV1ContextLength",
    "ThinkSettingsV1Endpoint",
    "ThinkSettingsV1FunctionsItem",
    "ThinkSettingsV1FunctionsItemEndpoint",
    "ThinkSettingsV1Provider",
    "ThinkSettingsV1Provider_Anthropic",
    "ThinkSettingsV1Provider_AwsBedrock",
    "ThinkSettingsV1Provider_Google",
    "ThinkSettingsV1Provider_Groq",
    "ThinkSettingsV1Provider_OpenAi",
    "UpdateProjectMemberScopesV1Response",
    "UpdateProjectV1Response",
    "UsageBreakdownV1Response",
    "UsageBreakdownV1ResponseResolution",
    "UsageBreakdownV1ResponseResultsItem",
    "UsageBreakdownV1ResponseResultsItemGrouping",
    "UsageFieldsV1Response",
    "UsageFieldsV1ResponseModelsItem",
    "UsageV1Response",
    "UsageV1ResponseResolution",
]
