# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ErrorResponseLegacyErrorParams(typing_extensions.TypedDict):
    err_code: typing_extensions.NotRequired[str]
    """
    The error code
    """

    err_msg: typing_extensions.NotRequired[str]
    """
    The error message
    """

    request_id: typing_extensions.NotRequired[str]
    """
    The request ID
    """
