# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1settings_agent import AgentV1SettingsAgent
from .agent_v1settings_audio import AgentV1SettingsAudio
from .agent_v1settings_flags import AgentV1SettingsFlags


class AgentV1Settings(UniversalBaseModel):
    type: typing.Literal["Settings"] = "Settings"
    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Tags to associate with the request
    """

    experimental: typing.Optional[bool] = pydantic.Field(default=None)
    """
    To enable experimental features
    """

    flags: typing.Optional[AgentV1SettingsFlags] = None
    mip_opt_out: typing.Optional[bool] = pydantic.Field(default=None)
    """
    To opt out of Deepgram Model Improvement Program
    """

    audio: AgentV1SettingsAudio
    agent: AgentV1SettingsAgent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
