# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.speak_v1cleared_type import SpeakV1ClearedType


class SpeakV1ClearedParams(typing_extensions.TypedDict):
    type: SpeakV1ClearedType
    """
    Message type identifier
    """

    sequence_id: float
    """
    The sequence ID of the response
    """
