# This file was auto-generated by Fern from our API Definition.

import typing

from .error_response_legacy_error import ErrorResponseLegacyError
from .error_response_modern_error import ErrorResponseModernError
from .error_response_text_error import ErrorResponseTextError

ErrorResponse = typing.Union[ErrorResponseTextError, ErrorResponseLegacyError, ErrorResponseModernError]
